@@ -37,6 +37,16 @@
 #include <malloc.h>
 
 
+////////////////////////////////////////////////////////////////////////////////////
+// MS-specific defines/typedefs, which are absent under Linux but still used
+////////////////////////////////////////////////////////////////////////////////////
+#define _aligned_malloc(size, alignment) memalign(alignment, size)
+#define _aligned_free(ptr) free(ptr)
+typedef uint8_t BOOLEAN, *PBOOLEAN;
+////////////////////////////////////////////////////////////////////////////////////
+// MS-specific defines/typedefs, which are absent under Linux but still used (End)
+////////////////////////////////////////////////////////////////////////////////////
+
 ////////////////////////////////////////////////////////////////////////////////////
 //      Platform dependent macros (Start)
 ////////////////////////////////////////////////////////////////////////////////////
@@ -150,11 +160,18 @@ typedef enum _VA_CM_FORMAT {
     VA_CM_FMT_IMC3                 = VA_FOURCC_IMC3,
     VA_CM_FMT_YV12                 = VA_FOURCC_YV12,
     VA_CM_FMT_P010                 = VA_FOURCC_P010,
+    VA_CM_FMT_P012                 = VA_FOURCC_P012,
     VA_CM_FMT_P016                 = VA_FOURCC_P016,
     VA_CM_FMT_P208                 = VA_FOURCC_P208,
     VA_CM_FMT_AYUV                 = VA_FOURCC_AYUV,
     VA_CM_FMT_Y210                 = VA_FOURCC_Y210,
+#if VA_CHECK_VERSION(1, 9, 0)
+    VA_CM_FMT_Y212                 = VA_FOURCC_Y212,
+#endif
     VA_CM_FMT_Y410                 = VA_FOURCC_Y410,
+#if VA_CHECK_VERSION(1, 9, 0)
+    VA_CM_FMT_Y412                 = VA_FOURCC_Y412,
+#endif
     VA_CM_FMT_Y216                 = VA_FOURCC_Y216,
     VA_CM_FMT_Y416                 = VA_FOURCC_Y416,
     VA_CM_FMT_AI44                 = VA_FOURCC_AI44,
@@ -241,6 +258,22 @@ typedef enum _VA_CM_FORMAT {
 //      Platform dependent definitions (End)
 ////////////////////////////////////////////////////////////////////////////////////
 
+typedef enum _AdapterInfoType
+{
+    Description,                    //    char Description[ 256 ];
+    VendorId,                       //    uint32_t VendorId;
+    DeviceId,                       //    uint32_t DeviceId;
+    SubSysId,                       //    uint32_t SubSysId;
+    Revision,                       //    uint32_t Revision;
+    DedicatedVideoMemory,           //    uint32_t DedicatedVideoMemory;
+    DedicatedSystemMemory,          //    uint32_t DedicatedSystemMemory;
+    SharedSystemMemory,             //    uint32_t SharedSystemMemory;
+    MaxThread,                      //    uint32_t hardware thread count
+    EuNumber,                       //    uint32_t EU count
+    TileNumber,                     //    uint32_t Tile count
+    Reserved                        //    uint32_t
+} AdapterInfoType;
+
 typedef enum _REGISTRATION_OP
 {
     REG_IGNORE          = 0,
