@@ -64,12 +64,12 @@ struct CM_ENQUEUE_GPUCOPY_PARAM
 
 struct CM_CREATEBUFFER_PARAM
 {
-    uint32_t size;             // [in]  buffer size in byte
+    size_t size;             // [in]  buffer size in byte
     CM_BUFFER_TYPE bufferType;  // [in]  Buffer type (Buffer, BufferUP, or Buffer SVM)
     void *sysMem;              // [in]  Address of system memory
     void *bufferHandle;      // [out] pointer to CmBuffer object in CMRT@UMD
     int32_t returnValue;       // [out] the return value from CMRT@UMD
-    uint32_t reserved;        // Reserved field to ensure sizeof(CM_CREATEBUFFER_PARAM_V2) is different from sizeof(CM_CREATEBUFFER_PARAM_V1) in x64 mode
+    uint32_t option;
 };
 
 namespace CMRT_UMD
@@ -116,27 +116,6 @@ double CmGetTimeInms()
     return curTime;
 }
 
-//*-----------------------------------------------------------------------------
-//| Purpose:   Convert GMM_RESROUCE_Format got by GetCaps to OSAL format
-//| Return:    Result of the operation.
-//*-----------------------------------------------------------------------------
-int32_t ConvertToOperatingSystemAbstractionLayerFormat(void *src,
-                                                       uint32_t numOfFormats)
-{
-    uint32_t i = 0 ;
-    if(src == nullptr || numOfFormats == 0)
-    {
-        CM_ASSERTMESSAGE("Error: Invalid input arguments.");
-        return CM_INVALID_ARG_VALUE;
-    }
-
-    for ( i=0 ; i< numOfFormats ; i++)
-    {
-        *((CM_OSAL_SURFACE_FORMAT *)src+i) = CmMosFmtToOSFmt(*((CM_SURFACE_FORMAT *)src+i));
-    }
-    return CM_SUCCESS;
-}
-
 #define CM_SET_NOFAILURE_STATUS(hr) \
         if (hr != CM_FAILURE) \
         { \
@@ -152,6 +131,7 @@ using CMRT_UMD::CmSurface2D;
 using CMRT_UMD::CmSurface2DRT;
 using CMRT_UMD::SurfaceIndex;
 using CMRT_UMD::CmDeviceRT;
+using CMRT_UMD::CmDeviceRTBase;
 using CMRT_UMD::CmBuffer;
 using CMRT_UMD::CmBufferUP;
 using CMRT_UMD::CmBufferSVM;
@@ -173,6 +153,7 @@ using CMRT_UMD::CmVebox;
 using CMRT_UMD::CmVeboxRT;
 using CMRT_UMD::CmSurface3D;
 using CMRT_UMD::CmSampler8x8;
+using CMRT_UMD::CmBufferStateless;
 //*-----------------------------------------------------------------------------
 //| Purpose:    CMRT thin layer library supported function execution
 //| Return:     CM_SUCCESS if successful
@@ -187,6 +168,7 @@ int32_t CmThinExecuteInternal(CmDevice *device,
     CmBuffer                    *cmBuffer          = nullptr;
     CmBufferUP                  *cmBufferUP        = nullptr;
     CmBufferSVM                 *cmBufferSVM       = nullptr;
+    CmBufferStateless           *cmBufferStateless = nullptr;
     CmSurface2DRT               *cmSurface2d       = nullptr;
     CmSurface2DUP               *cmSurface2dup     = nullptr;
     CmProgram                   *cmProgram         = nullptr;
@@ -209,6 +191,8 @@ int32_t CmThinExecuteInternal(CmDevice *device,
     CmSurface2D                 *cmSurf2DBase      = nullptr;
     CmVebox                     *cmVebox           = nullptr;
     CmDeviceRT                  *deviceRT          = nullptr;
+    CmDeviceRTBase              *deviceRtBase      = nullptr;
+
     if (cmPrivateInputData == nullptr)
     {
         CM_ASSERTMESSAGE("Error: Null pointer.");
@@ -221,6 +205,7 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         return CM_NULL_POINTER;
     }
     deviceRT = static_cast<CmDeviceRT*>(device);
+    deviceRtBase = static_cast<CmDeviceRTBase *>(device);
 
     switch(cmFunctionID)
     {
@@ -268,6 +253,19 @@ int32_t CmThinExecuteInternal(CmDevice *device,
                 //Fill the output message
                 pCmBufferParam->returnValue        = cmRet;
             }
+            else if (pCmBufferParam->bufferType == CM_BUFFER_STATELESS)
+            {
+                cmRet = deviceRtBase->CreateBufferStateless(pCmBufferParam->size,
+                                                            pCmBufferParam->option,
+                                                            pCmBufferParam->sysMem,
+                                                            cmBufferStateless);
+                if (cmRet == CM_SUCCESS)
+                {
+                    pCmBufferParam->bufferHandle = cmBufferStateless;
+                }
+                //Fill the output message
+                pCmBufferParam->returnValue = cmRet;
+            }
             else //should never jump here
             {
                 pCmBufferParam->returnValue = CM_INVALID_ARG_VALUE;
@@ -319,21 +317,17 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         cmDestBufferSVMParam->returnValue  = cmRet;
         break;
 
-    case CM_FN_CMDEVICE_CREATESURFACE2DUP:
-        PCM_CREATESURFACE2DUP_PARAM cmCreate2DUpParam;
-        cmCreate2DUpParam = (PCM_CREATESURFACE2DUP_PARAM)(cmPrivateInputData);
+    case CM_FN_CMDEVICE_DESTROYBUFFERSTATELESS:
+        PCM_DESTROYBUFFER_PARAM cmDestBufferStatelessParam;
+        cmDestBufferStatelessParam = (PCM_DESTROYBUFFER_PARAM)(cmPrivateInputData);
 
-        cmRet = device->CreateSurface2DUP(cmCreate2DUpParam->width,
-            cmCreate2DUpParam->height,
-            CmOSFmtToMosFmt(cmCreate2DUpParam->format),
-            cmCreate2DUpParam->sysMem,
-            cmSurface2dup);
-        if( cmRet == CM_SUCCESS)
-        {
-            cmCreate2DUpParam->surface2DUPHandle = static_cast<CmSurface2DUP *>(cmSurface2dup);
-        }
+        cmBufferStateless =
+            static_cast<CmBufferStateless *>(cmDestBufferStatelessParam->bufferHandle);
+        CM_ASSERT(cmBufferStateless);
 
-        cmCreate2DUpParam->returnValue         = cmRet;
+        cmRet = deviceRtBase->DestroyBufferStateless(cmBufferStateless);
+        //Fill the output message
+        cmDestBufferStatelessParam->returnValue = cmRet;
         break;
 
     case CM_FN_CMDEVICE_DESTROYSURFACE2DUP:
@@ -346,22 +340,6 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         cmDestroy2DUpParam->returnValue        = cmRet;
         break;
 
-    case CM_FN_CMDEVICE_GETSURFACE2DINFO:
-        PCM_GETSURFACE2DINFO_PARAM cmGet2DinfoParam;
-        uint32_t pitch,physicalsize;
-        cmGet2DinfoParam = (PCM_GETSURFACE2DINFO_PARAM)(cmPrivateInputData);
-
-        cmRet = device->GetSurface2DInfo( cmGet2DinfoParam->width,
-                                        cmGet2DinfoParam->height,
-                                        CmOSFmtToMosFmt(cmGet2DinfoParam->format),
-                                        pitch,
-                                        physicalsize);
-
-        cmGet2DinfoParam->pitch           = pitch;
-        cmGet2DinfoParam->physicalSize    = physicalsize;
-        cmGet2DinfoParam->returnValue     = cmRet;
-        break;
-
      case CM_FN_CMDEVICE_CREATESURFACE2D_ALIAS:
          {
              PCM_DEVICE_CREATE_SURF2D_ALIAS_PARAM createSurf2DAliasParam;
@@ -512,10 +490,7 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         {
             // Sync queue option and handle to thin layer.
             CmQueueRT *cmQueueRT = static_cast<CmQueueRT *>(cmQueue);
-            cmCreateQueParam->queueType     = (unsigned int)cmQueueRT->GetQueueOption().QueueType;
-            cmCreateQueParam->runAloneMode  = (unsigned int)cmQueueRT->GetQueueOption().RunAloneMode;
-            cmCreateQueParam->gpuContext    = (unsigned int)cmQueueRT->GetQueueOption().GPUContext;
-            cmCreateQueParam->sseuUsageHint = (unsigned int)cmQueueRT->GetQueueOption().SseuUsageHint;
+            cmCreateQueParam->createOption  = cmQueueRT->GetQueueOption();
             cmCreateQueParam->queueHandle   = (cmQueue);
             cmCreateQueParam->returnValue   = CM_SUCCESS;
         }
@@ -531,13 +506,9 @@ int32_t CmThinExecuteInternal(CmDevice *device,
     {
         CM_CREATEQUEUE_PARAM *cmCreateQueParam;
         cmCreateQueParam = (CM_CREATEQUEUE_PARAM *)(cmPrivateInputData);
+        CM_ASSERT(cmCreateQueParam);
 
-        CM_QUEUE_CREATE_OPTION queueCreateOption = CM_DEFAULT_QUEUE_CREATE_OPTION;
-        queueCreateOption.QueueType = (CM_QUEUE_TYPE)cmCreateQueParam->queueType;
-        queueCreateOption.RunAloneMode = cmCreateQueParam->runAloneMode;
-        queueCreateOption.GPUContext = cmCreateQueParam->gpuContext;
-        queueCreateOption.SseuUsageHint = (CM_QUEUE_SSEU_USAGE_HINT_TYPE)cmCreateQueParam->sseuUsageHint;
-        cmRet = device->CreateQueueEx(cmQueue, queueCreateOption);
+        cmRet = device->CreateQueueEx(cmQueue, cmCreateQueParam->createOption);
 
         cmCreateQueParam->returnValue = cmRet;
         cmCreateQueParam->queueHandle = (cmQueue);
@@ -606,7 +577,7 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         cmEvent        = (CmEvent *)cmDestroyEventParam->eventHandle;
         CM_ASSERT(cmQueue);
         CM_ASSERT(cmEvent);
-        
+
         cmRet = cmQueue->DestroyEvent(cmEvent);
 
         cmDestroyEventParam->returnValue = cmRet;
@@ -621,13 +592,13 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         cmEvent        = (CmEvent *)cmDestroyEventParam->eventHandle;
         CM_ASSERT(cmQueue);
         CM_ASSERT(cmEvent);
-        
+
         cmRet = cmQueue->DestroyEventFast(cmEvent);
 
         cmDestroyEventParam->returnValue = cmRet;
     }
         break;
-        
+
     case CM_FN_CMDEVICE_CREATETHREADSPACE:
         PCM_CREATETHREADSPACE_PARAM cmCreateTsParam;
         cmCreateTsParam = (PCM_CREATETHREADSPACE_PARAM)(cmPrivateInputData);
@@ -908,7 +879,7 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         CM_ASSERT(cmQueue);
 
         cmRet = cmQueue->EnqueueCopyCPUToCPU((unsigned char *) enqueueCopyL2LParam->dstSysMem,
-                                           (unsigned char *) enqueueCopyL2LParam->srcSysMem,
+                                            (unsigned char *) enqueueCopyL2LParam->srcSysMem,
                                             enqueueCopyL2LParam->copySize,
                                             enqueueCopyL2LParam->option,
                                             cmEvent);
@@ -918,6 +889,27 @@ int32_t CmThinExecuteInternal(CmDevice *device,
 
         break;
 
+    case CM_FN_CMQUEUE_ENQUEUECOPY_BUFFER:
+        PCM_ENQUEUE_COPY_BUFFER_PARAM  enqueueCopyBtoCPUParam;
+        enqueueCopyBtoCPUParam = (PCM_ENQUEUE_COPY_BUFFER_PARAM)(cmPrivateInputData);
+        cmQueue = (CmQueue*)enqueueCopyBtoCPUParam->cmQueueHandle;
+        CM_ASSERT(cmQueue);
+        cmEvent = (CmEvent*)enqueueCopyBtoCPUParam->cmEventHandle; // used as input
+        cmQueueRT = static_cast<CmQueueRT*>(cmQueue);
+
+        cmRet = cmQueueRT->EnqueueBufferCopy((CmBuffer*)enqueueCopyBtoCPUParam->buffer,
+                                            enqueueCopyBtoCPUParam->offset,
+                                            (unsigned char*)enqueueCopyBtoCPUParam->sysMem,
+                                            enqueueCopyBtoCPUParam->copySize,
+                                            (CM_GPUCOPY_DIRECTION)enqueueCopyBtoCPUParam->copyDir,
+                                            (CmEvent*)enqueueCopyBtoCPUParam->wait_event,
+                                            cmEvent,
+                                            enqueueCopyBtoCPUParam->option);
+
+        enqueueCopyBtoCPUParam->cmEventHandle = cmEvent;
+        enqueueCopyBtoCPUParam->returnValue = cmRet;
+        break;
+
     case CM_FN_CMQUEUE_ENQUEUEVEBOX:
         PCM_ENQUEUE_VEBOX_PARAM enqueueVeboxParam;
         enqueueVeboxParam = (PCM_ENQUEUE_VEBOX_PARAM)(cmPrivateInputData);
@@ -935,23 +927,6 @@ int32_t CmThinExecuteInternal(CmDevice *device,
 
         break;
 
-        //Surface 3D Create/Destroy Read/Write
-    case CM_FN_CMDEVICE_CREATESURFACE3D:
-        PCM_CREATE_SURFACE3D_PARAM createSurf3dParam;
-        createSurf3dParam = (PCM_CREATE_SURFACE3D_PARAM)(cmPrivateInputData);
-
-        cmRet = device->CreateSurface3D(createSurf3dParam->width,
-                                    createSurf3dParam->height,
-                                    createSurf3dParam->depth,
-                                    CmOSFmtToMosFmt(createSurf3dParam->format),
-                                    cmSurface3d);
-        if(cmRet == CM_SUCCESS)
-        {
-             createSurf3dParam->surface3DHandle  = static_cast<CmSurface3D *>(cmSurface3d);
-        }
-        createSurf3dParam->returnValue        = cmRet;
-        break;
-
     case CM_FN_CMDEVICE_DESTROYSURFACE3D:
         PCM_DESTROY_SURFACE3D_PARAM destroySurf3dParam;
         destroySurf3dParam = (PCM_DESTROY_SURFACE3D_PARAM)(cmPrivateInputData);
@@ -1107,6 +1082,13 @@ int32_t CmThinExecuteInternal(CmDevice *device,
         initPrintBufferParam->returnValue     = cmRet;
         break;
 
+    case CM_FN_CMDEVICE_FLUSH_PRINT_BUFFER:
+        PCM_DEVICE_FLUSH_PRINT_BUFFER_PARAM flushPrintBufferParam;
+        flushPrintBufferParam  = (PCM_DEVICE_FLUSH_PRINT_BUFFER_PARAM)(cmPrivateInputData);
+        cmRet = device->FlushPrintBufferIntoFile(flushPrintBufferParam->fileName);
+        flushPrintBufferParam->returnValue     = cmRet;
+        break;
+
     case CM_FN_CMDEVICE_CREATEVEBOX:
         {
             PCM_CREATEVEBOX_PARAM createVeboxParam;
