@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2016-2019, Intel Corporation
+* Copyright (c) 2016-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -1019,7 +1019,7 @@ MOS_STATUS CodecHalDecodeScalability_SwitchGpuContext(
         MOS_ZeroMemory(&UserFeatureWriteData, sizeof(UserFeatureWriteData));
         UserFeatureWriteData.Value.i32Data = pScalabilityState->bFESeparateSubmission;
         UserFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_SCALABILITY_FE_SEPARATE_SUBMISSION_IN_USE_ID;
-        MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1);
+        MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1, pOsInterface->pOsContext);
     }
 #endif
 
@@ -1300,10 +1300,13 @@ MOS_STATUS CodechalDecodeScalability_DebugOvrdDecidePipeNum(
 
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState);
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pVEInterface);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface);
 
     pVEInterface = pScalState->pVEInterface;
+    PMOS_INTERFACE pOsInterface = pScalState->pHwInterface->GetOsInterface();
+    CODECHAL_DECODE_CHK_NULL_RETURN(pOsInterface);
 
-    if (g_apoMosEnabled)
+    if (pOsInterface->apoMosEnabled)
     {
         CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface->veInterface);
         auto veInterface = pVEInterface->veInterface;
@@ -1395,7 +1398,7 @@ MOS_STATUS CodechalDecodeScalability_ConstructParmsForGpuCtxCreation(
         }
         CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnDebugOvrdDecidePipeNum(pScalState));
 
-        if (g_apoMosEnabled)
+        if (pOsInterface->apoMosEnabled)
         {
             CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface->veInterface);
             for (uint32_t i = 0; i < pVEInterface->veInterface->GetEngineCount(); i++)
@@ -1436,7 +1439,7 @@ MOS_STATUS CodechalDecodeScalability_ConstructParmsForGpuCtxCreation(
             }
         }
         initParams.usingSFC             = sfcInUse;
-        initParams.usingSecureDecode    = codecHalSetting->DecodeEncType();
+        initParams.usingSecureDecode    = codecHalSetting->secureMode;
         CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnDecidePipeNum(
             pScalState,
             &initParams));
@@ -1481,7 +1484,7 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams(
     {
         if (!MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(pOsInterface))
         {
-            if (g_apoMosEnabled)
+            if (pOsInterface->apoMosEnabled)
             {
                 CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface->veInterface);
                 pScalabilityState->ucScalablePipeNum = pVEInterface->veInterface->GetEngineCount() - 1;
@@ -1987,21 +1990,24 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState (
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD1_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dwHcpDecModeSwtichTh1Width = UserFeatureData.u32Data;
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD2_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dwHcpDecModeSwtichTh2Width = UserFeatureData.u32Data;
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_SCALABILITY_OVERRIDE_SPLIT_WIDTH_IN_MINCB,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dbgOvrdWidthInMinCb = UserFeatureData.u32Data;
 #endif
 
@@ -2073,7 +2079,8 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState (
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_ALWAYS_FRAME_SPLIT_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bAlwaysFrameSplit = UserFeatureData.u32Data ? true : false;
 #endif
 
