@@ -671,6 +671,9 @@ MOS_STATUS CodechalEncodeJpegState::ExecuteSliceLevel()
     CodecJpegQuantMatrix *tempJpegQuantMatrix = (CodecJpegQuantMatrix *)MOS_AllocAndZeroMemory(sizeof(CodecJpegQuantMatrix));
     CODECHAL_ENCODE_CHK_NULL_RETURN(tempJpegQuantMatrix);
 
+    static_assert(JPEG_MAX_NUM_QUANT_TABLE_INDEX <= JPEG_MAX_NUM_OF_QUANTMATRIX,
+        "access to CodecJpegQuantMatrix is controlled by numQuantTables");
+
     uint32_t numQuantTables = JPEG_MAX_NUM_QUANT_TABLE_INDEX;
     for (uint32_t scanCount = 0; scanCount < m_encodeParams.dwNumSlices; scanCount++)
     {
@@ -963,8 +966,8 @@ MOS_STATUS CodechalEncodeJpegState::ExecuteSliceLevel()
                 }
                 pakInsertObjectParams.dwOffset                      = 0;
                 pakInsertObjectParams.dwBitSize                     = pakInsertObjectParams.pBsBuffer->BufferSize;
-                //if full header is included in application data, it will be the last insert headers
-                if((appDataCmdSizeResidue == 0) && m_fullHeaderInAppData)
+                //if full header is included in application data, it will be the last header to insert and last chunk of it should be marked with EndOfSlice
+                if((appDataCmdSizeResidue == 0) && m_fullHeaderInAppData && (i == numAppDataCmdsNeeded - 1))
                 {
                     pakInsertObjectParams.bLastHeader                   = true;
                     pakInsertObjectParams.bEndOfSlice                   = true;
@@ -1323,6 +1326,27 @@ uint32_t CodechalEncodeJpegState::CalculateCommandBufferSize()
     return commandBufferSize;
 }
 
+MOS_STATUS CodechalEncodeJpegState::GetStatusReport(
+    EncodeStatus* encodeStatus,
+    EncodeStatusReport* encodeStatusReport)
+{
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+    PMHW_VDBOX_IMAGE_STATUS_CONTROL imgStatusCtrl = &encodeStatus->ImageStatusCtrl;
+
+    // The huffman tables sent by application were incorrect (used only for JPEG encoding)
+    if (imgStatusCtrl->MissingHuffmanCode == 1)
+    {
+        CODECHAL_ENCODE_ASSERTMESSAGE("Error: JPEG standard encoding: missing huffman code");
+        encodeStatusReport->CodecStatus = CODECHAL_STATUS_ERROR;
+        return eStatus;
+    }
+
+    eStatus = GetStatusReportCommon(encodeStatus, encodeStatusReport);
+
+    return eStatus;
+}
+
 CodechalEncodeJpegState::CodechalEncodeJpegState(
         CodechalHwInterface* hwInterface,
         CodechalDebugInterface* debugInterface,
@@ -1332,6 +1356,8 @@ CodechalEncodeJpegState::CodechalEncodeJpegState(
     CODECHAL_ENCODE_FUNCTION_ENTER;
 
     memset(m_refList, 0, sizeof(m_refList));
+
+    m_codecGetStatusReportDefined = true;
 }
 
 #if USE_CODECHAL_DEBUG_TOOL
