@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2013-2019, Intel Corporation
+* Copyright (c) 2013-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -20,8 +20,8 @@
 * OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
-//! \file      codechal_secure_decode_interface.h 
-//! \brief     Stub file for CodecHal Secure Decode 
+//! \file      codechal_secure_decode_interface.h
+//! \brief     Stub file for CodecHal Secure Decode
 //!
 #ifndef __CODECHAL_SECURE_DECODE_INTERFACE_H__
 #define __CODECHAL_SECURE_DECODE_INTERFACE_H__
@@ -124,22 +124,18 @@ public:
     //!
     virtual MOS_STATUS InitAuxSurface(
         PMOS_RESOURCE res,
-        bool auxUV) = 0;
+        bool auxUV,
+        bool isMmcEnabled) = 0;
 
     //!
     //! \brief  Is Dummy SteamOut Enabled
     //!
     virtual bool IsDummyStreamEnabled() = 0;
 
-    //!
-    //! \brief  Is secure decode is enabled
-    //!
-    virtual bool IsSecureDecodeEnabled() = 0;
-
     //!
     //! \brief  Destructor
     //!
-    virtual ~CodechalSecureDecodeInterface(){} 
+    virtual ~CodechalSecureDecodeInterface(){}
 
     //!
     //! \brief  Update huc streamout buffer index
@@ -149,19 +145,19 @@ public:
 
 
 //!
-//! \brief    Create CodechalSecureDeocde Object according CPLIB loading status
+//! \brief    Create CodechalSecureDeocde Object
 //!           Must use Delete_CodechalSecureDecodeInterface to delete created Object to avoid ULT Memory Leak errors
 //!
-//! \return   Return CP Wrapper Object if CPLIB not loaded
+//! \return   Return CP Wrapper Object
 //!
 CodechalSecureDecodeInterface *Create_SecureDecodeInterface(
     CodechalSetting *      codechalSettings,
     CodechalHwInterface *  hwInterfaceInput);
 
 //!
-//! \brief    Delete the CodecHalSecureDecode Object according CPLIB loading status
+//! \brief    Delete the CodecHalSecureDecode Object
 //!
-//! \param    [in] *pMhwCpInterface 
+//! \param    [in] *pMhwCpInterface
 //!           MhwCpInterface
 //!
 void Delete_SecureDecodeInterface(CodechalSecureDecodeInterface* pCodechalSecureDecodeInterface);
