@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2017, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -65,9 +65,12 @@ public:
     // Decode SFC enabling
     bool                    sfcEnablingHinted = false;     //!< Applies to decode only, application may request field sfc.
     bool                    sfcInUseHinted = false;        //!< Applies to decode only, application may request sfc engine.
-    bool                    enableCodecMmc = false;        //!< Applies to both of decode and encode, to indicate if codec MMC could be enabled by default
+    bool                    enableCodecMmc = true;        //!< Applies to both of decode and encode, to indicate if codec MMC could be enabled by default
     bool                    secureMode = false;            //!< secure decoder is required if enabled
 
+    // HEVC Encode only
+    bool                     isSCCEnabled = false;          //!< Flag to indicate if HEVC SCC is enabled.
+
     //!
     //! \brief    Destructor 
     //!
@@ -83,11 +86,6 @@ public:
     //!
     virtual bool CheckCencAdvance() {return false; };
 
-    //!
-    //! \brief    Return the decode enc type 
-    //!
-    virtual uint32_t DecodeEncType() {return 0; };
-
     //!
     //! \brief    Create CodechalSetting instance 
     //!
