@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2019, Intel Corporation
+* Copyright (c) 2009-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -74,6 +74,34 @@ protected:
     MosInterface() = default;
 
 public:
+    //!
+    //! \brief    Init Os Utilities
+    //! \details  Include Utilities, user settings key, mem ninja etc
+    //! \details  Must be first called MOS interface before CreateOsDeviceContext
+    //! \details  Caller: DDI only.
+    //!
+    //! \param    [in] ddiDeviceContext
+    //!           Pointer of device context in DDI to init Os Device Context
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS InitOsUtilities(DDI_DEVICE_CONTEXT ddiDeviceContext);
+
+    //!
+    //! \brief    Close Os Utilities
+    //! \details  Include Utilities, user settings key, mem ninja etc
+    //! \details  Must be last called MOS interface after DestroyOsDeviceContext
+    //! \details  Caller: DDI only.
+    //!
+    //! \param    [in] mosCtx
+    //!           Pointer of device context in DDI for reg ops
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS CloseOsUtilities(PMOS_CONTEXT mosCtx);
+
     //!
     //! \brief    Create Os Device Context
     //! \details  Create the Os Device Context in device level.
@@ -105,7 +133,7 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     static MOS_STATUS DestroyOsDeviceContext(MOS_DEVICE_HANDLE deviceContext);
-    
+
     //!
     //! \brief    Create Os Stream State
     //! \details  Create the Os Stream State in stream level.
@@ -117,14 +145,25 @@ public:
     //!           Handle of Os Stream State to create. If creation failed, it is INVALID_HANLE.
     //!           OsStreamState is a stream level state which stores the flags, info specific to OS specfic to that stream.
     //!           It is be binded with a valid OsDeviceContext to indicate the inclusion relationship between device and stream.
+    //! \param    [in] deviceContext
+    //!           Device context to init streamState
+    //! \param    [in] osInterface
+    //!           Os interface to store streamState
+    //! \param    [in] component
+    //!           Indicate which component the stream state to create belongs to
+    //! \param    [in] extraParams
+    //!           Additional parameters needed to init streamstate
     //!
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!    
+    //!
     static MOS_STATUS CreateOsStreamState(
-        MOS_STREAM_HANDLE *streamState,
-        MOS_DEVICE_HANDLE deviceContext);
-     
+        MOS_STREAM_HANDLE       *streamState,
+        MOS_DEVICE_HANDLE       deviceContext,
+        MOS_INTERFACE_HANDLE    osInterface,
+        MOS_COMPONENT           component,
+        EXTRA_PARAMS            extraParams = nullptr);
+
     //!
     //! \brief    Destroy Os Stream State
     //! \details  Destroy the Os Stream State in stream level
@@ -209,7 +248,23 @@ public:
     //!           Read-only GT system info got, nullptr if failed to get
     //!
     static MEDIA_SYSTEM_INFO *GetGtSystemInfo(MOS_STREAM_HANDLE streamState);
-    
+
+    //!
+    //! \brief    Get Media Engine Info
+    //! \details  [System info Interface] Get Media Engine Info
+    //! \details  Caller: HAL & MHW
+    //! \details  This func is called to differentiate the behavior according to Media Engine Info.
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    [in] info
+    //!           MEDIA_SYS_INFO
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS GetMediaEngineInfo(MOS_STREAM_HANDLE streamState, MEDIA_ENGINE_INFO &info);
+
     //!
     //! \brief    Get Adapter Info
     //! \details  [System info Interface] Get Adapter Info
@@ -227,14 +282,50 @@ public:
     //!
     //! \brief    Get current gmmclientcontext
     //! \details  Get current gmmclientcontext
-    //! \param    PMOS_INTERFACE pOsInterface
-    //!           [in] OS Interface
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //!
     //! \return   GMM_CLIENT_CONTEXT
     //!           Current gmmclientcontext
     //!
     static GMM_CLIENT_CONTEXT *GetGmmClientContext(
         MOS_STREAM_HANDLE streamState);
 
+    //!
+    //! \brief    Get current Gpu context priority
+    //! \details  Get current Gpu context priority
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //!
+    //!           [out]
+    //!           Current Gpu context priority
+    //!
+    static void GetGpuPriority(MOS_STREAM_HANDLE streamState, int32_t* priority);
+
+    //!
+    //! \brief    Set current Gpu context priority
+    //! \details  Set current Gpu context priority
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //!           [in] priority
+    //!           priority to set for gpu context
+    //!
+    static void SetGpuPriority(MOS_STREAM_HANDLE streamState, int32_t priority);
+
+    //!
+    //! \brief    Get AuxTable base address
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   uint64_t
+    //!           64bit base address value of AuxTable
+    //!
+    static uint64_t GetAuxTableBaseAddr(
+        MOS_STREAM_HANDLE streamState);
+
     //!
     //! \brief    Create Gpu Context
     //! \details  [GPU Context Interface] Create Gpu Context to submit cmdbuffers
@@ -304,10 +395,25 @@ public:
         MOS_STREAM_HANDLE streamState,
         GPU_CONTEXT_HANDLE gpuContext);
 
+    //!
+    //! \brief    Get GPU context pointer
+    //! \details  Get GPU context pointer
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    GPU_CONTEXT_HANDLE gpuContextHandle
+    //!           [in] GPU Context Handle
+    //! \return   void *
+    //!           a pointer to a gpu context
+    //!
+    static void *GetGpuContextbyHandle(
+        MOS_STREAM_HANDLE  streamState,
+        GPU_CONTEXT_HANDLE gpuContextHandle);
+
     //!
     //! \brief    Add Command
     //! \details  [Cmd Buffer Interface] Add gpu commands into cmd buffer
     //! \details  Caller: MHW only
+    //! \details  It is not device stated function and can be used in both APO MHW and NON-APO MOS.
     //! \details  This func is called when a stream (Hal instance) adds gpu cmds into cmd buffer.
     //! \details  Before getting a cmd buffer to program GPU cmds, a valid GPU context must be setted into the stream.
     //! \details  Calling sequence is like: SetGpuContext -> GetCommandBuffer -> AddCommand ...
@@ -559,7 +665,7 @@ public:
         uint8_t **indirectState,
         uint32_t &offset,
         uint32_t &size);
-    
+
     //!
     //! \brief    Setup indirect state
     //! \details  [Cmd Buffer Interface] Setup the indirect state region in cmd buffer.
@@ -580,6 +686,25 @@ public:
         MOS_STREAM_HANDLE streamState,
         uint32_t size);
 
+    //!
+    //! \brief    Setup commandlist and command pool
+    //! \details  Set the commandlist and commandPool used in this stream.
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    [in] cmdList
+    //!           pointer to the command list.
+    //! \param    [in] cmdBufMgr
+    //!           pointer to the command buffer manager.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS SetupCurrentCmdListAndPool(
+        MOS_STREAM_HANDLE   streamState,
+        CommandList         *cmdList,
+        CmdBufMgrNext       *cmdBufMgr);
+
     //!
     //! \brief    Setup VE Attribute Buffer
     //! \details  [Cmd Buffer Interface] Setup VE Attribute Buffer into cmd buffer.
@@ -614,7 +739,22 @@ public:
     //!
     static MOS_CMD_BUF_ATTRI_VE *GetAttributeVeBuffer(
         COMMAND_BUFFER_HANDLE cmdBuffer);
-        
+
+    //!
+    //! \brief    Get Cache Policy Memory Object
+    //! \details  [Resource Interface] Get Cache Policy Memory Object in GMM corresponding to the resource usage
+    //!           Caller: HAL & MHW
+    //!
+    //! \param    [in] mosUsage
+    //!           Resource usage as index to the memory object table
+    //!           If prociding unknown usage, default state will be returned
+    //!
+    //! \return   MEMORY_OBJECT_CONTROL_STATE
+    //!           The cache policy memory object got from MOS interface
+    //!
+    static GMM_RESOURCE_USAGE_TYPE GetGmmResourceUsageType(
+        MOS_HW_RESOURCE_DEF mosUsage);
+
     //!
     //! \brief    Get Cache Policy Memory Object
     //! \details  [Resource Interface] Get Cache Policy Memory Object in GMM corresponding to the resource usage
@@ -651,10 +791,67 @@ public:
         MOS_STREAM_HANDLE streamState,
         MOS_HW_RESOURCE_DEF mosUsage);
 
+    //!
+    //! \brief    Get Reserved info from resource
+    //! \details
+    //!
+    //! \param    [in] resource
+    //!           Handle of resource
+    //! \param    [out] val
+    //!           result of info.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS GetReservedFromResouce(MOS_RESOURCE_HANDLE resource, uint32_t &val);
+
+    //!
+    //! \brief    Get Reserved info from Stream
+    //! \details
+    //!
+    //! \param    [in] stream
+    //!           Handle of stream
+    //! \param    [out] val
+    //!           result of info.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS GetReservedFromStream(MOS_STREAM_HANDLE stream, uint32_t &val);
+
+    //!
+    //! \brief    Get Reserved info from Device
+    //! \details
+    //!
+    //! \param    [in] osDeivceContext
+    //!           Handle of device
+    //! \param    [out] val
+    //!           result of info.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS GetReservedFromDevice(MOS_DEVICE_HANDLE device, uint32_t &val);
+
+    //!
+    //! \brief    Get preStreamParameters(mos context) info from streamState
+    //! \details
+    //!
+    //! \param    [in] stream
+    //!           Handle of stream
+    //! \param    [out] perStreamParameters
+    //!           pointer of mos conxtex.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS GetperStreamParameters(MOS_STREAM_HANDLE stream, void **perStreamParameters);
+
     //!
     //! \brief    Convert Resource From Ddi
     //! \details  [Resource Interface] Convert Resource structure From OS/API specific to MOS reource.
     //! \details  Caller: DDI only
+    //! \details  It is not device stated function and can be used in both APO DDI and NON-APO MOS.
     //! \details  MOS resoure is the structure inside MOS module. DDI specific resource depends on OS/API verison.
     //!           DDI call this to convert external resources (not created by hal) to Mos resources so that HAL & MHW can use them.
     //!
@@ -692,13 +889,14 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     static MOS_STATUS CreateOsSpecificResourceInfo(OsSpecificRes resource, bool isInternal = false);
-    
+
     //!
     //! \brief    Destroy Os Specific Resource Info
     //! \details  [Resource Interface] Destroy OS/API specific resource structure.
     //! \details  Caller: DDI only
+    //! \details  It is not device stated function and can be used in both APO DDI and NON-APO MOS.
     //! \details  Os Specific resource info must be destroied if the resource is not used anymore.
-    //!           
+    //!
     //! \param    [in, out] resource
     //!           OS/API specific resource structure to initialize.
     //!
@@ -706,7 +904,7 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     static MOS_STATUS DestroySpecificResourceInfo(OsSpecificRes resource);
-        
+
     //!
     //! \brief    Allocate Resource
     //! \details  [Resource Interface] Allocate a graphic resource.
@@ -726,9 +924,29 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     static MOS_STATUS AllocateResource(
-        MOS_STREAM_HANDLE streamState,
-        PMOS_ALLOC_GFXRES_PARAMS params,    // user provided va
-        MOS_RESOURCE_HANDLE &resource);
+        MOS_STREAM_HANDLE           streamState,
+        PMOS_ALLOC_GFXRES_PARAMS    params,    // user provided va
+        MOS_RESOURCE_HANDLE         &resource
+#if MOS_MESSAGES_ENABLED
+        ,
+        const char                  *functionName,
+        const char                  *filename,
+        int32_t                     line
+#endif
+    );
+
+    //!
+    //! \brief    Convert HAL free flags to OS free flags
+    //!
+    //! \param    [in] halFreeFlag
+    //!           bit definition in MOS_GFXRES_FREE_FLAGS
+    //!
+    //! \return   uint32_t
+    //!           OS resouce deallc flags
+    //!
+    static uint32_t ConvertHalFreeFlagsToOsFreeFlags(
+        uint32_t halFreeFlag
+    );
 
     //!
     //! \brief    Free Resource
@@ -749,9 +967,16 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     static MOS_STATUS FreeResource(
-        MOS_STREAM_HANDLE streamState,
-        MOS_RESOURCE_HANDLE resource,
-        uint32_t flag);
+        MOS_STREAM_HANDLE       streamState,
+        MOS_RESOURCE_HANDLE     resource,
+        uint32_t                flag
+#if MOS_MESSAGES_ENABLED
+        ,
+        const char              *functionName,
+        const char              *filename,
+        int32_t                 line
+#endif  // MOS_MESSAGES_ENABLED
+    );
 
     //!
     //! \brief    Get Resource Info
@@ -823,6 +1048,20 @@ public:
         MOS_STREAM_HANDLE streamState,
         MOS_RESOURCE_HANDLE resource);
 
+    //!
+    //! \brief    Update resource usage type
+    //! \details  update the resource usage for cache policy
+    //! \param    PMOS_RESOURCE pOsResource
+    //!           [in/out] Pointer to OS Resource
+    //! \param    MOS_HW_RESOURCE_DEF resUsageType
+    //!           [in] MOS resosuce usage type
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS UpdateResourceUsageType(
+        PMOS_RESOURCE           pOsResource,
+        MOS_HW_RESOURCE_DEF     resUsageType);
+
     //!
     //! \brief    Register Resource
     //! \details  [Resource Interface] Register the resource to current streamState.
@@ -893,6 +1132,7 @@ public:
     //! \brief    Skip Resource Sync
     //! \details  [Resource Interface] Skip the sync handling of the resource 
     //! \details  Caller: HAL only
+    //! \details  It is not device stated function and can be used in both APO HAL and NON-APO MOS.
     //! \details  Indicate the resource provided needn't to be synced. 
     //!           The resource skipping sync can be accessed by different cmd buffers on different GPU contexts at the same time.
     //! \details  RegisterResource and LockResource will not handling the sync of the resources between different GPU cotnexts.
@@ -1027,6 +1267,8 @@ public:
     //!
     //! \brief    Trim Residency
     //!
+    //! \param    [in] device
+    //!           MOS device handle
     //! \param    [in] periodicTrim
     //!           Indicate if the trim is periodic
     //! \param    [in] restartPeriodicTrim
@@ -1042,12 +1284,32 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!        
     static MOS_STATUS TrimResidency(
+        MOS_DEVICE_HANDLE device,
         bool periodicTrim, 
         bool restartPeriodicTrim, 
         uint64_t &numBytesToTrim, 
         bool trimToMinimum,
         bool trimOnlyMediaResources);
 
+    //!
+    //! \brief    Update Residency
+    //!
+    //! \param    [in] device
+    //!           MOS device handle
+    //! \param    [in] resInfo
+    //!           Os specific resource info
+    //! \param    [in] index
+    //!           Resource index
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!  
+    static MOS_STATUS UpdateResidency(
+        MOS_DEVICE_HANDLE device,
+        OsSpecificRes     resInfo,
+        uint32_t          index);
+    
+
     // Memory compression interfaces
 
     //!
@@ -1187,10 +1449,10 @@ public:
         uint32_t            copyHeight,
         uint32_t            copyInputOffset,
         uint32_t            copyOutputOffset,
+        uint32_t            bpp,
         bool                outputCompressed);
 
     // GPU Status interfaces
-
     //!
     //! \brief   Get Gpu Status Tag
     //!
@@ -1252,7 +1514,7 @@ public:
 
     static MOS_STATUS GetGpuStatusBufferResource(
         MOS_STREAM_HANDLE streamState,
-        MOS_RESOURCE_HANDLE resource,
+        MOS_RESOURCE_HANDLE &resource,
         GPU_CONTEXT_HANDLE gpuContext);
     
     //!
@@ -1478,7 +1740,109 @@ public:
 
 #endif // _DEBUG || _RELEASE_INTERNAL
 
+    //!
+    //! \brief    Sets the perf tag
+    //! \details  Sets the perf tag
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    uint32_t perfTag
+    //!           [in] Perf tag
+    //! \return   void
+    //!
+    static void SetPerfTag(
+        MOS_STREAM_HANDLE streamState,
+        uint32_t       perfTag);
+
+    //!
+    //! \brief    Gets the perf tag
+    //! \details  Gets the perf tag
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   uint32_t
+    //!           Return perf tag
+    //!
+    static uint32_t GetPerfTag(
+        MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief    Check if Perf Tag is already set
+    //! \details  Check if Perf Tag is already set
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   int32_t
+    //!
+    static int32_t IsPerfTagSet(
+        MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief    Increase performance data frame ID
+    //! \details  Increase performance data frame ID
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   void
+    //!
+    static void IncPerfFrameID(
+        MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief    Set Hybrid Kernel ID
+    //! \details  Set Hybrid Kernel ID
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    uint32_t kernelID
+    //!           [in] Hybrid Decoder kernel ID
+    //! \return   void
+    //!
+    static void SetPerfHybridKernelID(
+        MOS_STREAM_HANDLE streamState,
+        uint32_t          kernelID);
+
+    //!
+    //! \brief    Reset performance data buffer ID
+    //! \details  Reset performance data buffer ID
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   void
+    //!
+    static void ResetPerfBufferID(
+        MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief    Increase performance data buffer ID
+    //! \details  Increase performance data buffer ID
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   VOID
+    //!
+    static void IncPerfBufferID(
+        MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief    Determines if the GPU Hung
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   int32_t
+    //!           Return if the GPU Hung
+    //!
+    static int32_t IsGPUHung(
+        MOS_STREAM_HANDLE streamState);
+
 private:
+    //!
+    //! \brief    Init per stream parameters
+    //! \details  Init per stream parameters
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    [in] extraParams
+    //!           Additional parameters needed to init streamstate
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS InitStreamParameters(
+        MOS_STREAM_HANDLE   streamState,
+        EXTRA_PARAMS        extraParams = nullptr);
 
     //!
     //! \brief    Compose Cmd buffer header
@@ -1509,6 +1873,73 @@ private:
     //!           GPU Context instance got by GPU context handle, nullptr if get failed
     //!
     static GpuContextSpecificNext *GetGpuContext(MOS_STREAM_HANDLE streamState, GPU_CONTEXT_HANDLE handle);
+
+#if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
+    //! \brief    Unified dump command buffer initialization
+    //! \details  check if dump command buffer was enabled and create the output directory
+    //! \param    [in/out] streamState
+    //!           Os stream state to init cmd buffer dump
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS DumpCommandBufferInit(
+        MOS_STREAM_HANDLE streamState);
+#endif  // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+
+    enum OS_API_FAIL_TYPE
+    {
+        OS_API_FAIL_TYPE_NONE    = 0,
+        OS_FAIL_ALLOC_GFX_RES    = 1,
+        OS_FAIL_REGISTER_GFX_RES = 1 << 1,
+        OS_API_FAIL_TYPE_MAX     = OS_FAIL_ALLOC_GFX_RES | OS_FAIL_REGISTER_GFX_RES,
+    };
+
+    enum OS_API_FAIL_SIMULATE_MODE
+    {
+        OS_API_FAIL_SIMULATE_MODE_DEFAULT  = 0,
+        OS_API_FAIL_SIMULATE_MODE_RANDOM   = 1,
+        OS_API_FAIL_SIMULATE_MODE_TRAVERSE = 1 << 1,
+        OS_API_FAIL_SIMULATE_MODE_MAX      = OS_API_FAIL_SIMULATE_MODE_RANDOM | OS_API_FAIL_SIMULATE_MODE_TRAVERSE,
+    };
+
+    #define MIN_OS_API_FAIL_FREQ (1)      //max memory allcation fail rate 100%
+    #define MAX_OS_API_FAIL_FREQ (10000)  //min memory allcation fail rate 1/10000
+
+    #define MosOsApiFailSimulationEnabled(OsApiType)                  \
+        (m_mosOsApiFailSimulateType == OsApiType &&                   \
+         m_mosOsApiFailSimulateMode &  OS_API_FAIL_SIMULATE_MODE_MAX)
+
+    //!
+    //! \brief    Init OS API fail simulate flags
+    //! \details  Init OS API fail simulate flags according user feature value
+    //! \param    [in] mosCtx
+    //!           os device ctx handle
+    //! \return   void
+    //!
+    static void MosInitOsApiFailSimulateFlag(MOS_CONTEXT_HANDLE mosCtx);
+
+    //!
+    //! \brief    Deinit OS API fail simulate flags
+    //! \details  Reset OS API fail simulate flags
+    //! \param    none
+    //! \return   void
+    //!
+    static void MosDeinitOsApiFailSimulateFlag();
+
+    static bool MosSimulateOsApiFail(
+        OS_API_FAIL_TYPE type,
+        const char *functionName,
+        const char *filename,
+        int32_t     line);
+
+    static uint32_t m_mosOsApiFailSimulateType;
+    static uint32_t m_mosOsApiFailSimulateMode;
+    static uint32_t m_mosOsApiFailSimulateFreq;
+    static uint32_t m_mosOsApiFailSimulateHint;
+    static uint32_t m_mosOsApiFailSimulateCounter;
+#endif
 };
 
-#endif  // __MOS_INTERFACE_H__
\ No newline at end of file
+#endif  // __MOS_INTERFACE_H__
