@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019, Intel Corporation
+* Copyright (c) 2020-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -163,11 +163,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_AVC_OLD_MODE_COST_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_AVC_FORCE_TO_SKIP_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_AVC_SLIDING_WINDOW_SIZE_ID,
-    __MEDIA_USER_FEATURE_VALUE_VDENC_MB_SLICE_THRESHOLD_ID,
-    __MEDIA_USER_FEATURE_VALUE_VDENC_SLICE_THRESHOLD_TABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VDENC_TAIL_INSERTION_DELAY_COUNT_ID,
-    __MEDIA_USER_FEATURE_VALUE_VDENC_THRESHOLD_I_SLICE_SIZE_MINUS_ID,
-    __MEDIA_USER_FEATURE_VALUE_VDENC_THRESHOLD_P_SLICE_SIZE_MINUS_ID,
     __MEDIA_USER_FEATURE_VALUE_VDENC_CRE_PREFETCH_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VDENC_TLB_PREFETCH_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VDENC_TLB_ALLOCATION_WA_ENABLE_ID,
@@ -225,6 +221,9 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_ENCODE_BRC_SOFTWARE_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_BRC_SOFTWARE_PATH_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_BRC_SOFTWARE_IN_USE_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENCODE_LA_SOFTWARE_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENCODE_LA_SOFTWARE_PATH_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENCODE_LA_SOFTWARE_IN_USE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_ACQP_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_VDENC_VQI_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_FORCE_PAK_PASS_NUM_ID,
@@ -275,6 +274,21 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_VP8_ENCODE_REPAK_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP8_ENCODE_MULTIPASS_BRC_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP8_ENCODE_ADAPTIVE_REPAK_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_DISABLE_HEVC_REALTILE_DECODE_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_REALTILE_MULTI_PHASE_DECODE_ID,
+    __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_USER_PIPE_NUM_ID,
+    __MEDIA_USER_FEATURE_VALUE_APOGEIOS_AV1D_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_DECODE_RT_FRAME_COUNT_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_DECODE_VT_FRAME_COUNT_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_DECODE_SP_FRAME_COUNT_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1BTDLROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1SMVLROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1IPDLROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1DFLYROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1DFLUROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1DFLVROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1CDEFROWSTORECACHE_DISABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_ENABLE_AVP_SCALABILITY_DECODE_ID,
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
     __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_BUFFER_ENABLE_ID,
 #endif  // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
@@ -324,7 +338,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_DECOMPRESS_DECODE_SFC_OUTPUT_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_DEBUG_OUTPUT_DIRECTORY_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_DUMP_OUTPUT_DIRECTORY_ID,
-    __MEDIA_USER_FEATURE_VALUE_CODECHAL_DEBUG_CFG_GENERATION_ID,
+    __MEDIA_USER_FEATURE_VALUE_MEDIA_DEBUG_CFG_GENERATION_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_RDOQ_INTRA_TU_OVERRIDE_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_RDOQ_INTRA_TU_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_RDOQ_INTRA_TU_THRESHOLD_ID,
@@ -333,6 +347,9 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_FAKE_PBFRAME_HEADER_SIZE_ID,
     __MEDIA_USER_FEATURE_VALUE_COMMAND_OVERRIDE_INPUT_FILE_PATH_ID,
     __MEDIA_USER_FEATURE_VALUE_MHW_BASE_VDENC_INTERFACE_ID,
+    __MEDIA_USER_FEATURE_VALUE_FORCE_AV1_TILE_BASED_DECODE_ID,
+    __MEDIA_USER_FEATURE_VALUE_AV1_ERROR_STATUS_ADDR_VALUE_ID,
+    __MEDIA_USER_FEATURE_VALUE_DECODE_HISTOGRAM_DEBUG_ID,
 #endif  // (_DEBUG || _RELEASE_INTERNAL)
     __MEDIA_USER_FEATURE_VALUE_STATUS_REPORTING_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_SPLIT_SCREEN_DEMO_POSITION_ID,
@@ -374,9 +391,9 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MOS_USER_FEATURE_KEY_MESSAGE_MMC_TAG_ID,
     __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_MMC_ID,
     __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MMC_TAG_ID,
-    __MOS_USER_FEATURE_KEY_MESSAGE_BLT_TAG_ID,
-    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_BLT_ID,
-    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_BLT_TAG_ID,
+    __MOS_USER_FEATURE_KEY_MESSAGE_MCPY_TAG_ID,
+    __MOS_USER_FEATURE_KEY_BY_SUB_COMPONENT_MCPY_ID,
+    __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MCPY_TAG_ID,
 #endif  // MOS_MESSAGES_ENABLED
     __MEDIA_USER_FEATURE_VALUE_HEVC_SF_2_DMA_SUBMITS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVCDATROWSTORECACHE_DISABLE_ID,
@@ -408,6 +425,8 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_MDF_FORCE_COHERENT_STATELESSBTI_ID,
     __MEDIA_USER_FEATURE_ENABLE_RENDER_ENGINE_MMC_ID,
     __MEDIA_USER_FEATURE_VALUE_DISABLE_MMC_ID,
+    __MEDIA_USER_FEATURE_VALUE_FORCE_MMC_ON_ID,
+    __MEDIA_USER_FEATURE_MCPY_MODE_ID,
     __VPHAL_VEBOX_OUTPUTPIPE_MODE_ID,
     __VPHAL_VEBOX_FEATURE_INUSE_ID,
     __VPHAL_RNDR_SSD_CONTROL_ID,
@@ -430,6 +449,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __VPHAL_DBG_PARAM_DUMP_START_FRAME_KEY_NAME_ID,
     __VPHAL_DBG_PARAM_DUMP_END_FRAME_KEY_NAME_ID,
     __VPHAL_DBG_DUMP_OUTPUT_DIRECTORY_ID,
+    __VPHAL_DBG_PARA_DUMP_ENABLE_SKUWA_DUMP_ID,
 #endif
     __VPHAL_SET_SINGLE_SLICE_VEBOX_ID,
     __VPHAL_BYPASS_COMPOSITION_ID,
@@ -444,11 +464,18 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __VPHAL_VEBOX_DISABLE_TEMPORAL_DENOISE_FILTER_ID,
     __VPHAL_ENABLE_SUPER_RESOLUTION_ID,
     __VPHAL_SUPER_RESOLUTION_MODE_ID,
+    __VPHAL_SUPER_RESOLUTION_SCENARIO_ID,
+    __VPHAL_FORCE_TO_ENABLE_SR_ID,
     __VPHAL_ENABLE_SUPER_RESOLUTION_EDSR_ID,
     __VPHAL_SUPER_RESOLUTION_EDSR_MODE_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_COMP_8TAP_ADAPTIVE_ENABLE_ID,
     __VPHAL_RNDR_FORCE_VP_DECOMPRESSED_OUTPUT_ID,
+    __VPHAL_ENABLE_1K_1DLUT_ID,
+    __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
+#endif
+#if (_DEBUG || _RELEASE_INTERNAL)
+    __VPHAL_ENABLE_SFC_NV12_P010_LINEAR_OUTPUT_ID,
 #endif
 #if ((_DEBUG || _RELEASE_INTERNAL) && !EMUL)
     __VPHAL_RNDR_VEBOX_MODE_0_ID,
@@ -458,6 +485,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
 #endif
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_ENABLE_COMPUTE_CONTEXT_ID,
+    __VPHAL_DISPLAY_COLORIMETRIC_CONTROL_ID,
 #endif
     __MOS_USER_FEATURE_KEY_VP_CAPS_FF_OVERRIDE_ID,
     __MOS_USER_FEATURE_KEY_XML_AUTOGEN_ID,
@@ -498,7 +526,7 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VPP_APOGEIOS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_SUPER_RESOLUTION_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SUPER_RESOLUTION_MODE_ID,
+    __MEDIA_USER_FEATURE_VALUE_SUPER_RESOLUTION_MODEL_ID,
     __MEDIA_USER_FEATURE_VALUE_EXTERNAL_COPY_SYNC_ID,
     __MEDIA_USER_FEATURE_VALUE_ENABLE_UMD_OCA_ID,
     __MEDIA_USER_FEATURE_VALUE_COUNT_FOR_OCA_BUFFER_LEAKED_ID,
@@ -507,19 +535,35 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_OCA_STATUS_ID,
     __MEDIA_USER_FEATURE_VALUE_OCA_ERROR_HINT_ID,
     __MEDIA_USER_FEATURE_VALUE_IS_INDIRECT_STATE_HEAP_INVALID_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_SW_BACK_ANNOTATION_ID,
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_CC_STITCHING_ID,
+    __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_START_COUNTER_ID,
+    __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_END_COUNTER_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
-    __MEDIA_USER_FEATURE_VALUE_ENABLE_SW_STITCHING_ID,
+    __MEDIA_USER_FEATURE_VALUE_INIT_CP_OUTPUT_SURFACE_ID,
     __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_MODE_ID,
     __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_FREQ_ID,
     __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_HINT_ID,
+    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_TYPE_ID,
+    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_MODE_ID,
+    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_FREQ_ID,
+    __MEDIA_USER_FEATURE_VALUE_OS_API_FAIL_SIMULATE_HINT_ID,
+    __MEDIA_USER_FEATURE_VALUE_MEDIA_TILE_ENCODING_1_DEFAULT_ID,
+    __MEDIA_USER_FEATURE_VALUE_TILE_ENCODING_1_INTERNAL_USED_ID,
+    __MEDIA_USER_FEATURE_VALUE_TILE_ENCODING_3_INTERNAL_USED_ID,
 #endif
     __MEDIA_USER_FEATURE_VALUE_PERF_UTILITY_TOOL_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_PERF_OUTPUT_DIRECTORY_ID,
     __MEDIA_USER_FEATURE_VALUE_APO_MOS_PATH_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_HEVCD_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_APOGEIOS_AVCD_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_APOGEIOS_VP9D_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_RESOURCE_ADDR_DUMP_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_RA_MODE_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_LOCAL_MEMORY_LEVEL_SWITCH_ID,
+    __MEDIA_USER_FEATURE_VALUE_NULLHW_ENABLE_ID,
+    __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_PLATFORM_ID,
+    __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_STEPPING_ID,
+    __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_DEVICE_ID,
+    __MEDIA_USER_FEATURE_VALUE_RENDER_ENABLE_EUFUSION_ID,
     __MOS_USER_FEATURE_KEY_MAX_ID,
 } MOS_USER_FEATURE_VALUE_ID;
 
@@ -739,7 +783,8 @@ typedef struct _MOS_USER_FEATURE_INTERFACE
     MOS_STATUS (*pfnEnableNotification)
     (
         PMOS_USER_FEATURE_INTERFACE   pOsUserFeatureInterface,
-        PMOS_USER_FEATURE_NOTIFY_DATA pNotification);
+        PMOS_USER_FEATURE_NOTIFY_DATA pNotification,
+        MOS_CONTEXT_HANDLE            mosCtx);
 
     MOS_STATUS (*pfnDisableNotification)
     (
