@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2010-2019, Intel Corporation
+* Copyright (c) 2010-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -35,7 +35,6 @@
 #include "renderhal_platform_interface.h"
 #include "vphal_render_hdr_g9_base.h"
 
-static bool sForceSplitFrame = false;
 
 #if (_DEBUG || _RELEASE_INTERNAL)
 static bool sEnableKernelDump = false;
@@ -93,14 +92,14 @@ MOS_STATUS VpHal_HdrInitialize(
     // no matter HW support preemption or not.
     // If it is not set, and HW doesn't support preemption, then the split portions
     // will be calculted based on resolution.
-    if (!sForceSplitFrame)
+    if (!pHdrState->bForceSplitFrame)
     {
         if (MEDIA_IS_SKU(pHdrState->pSkuTable, FtrMediaMidBatchPreempt) ||
             MEDIA_IS_SKU(pHdrState->pSkuTable, FtrMediaThreadGroupLevelPreempt) ||
             MEDIA_IS_SKU(pHdrState->pSkuTable, FtrMediaMidThreadLevelPreempt))
         {
             pHdrState->uiSplitFramePortions = 1;
-            sForceSplitFrame = true;
+            pHdrState->bForceSplitFrame     = true;
         }
     }
 
@@ -299,7 +298,7 @@ MOS_STATUS VpHal_HdrUpdatePerLayerPipelineStates(
         StageEnables.GamutClamp1Enable = ConfigEntry.GamutClamp1;
         StageEnables.GamutClamp2Enable = ConfigEntry.GamutClamp2;
 
-        if (IS_YUV_FORMAT(pSrc->Format) || pSrc->Format == Format_AYUV)
+        if (IS_YUV_FORMAT(pSrc->Format) || IS_ALPHA_YUV_FORMAT(pSrc->Format))
         {
             StageEnables.PriorCSCEnable = 1;
         }
@@ -914,10 +913,11 @@ MOS_STATUS Vphal_HdrSetupComputeWalker(
     VPHAL_RENDER_CHK_NULL(pHdrState->pTargetSurf[0]);
     VPHAL_RENDER_CHK_NULL(pHdrState->pSrcSurf[0]);
     VPHAL_RENDER_CHK_NULL(pRenderData);
-    VPHAL_RENDER_CHK_NULL(pRenderHal);
     VPHAL_RENDER_CHK_NULL(pWalkerParams);
 
     pRenderHal              = pHdrState->pRenderHal;
+    VPHAL_RENDER_CHK_NULL(pRenderHal);
+
     bVerticalPattern        = false;
     AlignedRect             = pHdrState->pTargetSurf[0]->rcDst;
 
