@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2019, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -499,6 +499,10 @@ typedef enum _VEBOX_STAT_QUERY_TYPE
 #define VPHAL_NUM_RGB_CHANNEL                   3
 #define VPHAL_NUM_FRAME_PREVIOUS_CURRENT        2
 
+//No matter how many vebox running, the histogram slice number is always 4.
+//When there is only one VEBOX, 0 is written to the other histogram slices by HW.
+#define VPHAL_VEBOX_HISTOGRAM_SLICES_COUNT      4
+
 //!
 //! \brief Binding Table Index for Secure Block Copy kernel
 //!
@@ -571,6 +575,7 @@ typedef struct _VPHAL_VEBOX_SURFACE_STATE_CMD_PARAMS
     PVPHAL_SURFACE                  pSurfDNOutput;
     PVPHAL_SURFACE                  pSurfSkinScoreOutput;
     bool                            bDIEnable;
+    bool                            b3DlutEnable;
 } VPHAL_VEBOX_SURFACE_STATE_CMD_PARAMS, *PVPHAL_VEBOX_SURFACE_STATE_CMD_PARAMS;
 
 //!
@@ -616,6 +621,8 @@ public:
                                             bChromaDenoise = false;
                                             bOutOfBound    = false;
                                             bVDIWalker     = false;
+                                            b2PassesCSC    = false;
+                                            bBT2020TosRGB  = false;
                                             bIECP          = false;
                                             bColorPipe     = false;
                                             bProcamp       = false;
@@ -643,6 +650,8 @@ public:
                                             iMediaID1      = 0;
                                             // Perf
                                             PerfTag        = VPHAL_NONE;
+                                            // BT202 CSC destination Color Space
+                                            BT2020DstColorSpace = CSpace_Any;
                                             // States
                                             pMediaState        = nullptr;
                                             pVeboxState        = nullptr;
@@ -676,6 +685,7 @@ public:
                                             fScaleY              = 0.0f;
 
                                             bHdr3DLut            = false;
+                                            bUseVEHdrSfc         = false;
                                             uiMaxDisplayLum      = 4000;
                                             uiMaxContentLevelLum = 1000;
                                             hdrMode              = VPHAL_HDR_MODE_NONE;
@@ -702,7 +712,8 @@ public:
     bool                                bChromaDenoise;
     bool                                bOutOfBound;
     bool                                bVDIWalker;
-
+    bool                                b2PassesCSC;
+    bool                                bBT2020TosRGB;
     bool                                bIECP;
     bool                                bColorPipe;
     bool                                bProcamp;
@@ -735,6 +746,9 @@ public:
     // Perf
     VPHAL_PERFTAG                       PerfTag;
 
+    // BT202 CSC destination Color Space
+    VPHAL_CSPACE                        BT2020DstColorSpace;
+
     // States
     PRENDERHAL_MEDIA_STATE              pMediaState;
     PMHW_VEBOX_HEAP_STATE               pVeboxState;
@@ -778,6 +792,7 @@ public:
     float                               fScaleY;                                //!< Y Scaling ratio
 
     bool                                bHdr3DLut;                              //!< Enable 3DLut to process HDR
+    bool                                bUseVEHdrSfc;                              //!< Use SFC to perform CSC/Scaling for HDR content
     uint32_t                            uiMaxDisplayLum;                        //!< Maximum Display Luminance
     uint32_t                            uiMaxContentLevelLum;                   //!< Maximum Content Level Luminance
     VPHAL_HDR_MODE                      hdrMode;
@@ -899,7 +914,7 @@ public:
     PMHW_SFC_INTERFACE              m_pSfcInterface;                              //!< Pointer to SFC Structure Interface
     Kdll_State                      *m_pKernelDllState;                           //!< Kernel DLL state
     VpKernelID                      m_currKernelId;                               //!< Kernel ID
-
+    VPHAL_SURFACE                   m_BT2020CSCTempSurface;                       //!< BT2020 temp surface for Vebox Gen9+
     VphalSfcState                   *m_sfcPipeState;                              //!< SFC state
 
     // Execution state
@@ -1328,8 +1343,6 @@ protected:
     //!           reference to Cmd buffer control struct
     //! \param    [out] GenericPrologParams
     //!           Generic prolog params struct to be set
-    //! \param    [out] GpuStatusBuffer
-    //!           GpuStatusBuffer resource to be set
     //! \param    [out] iRemaining
     //!           integer showing initial cmd buffer usage
     //! \return   MOS_STATUS
@@ -1338,7 +1351,6 @@ protected:
     virtual MOS_STATUS VeboxSendVeboxCmd_Prepare(
         MOS_COMMAND_BUFFER                      &CmdBuffer,
         RENDERHAL_GENERIC_PROLOG_PARAMS         &GenericPrologParams,
-        MOS_RESOURCE                            &GpuStatusBuffer,
         int32_t                                 &iRemaining);
 
     //!
@@ -1351,8 +1363,9 @@ protected:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS VeboxIsCmdParamsValid(
-        const MHW_VEBOX_STATE_CMD_PARAMS        &VeboxStateCmdParams,
-        const MHW_VEBOX_DI_IECP_CMD_PARAMS      &VeboxDiIecpCmdParams);
+        const MHW_VEBOX_STATE_CMD_PARAMS            &VeboxStateCmdParams,
+        const MHW_VEBOX_DI_IECP_CMD_PARAMS          &VeboxDiIecpCmdParams,
+        const VPHAL_VEBOX_SURFACE_STATE_CMD_PARAMS  &VeboxSurfaceStateCmdParams);
 
     //!
     //! \brief    Render the Vebox Cmd buffer for VeboxSendVeboxCmd
@@ -1872,6 +1885,13 @@ protected:
     //!
     bool IS_OUTPUT_PIPE_VEBOX_FEASIBLE(PVPHAL_VEBOX_STATE _pVeboxState, PCVPHAL_RENDER_PARAMS _pcRenderParams, PVPHAL_SURFACE _pSrcSurface);
 
+    //!
+    //! \brief    Check for DN only case
+    //! \details  Check for DN only case
+    //! \return   bool
+    //!           Return true if DN only case, otherwise not
+    //!
+    virtual bool            IsDNOnly() = 0;
 };
 
 //!
