@@ -87,7 +87,7 @@ extern "C" {
 #endif // __cplusplus
 
 typedef enum _MOS_FORMAT            Kdll_Format;
-typedef enum _VPHAL_CSPACE          Kdll_CSpace;
+typedef enum _MEDIA_CSPACE          Kdll_CSpace;
 
 // Layer definition
 typedef enum _KDLL_LAYER
@@ -177,6 +177,7 @@ typedef enum tagKdll_Processing
     Process_Source      = -1,     // Current source processing
     Process_Any         =  0,
     Process_Composite   ,         // Composite 2 layers
+    Process_XORComposite,         // XOR mono composite.
     Process_PBlend      ,         // Partial Blend 2 layers  - 8-bits alpha
     Process_CBlend      ,         // Constant Blend 2 layers - 8-bits alpha
     Process_SBlend      ,         // Source Blend 2 layers   - 8-bits alpha
