@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2012-2018, Intel Corporation
+* Copyright (c) 2012-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -648,6 +648,7 @@ MOS_STATUS CodechalDecodeVp9G11 :: DecodePrimitiveLevel()
             m_scalabilityState,
             &scdryCmdBuffer,
             &cmdBufferInUse));
+        CodecHalDecodeScalability_DecPhaseToSubmissionType(m_scalabilityState,cmdBufferInUse);
     }
 
     // store CS ENGINE ID register
@@ -855,22 +856,14 @@ MOS_STATUS CodechalDecodeVp9G11 :: DecodePrimitiveLevel()
     {
         submitCommand = CodecHalDecodeScalabilityIsToSubmitCmdBuffer(m_scalabilityState);
 
-        if (m_osInterface->osCpInterface->IsHMEnabled())
-        {
-            HalOcaInterface::DumpCpParam(scdryCmdBuffer, *m_osInterface->pOsContext, m_osInterface->osCpInterface->GetOcaDumper());
-        }
-        HalOcaInterface::On1stLevelBBEnd(scdryCmdBuffer, *m_osInterface->pOsContext);
+        HalOcaInterface::On1stLevelBBEnd(scdryCmdBuffer, *m_osInterface);
     }
     else
     {
-        if (m_osInterface->osCpInterface->IsHMEnabled())
-        {
-            HalOcaInterface::DumpCpParam(primCmdBuffer, *m_osInterface->pOsContext, m_osInterface->osCpInterface->GetOcaDumper());
-        }
-        HalOcaInterface::On1stLevelBBEnd(primCmdBuffer, *m_osInterface->pOsContext);
+        HalOcaInterface::On1stLevelBBEnd(primCmdBuffer, *m_osInterface);
     }
 
-    if (submitCommand || m_osInterface->phasedSubmission)
+    if (submitCommand)
     {
         uint32_t renderingFlags = m_videoContextUsesNullHw;
 
@@ -884,7 +877,6 @@ MOS_STATUS CodechalDecodeVp9G11 :: DecodePrimitiveLevel()
             && MOS_VE_SUPPORTED(m_osInterface)
             && CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState))
         {
-            CodecHalDecodeScalability_DecPhaseToSubmissionType(m_scalabilityState,cmdBufferInUse);
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
                 m_osInterface,
                 cmdBufferInUse,
@@ -1037,65 +1029,3 @@ MOS_STATUS CodechalDecodeVp9G11 :: AllocateStandard (
 
     return eStatus;
 }
-
-MOS_STATUS CodechalDecodeVp9G11::SetCencBatchBuffer(
-    PMOS_COMMAND_BUFFER cmdBuffer)
-{
-    CODECHAL_DECODE_CHK_NULL_RETURN(cmdBuffer);
-
-    MHW_BATCH_BUFFER        batchBuffer;
-    MOS_ZeroMemory(&batchBuffer, sizeof(MHW_BATCH_BUFFER));
-    MOS_RESOURCE *resHeap = nullptr;
-    CODECHAL_DECODE_CHK_NULL_RETURN(resHeap = m_cencBuf->secondLvlBbBlock->GetResource());
-
-    batchBuffer.OsResource   = *resHeap;
-    batchBuffer.dwOffset     = m_cencBuf->secondLvlBbBlock->GetOffset() + VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.iSize        = m_cencBuf->secondLvlBbBlock->GetSize() - VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.bSecondLevel = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-    batchBuffer.iLastCurrent = batchBuffer.iSize;
-#endif  // (_DEBUG || _RELEASE_INTERNAL)
-
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferStartCmd(
-        cmdBuffer,
-        &batchBuffer));
-
-    CODECHAL_DEBUG_TOOL(
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->Dump2ndLvlBatch(
-            &batchBuffer,
-            CODECHAL_NUM_MEDIA_STATES,
-            "_2ndLvlBatch_Pic_Cmd"));)
-
-    // Primitive level cmds should not be in BE phases
-    if (!(CodecHalDecodeScalabilityIsBEPhase(m_scalabilityState) && MOS_VE_SUPPORTED(m_osInterface)))
-    {
-        batchBuffer.dwOffset = m_cencBuf->secondLvlBbBlock->GetOffset();
-        batchBuffer.iSize = VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-        batchBuffer.bSecondLevel = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-        batchBuffer.iLastCurrent = batchBuffer.iSize;
-#endif  // (_DEBUG || _RELEASE_INTERNAL)
-
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferStartCmd(
-            cmdBuffer,
-            &batchBuffer));
-
-        CODECHAL_DEBUG_TOOL(
-            CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->Dump2ndLvlBatch(
-                &batchBuffer,
-                CODECHAL_NUM_MEDIA_STATES,
-                "_2ndLvlBatch_Primitive_Cmd"));)
-    }
-
-    // Update GlobalCmdBufId
-    MHW_MI_STORE_DATA_PARAMS miStoreDataParams;
-    MOS_ZeroMemory(&miStoreDataParams, sizeof(miStoreDataParams));
-    miStoreDataParams.pOsResource = m_cencBuf->resTracker;
-    miStoreDataParams.dwValue     = m_cencBuf->trackerId;
-    CODECHAL_DECODE_VERBOSEMESSAGE("dwCmdBufId = %d", miStoreDataParams.dwValue);
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiStoreDataImmCmd(
-        cmdBuffer,
-        &miStoreDataParams));
-    return MOS_STATUS_SUCCESS;
-}
-
