@@ -258,7 +258,8 @@ public:
         MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_ROWSTORE_CACHE_DISABLE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            this->m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
         this->m_rowstoreCachingSupported = userFeatureData.i32Data ? false : true;
 
@@ -269,7 +270,8 @@ public:
             MOS_UserFeature_ReadValue_ID(
                 nullptr,
                 __MEDIA_USER_FEATURE_VALUE_VDENCROWSTORECACHE_DISABLE_ID,
-                &userFeatureData);
+                &userFeatureData,
+                this->m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
             this->m_vdencRowStoreCache.bSupported = userFeatureData.i32Data ? false : true;
         }
@@ -1393,9 +1395,9 @@ public:
 
             for (uint8_t i = 0; i < avcPicParams->NumROI; i++)
             {
-                int8_t dQpRoi = avcPicParams->ROI[i].PriorityLevelOrDQp;
+                int8_t dQpRoi = avcPicParams->ROIDistinctDeltaQp[i];
 
-                // clip delta qp roi to VDEnc supported range 
+                // clip delta qp roi to VDEnc supported range
                 priorityLevelOrDQp[i] = (char)CodecHal_Clip3(
                     ENCODE_VDENC_AVC_MIN_ROI_DELTA_QP_G9, ENCODE_VDENC_AVC_MAX_ROI_DELTA_QP_G9, dQpRoi);
             }
@@ -1420,11 +1422,20 @@ public:
             cmd.DW31.BestdistortionQpAdjustmentForZone3 = 3;
         }
 
-        if (params->bVdencBRCEnabled && avcPicParams->NumDirtyROI && params->bVdencStreamInEnabled)
+        if (avcPicParams->EnableRollingIntraRefresh == ROLLING_I_DISABLED && params->bVdencStreamInEnabled &&
+            (avcPicParams->NumDirtyROI && params->bVdencBRCEnabled || avcPicParams->NumROI && avcPicParams->bNativeROI ||
+                (avcPicParams->TargetFrameSize > 0 && !avcSeqParams->LookaheadDepth)))  // TCBRC (for AdaptiveRegionBoost)
         {
             cmd.DW34.RoiEnable = true;
         }
 
+        // non-native ROI in ForceQP mode (VDEnc StreamIn filled by HuC in BRC mode and by UMD driver in CQP) or MBQP
+        if (avcPicParams->EnableRollingIntraRefresh == ROLLING_I_DISABLED && params->bVdencStreamInEnabled &&
+            avcPicParams->NumROI && !avcPicParams->bNativeROI)
+        {
+            cmd.DW34.MbLevelQpEnable = true;
+        }
+
         if (params->bVdencStreamInEnabled)
         {
             cmd.DW34.FwdPredictor0MvEnable = 1;
