@@ -86,6 +86,17 @@ CodechalDecodeVp9G12::CodechalDecodeVp9G12(
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
     Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
+    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+    MOS_UserFeature_ReadValue_ID(
+        nullptr,
+        __MEDIA_USER_FEATURE_VALUE_DECODE_HISTOGRAM_DEBUG_ID,
+        &userFeatureData,
+        m_osInterface->pOsContext);
+    m_histogramDebug = userFeatureData.u32Data ? true : false;
+#endif
 }
 
 MOS_STATUS CodechalDecodeVp9G12::SetGpuCtxCreatOption(
@@ -172,8 +183,6 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateResourcesVariableSizes()
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
-    CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeVp9 :: AllocateResourcesVariableSizes());
-
 #ifdef _MMC_SUPPORTED
     // To WA invalid aux data caused HW issue when MMC on
     if (m_mmc && m_mmc->IsMmcEnabled() && MEDIA_IS_WA(m_waTable, Wa_1408785368) &&
@@ -228,6 +237,8 @@ MOS_STATUS CodechalDecodeVp9G12 :: AllocateResourcesVariableSizes()
         m_frameSizeMaxAlloced = frameSizeMax;
     }
 
+    CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeVp9 ::AllocateResourcesVariableSizes());
+
     return eStatus;
 }
 
@@ -237,7 +248,7 @@ MOS_STATUS CodechalDecodeVp9G12::InitSfcState()
 #ifdef _DECODE_PROCESSING_SUPPORTED
     // Check if SFC can be supported
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_sfcState->CheckAndInitialize(
-        (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams, 
+        (DecodeProcessingParams *)m_decodeParams.m_procParams, 
         m_vp9PicParams, 
         m_scalabilityState));
 #endif
@@ -324,8 +335,21 @@ MOS_STATUS CodechalDecodeVp9G12 :: InitializeDecodeMode ()
         initParams.u32PicHeightInPixel = m_usFrameHeightAlignedMinBlk;
         initParams.format              = m_decodeParams.m_destSurface->Format;
         initParams.gpuCtxInUse         = GetVideoContext();
-        initParams.usingSecureDecode   = m_secureDecoder ? m_secureDecoder->IsSecureDecodeEnabled() : false;
-
+        initParams.usingSecureDecode   = (m_secureDecoder != nullptr);
+        if (m_decodeHistogram == nullptr)
+        {
+            initParams.usingHistogram = false;
+#if (_DEBUG || _RELEASE_INTERNAL)
+            if (m_histogramDebug)
+            {
+                initParams.usingHistogram = true;
+            }
+#endif
+        }
+        else
+        {
+            initParams.usingHistogram = true;
+        }
         CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeScalability_InitScalableParams_G12(
             m_scalabilityState,
             &initParams,
@@ -552,11 +576,29 @@ MOS_STATUS CodechalDecodeVp9G12::AddPicStateMhwCmds(
     if (m_vp9PicParams->PicFlags.fields.frame_type == CODEC_VP9_INTER_FRAME &&
         !m_vp9PicParams->PicFlags.fields.intra_only)
     {
+#ifdef _MMC_SUPPORTED
+        //Get each reference surface state and be recorded by skipMask if current surface state is mmc disabled
+        uint8_t skipMask = 0xf8;
         for (uint8_t i = 1; i < 4; i++)
         {
-#ifdef _MMC_SUPPORTED
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetSurfaceState(m_picMhwParams.SurfaceParams[i]));
+            if (m_picMhwParams.SurfaceParams[i]->mmcState == MOS_MEMCOMP_DISABLED)
+            {
+                skipMask |= (1 << (i - 1));
+            }
+        }
+        CODECHAL_DECODE_NORMALMESSAGE("MMC skip masK is %d\n", skipMask);
+        for (uint8_t i = 1; i < 4; i++)
+        {
+            //Set each ref surface state as MOS_MEMCOMP_MC to satisfy MmcEnable in AddHcpSurfaceCmd
+            //Because each ref surface state should be programmed as the same
+            //The actual mmc state is recorded by skipMask and set each ref surface too
+            m_picMhwParams.SurfaceParams[i]->mmcState    = MOS_MEMCOMP_MC;
+            m_picMhwParams.SurfaceParams[i]->mmcSkipMask = skipMask;
+        }
 #endif
+        for (uint8_t i = 1; i < 4; i++)
+        {
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_hcpInterface->AddHcpSurfaceCmd(
                 cmdBuffer,
                 m_picMhwParams.SurfaceParams[i]));
@@ -625,7 +667,7 @@ MOS_STATUS CodechalDecodeVp9G12::SetFrameStates()
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(AllocateHistogramSurface());
 
-        ((CODECHAL_DECODE_PROCESSING_PARAMS*)m_decodeParams.m_procParams)->pHistogramSurface = m_histogramSurface;
+        ((DecodeProcessingParams *)m_decodeParams.m_procParams)->m_histogramSurface = m_histogramSurface;
 
         if(m_decodeHistogram)
             m_decodeHistogram->SetSrcHistogramSurface(m_histogramSurface);
@@ -845,6 +887,7 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
             m_scalabilityState,
             &scdryCmdBuffer,
             &cmdBufferInUse));
+        CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(m_scalabilityState,cmdBufferInUse);
     }
 
     // store CS ENGINE ID register
@@ -1017,6 +1060,14 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
 
     CODECHAL_DEBUG_TOOL(
 
+        if (m_histogramDebug && m_histogramSurface) {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->DumpBuffer(
+                &m_histogramSurface->OsResource,
+                CodechalDbgAttr::attrSfcHistogram,
+                "_DEC",
+                256 * 4));
+        }
+
         if (CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState)) {
             CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
                 this,
@@ -1074,7 +1125,7 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
         HalOcaInterface::On1stLevelBBEnd(primCmdBuffer, *m_osInterface);
     }
 
-    if (submitCommand || m_osInterface->phasedSubmission)
+    if (submitCommand)
     {
         uint32_t renderingFlags = m_videoContextUsesNullHw;
 
@@ -1088,7 +1139,6 @@ MOS_STATUS CodechalDecodeVp9G12 :: DecodePrimitiveLevel()
             && MOS_VE_SUPPORTED(m_osInterface)
             && CodecHalDecodeScalabilityIsScalableMode(m_scalabilityState))
         {
-            CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(m_scalabilityState,cmdBufferInUse);
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
                 m_osInterface,
                 cmdBufferInUse,
