@@ -49,6 +49,9 @@ MOS_STATUS CodechalEncodeCscDsG12::AllocateSurfaceCsc()
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodechalEncodeCscDs::AllocateSurfaceCsc());
 
+    MEDIA_WA_TABLE* waTable = m_osInterface->pfnGetWaTable(m_osInterface);
+    uint32_t memType = (MEDIA_IS_WA(waTable, WaForceAllocateLML4)) ? MOS_MEMPOOL_DEVICEMEMORY : 0;
+
     // allocate the MbStats surface
     if (Mos_ResourceIsNull(&m_resMbStatsBuffer))
     {
@@ -62,6 +65,7 @@ MOS_STATUS CodechalEncodeCscDsG12::AllocateSurfaceCsc()
         allocParamsForBufferLinear.dwBytes = m_hwInterface->m_avcMbStatBufferSize =
             MOS_ALIGN_CEIL((alignedWidth * alignedHeight << 6) , 1024);
         allocParamsForBufferLinear.pBufName = "MB Statistics Buffer";
+        allocParamsForBufferLinear.dwMemType = memType;
 
         CODECHAL_ENCODE_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
             m_osInterface,
@@ -96,7 +100,8 @@ MOS_STATUS CodechalEncodeCscDsG12::CheckRawColorFormat(MOS_FORMAT format, MOS_TI
         m_cscUsingSfc = IsSfcEnabled() ? 1 : 0;
         m_cscRequireColor = 1;
         //Use EU for better performance in big resolution cases
-        if (m_cscRawSurfWidth * m_cscRawSurfHeight > 1920 * 1088)
+        if (m_cscRawSurfWidth * m_cscRawSurfHeight > 1920 * 1088
+            && !MEDIA_IS_WA(m_hwInterface->GetWaTable(), Wa_1409932735))
         {
             m_cscUsingSfc = 0;
         }
@@ -135,25 +140,26 @@ MOS_STATUS CodechalEncodeCscDsG12::CheckRawColorFormat(MOS_FORMAT format, MOS_TI
         m_cscRequireConvTo8bPlanar = 1;
         break;
     case Format_AYUV:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorAYUV;
+            m_cscRequireColor = 1;
             break;
         }
     case Format_R10G10B10A2:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorARGB10;
             break;
         }
     case Format_B10G10R10A2:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorABGR10;
             break;
         }
     case Format_Y410:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorY410;
             break;
@@ -290,7 +296,7 @@ MOS_STATUS CodechalEncodeCscDsG12::SetKernelParamsCsc(KernelParams* params)
     }
     else
     {
-        // do 16x/32x downscaling      
+        // do 16x/32x downscaling
         m_curbeParams.bConvertFlag = false;
         mbStatsSurface = nullptr;
 
@@ -301,7 +307,7 @@ MOS_STATUS CodechalEncodeCscDsG12::SetKernelParamsCsc(KernelParams* params)
             m_curbeParams.downscaleStage = dsStage16x;
             inputFrameWidth = m_encoder->m_downscaledWidth4x << 2;
             inputFrameHeight = m_encoder->m_downscaledHeight4x << 2;
-            
+
             inputSurface = m_encoder->m_trackedBuf->Get4xDsSurface(CODEC_CURR_TRACKED_BUFFER);
             output4xDsSurface = m_encoder->m_trackedBuf->Get16xDsSurface(CODEC_CURR_TRACKED_BUFFER);
             output2xDsSurface = nullptr;
@@ -326,7 +332,12 @@ MOS_STATUS CodechalEncodeCscDsG12::SetKernelParamsCsc(KernelParams* params)
 
     // setup Curbe
     m_curbeParams.dwInputPictureWidth = inputFrameWidth;
-    m_curbeParams.dwInputPictureHeight = inputFrameHeight;  
+    m_curbeParams.dwInputPictureHeight = inputFrameHeight;
+    m_curbeParams.bFlatnessCheckEnabled = m_flatnessCheckEnabled;
+    m_curbeParams.bMBVarianceOutputEnabled = m_mbStatsEnabled;
+    m_curbeParams.bMBPixelAverageOutputEnabled = m_mbStatsEnabled;
+    m_curbeParams.bCscOrCopyOnly = !m_scalingEnabled || params->cscOrCopyOnly;
+    m_curbeParams.inputColorSpace = params->inputColorSpace;
 
     // setup surface states
     m_surfaceParamsCsc.psInputSurface = inputSurface;
@@ -382,13 +393,6 @@ MOS_STATUS CodechalEncodeCscDsG12::SetCurbeCsc()
     curbe.DW2_OriginalPicWidthInSamples = m_curbeParams.dwInputPictureWidth;
     curbe.DW2_OriginalPicHeightInSamples = m_curbeParams.dwInputPictureHeight;
 
-    // when the input surface is NV12 tiled format and not aligned with 4 bytes,
-    // need kernel to do the padding copy with force to linear format, it's
-    // transparent to kernel and hw can handle it
-    if (m_colorRawSurface == cscColorNv12TileY && m_cscFlag == 1)
-        curbe.DW1_PictureFormat = cscColorNv12Linear;
-
-
     // RGB->YUV CSC coefficients
     if (m_curbeParams.inputColorSpace == ECOLORSPACE_P709)
     {
@@ -508,17 +512,13 @@ MOS_STATUS CodechalEncodeCscDsG12::SendSurfaceCsc(PMOS_COMMAND_BUFFER cmdBuffer)
                                                    cscColorNv12Linear == m_colorRawSurface);
     }
 
-    if(m_encoder->m_vdencEnabled && CODECHAL_HEVC == m_standard)
+    if (m_encoder->m_vdencEnabled && (CODECHAL_HEVC == m_standard || CODECHAL_AVC == m_standard))
     {
         surfaceParams.bCheckCSC8Format= true;
     }
 
-    // when input surface is NV12 tiled and not aligned by 4 bytes, need kernel to do the
-    // padding copy by forcing to linear format and set the HeightInUse as Linear format
-    // kernel will use this info to calucate UV offset
     surfaceParams.psSurface = m_surfaceParamsCsc.psInputSurface;
-    if (cscColorNv12Linear == m_colorRawSurface ||
-        (cscColorNv12TileY == m_colorRawSurface && m_cscFlag == 1))
+    if (cscColorNv12Linear == m_colorRawSurface)
     {
         surfaceParams.dwHeightInUse = (surfaceParams.psSurface->dwHeight * 3) / 2;
     }
@@ -850,6 +850,16 @@ MOS_STATUS CodechalEncodeCscDsG12::InitSfcState()
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS CodechalEncodeCscDsG12::CheckRawSurfaceAlignment(MOS_SURFACE surface)
+{
+    if (m_cscEnableCopy && (surface.dwWidth % m_rawSurfAlignment || surface.dwHeight % m_rawSurfAlignment) &&
+        m_colorRawSurface != cscColorNv12TileY)
+    {
+        m_cscRequireCopy = 1;
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
 CodechalEncodeCscDsG12::CodechalEncodeCscDsG12(CodechalEncoderState* encoder)
     : CodechalEncodeCscDs(encoder)
 {
