@@ -40,6 +40,7 @@
 #define  VDBOX_HUC_PAK_INTEGRATION_KERNEL_DESCRIPTOR 15
 #define  BRC_IMG_STATE_SIZE_PER_PASS_G12             192
 #define  HEVC_BRC_LONG_TERM_REFRENCE_FLAG            0x8000
+#define  MAX_CONCURRENT_GROUP                        4
 
 //!
 //! \struct HucPakStitchDmemEncG12
@@ -817,9 +818,11 @@ public:
             uint32_t   R1_4;
             struct
             {
-                uint32_t FrameQP : 7;
-                uint32_t FrameQPSign : 1;
-                uint32_t ConcurrentGroupNum : 8;
+                uint32_t FrameQP              : 7;
+                uint32_t FrameQPSign          : 1;
+                uint32_t ConcurrentGroupNum   : 4;
+                uint32_t MBZ_Reserved         : 3;
+                uint32_t WaveFrontSplitVQFix  : 1;
                 uint32_t NumofUnitInWaveFront : 16;
             };
         };
@@ -1129,9 +1132,9 @@ public:
     static const uint8_t  m_sumMVThreshold = 16;
     uint8_t m_hevcThreadTaskDataNum = 2;
     uint32_t m_maxWavefrontsforTU1 = 2;
-    uint32_t m_maxWavefrontsforTU4 = 4;
+    uint32_t m_maxWavefrontsforTU4 = 2;
     static const uint32_t m_loadBalanceSize = (256 * 16);               //!< Load balance size used for load balance array.
-    uint32_t m_alignReconFactor = 1;
+    double m_alignReconFactor = 1.0;
     uint32_t m_threadMapSize = (256 * 16);                              //!< Thread map surface size will be updated depending on various gen
 
     static const uint8_t m_meMethod[NUM_TARGET_USAGE_MODES];             //!< ME method
@@ -1186,7 +1189,7 @@ public:
     uint32_t      m_lambdaRD = 0;              //!< Lambda value to multiply the RD  costs
 
     uint8_t                 m_numberEncKernelSubThread = m_hevcThreadTaskDataNum;
-    uint32_t                m_numberConcurrentGroup = 4;    // can dividie one picture into several groups
+    uint32_t                m_numberConcurrentGroup = MAX_CONCURRENT_GROUP;    // can dividie one picture into several groups
     uint32_t                m_numWavefrontInOneRegion = 0;
     uint16_t                m_lastPictureCodingType = I_TYPE;
     uint8_t*                m_swScoreboard = nullptr;
@@ -1200,6 +1203,7 @@ public:
     uint32_t                m_threadTaskBufferSize = 0;
     uint32_t                m_threadTaskBufferOffset = 0;
     bool                    m_initEncConstTable = true;
+    bool                    m_initEncLoadBalence = true;
     bool                    m_enableBrcLTR = 1;  //!< flag to enable long term reference BRC feature.
     bool                    m_isFrameLTR = 0;    //!<flag to check if current frame is set as long term reference
     uint32_t                m_ltrInterval = 0;   //!< long term reference interval
@@ -1765,66 +1769,6 @@ public:
      //!
     MOS_STATUS GenerateSkipFrameMbCodeSurface(SkipFrameInfo &skipframeInfo);
 
-    //!
-    //! \brief    Convert from Y210 to Y210V format
-    //!
-    //! \param    [in]  source
-    //!           Source surface
-    //! \param    [out]  target
-    //!           Destination surface
-    //!
-    //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason
-    //!
-    MOS_STATUS ConvertY210ToY210V(
-        PMOS_SURFACE source,
-        PMOS_SURFACE target);
-
-    //!
-    //! \brief    Convert from P010 to P010V format
-    //!
-    //! \param    [in]  source
-    //!           Source surface
-    //! \param    [out]  target
-    //!           Destination surface
-    //!
-    //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason
-    //!
-    MOS_STATUS ConvertP010ToP010V(
-        PMOS_SURFACE source,
-        PMOS_SURFACE target);
-
-    //!
-    //! \brief    Convert from YUY2 to YUY2V format
-    //!
-    //! \param    [in]  source
-    //!           Source surface
-    //! \param    [out]  target
-    //!           Destination surface
-    //!
-    //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason
-    //!
-    MOS_STATUS ConvertYUY2ToYUY2V(
-        PMOS_SURFACE source,
-        PMOS_SURFACE target);
-
-    //!
-    //! \brief    Downscale input by 2X
-    //!
-    //! \param    [in]  source
-    //!           Source surface
-    //! \param    [out]  target
-    //!           Destination surface
-    //!
-    //! \return   MOS_STATUS
-    //!           MOS_STATUS_SUCCESS if success, else fail reason
-    //!
-    MOS_STATUS DownScaling2X(
-        PMOS_SURFACE source,
-        PMOS_SURFACE target);
-
     //!
     //! \brief    Load cost table
     //!
@@ -2084,12 +2028,20 @@ public:
     MOS_STATUS HucPakIntegrate(
         PMOS_COMMAND_BUFFER cmdBuffer);
 
+    //!
+    //! \brief    Resize buffers due to resoluton change.
+    //! \details  Resize buffers due to resoluton change.
+    //!
+    //! \return   void
+    //!
+    virtual void ResizeOnResChange() override;
+
     MOS_STATUS InitMmcState() override;
 
     MOS_STATUS UpdateCmdBufAttribute(
         PMOS_COMMAND_BUFFER cmdBuffer,
         bool                renderEngineInUse) override;
-        
+
     //!
     //! \brief    Configue stitch data buffer as Huc Pak Integration input
     //!
@@ -2100,8 +2052,8 @@ public:
 
     MOS_STATUS AddMediaVfeCmd(
         PMOS_COMMAND_BUFFER cmdBuffer,
-        SendKernelCmdsParams *params) override;    
-    
+        SendKernelCmdsParams *params) override;
+
     //!
     //! \brief    allocate resources with sizes varying from frame to frame
     //! \return   MOS_STATUS
