@@ -104,7 +104,7 @@ struct CODECHAL_VDENC_HEVC_HUC_BRC_INIT_DMEM_G12
     uint32_t    SlidingWindow_Size_U32;                 // 30
 
     uint8_t     SLIDINGWINDOW_MaxRateRatio;
-    uint8_t     RSVD2;
+    uint8_t     LookaheadDepth_U8;
     int8_t      CbQPOffset;
     int8_t      CrQPOffset;
 
@@ -202,7 +202,9 @@ struct CODECHAL_VDENC_HEVC_HUC_BRC_UPDATE_DMEM_G12
     uint32_t    SliceHeaderSize;
     uint8_t     IsLongTermRef;
 
-    uint8_t     RSVD[3];                           // 64 bytes aligned
+    uint8_t    EnableMotionAdaptive;
+    uint8_t    EnableLookAhead;
+    uint8_t    UPD_CQMEnabled_U8; // 0 indicates CQM is disabled for current frame; otherwise CQM is enabled
 };
 C_ASSERT(192 == sizeof(CODECHAL_VDENC_HEVC_HUC_BRC_UPDATE_DMEM_G12));
 
@@ -280,6 +282,9 @@ struct CODECHAL_VDENC_HEVC_HUC_BRC_CONSTANT_DATA_G12
         uint16_t    WeightTable_EndInBits;                  // number of bits from beginning of slice header for weight table last bit, 0xffff means not awailable
     } Slice[CODECHAL_VDENC_HEVC_MAX_SLICE_NUM];
     uint8_t     PenaltyForIntraNonDC32x32PredMode[52];
+    uint32_t   UPD_TR_TargetSize_U32; //TR_BRC
+    uint32_t   UPD_LA_TargetFulness_U32; //LOOK_AHEAD
+    uint8_t    UPD_deltaQP;
 };
 
 using PCODECHAL_VDENC_HEVC_HUC_BRC_CONSTANT_DATA_G12 = CODECHAL_VDENC_HEVC_HUC_BRC_CONSTANT_DATA_G12*;
@@ -520,6 +525,13 @@ enum CODECHAL_BINDING_TABLE_OFFSET_HEVC_VP9_VDENC_KERNEL_G12
     CODECHAL_VDENC_HME_END_G12,
 };
 
+enum SCC_IBC_CONTROL_IBC_G12
+{
+    SCC_IBC_CONTROL_IBC_DISABLED_G12 = 0x0,
+    SCC_IBC_CONTROL_IBC_ONLY_LBC_G12 = 0x1,
+    SCC_IBC_CONTROL_IBC_ENABLED_TBCLBC_G12 = 0x3,
+};
+
 struct MEDIA_OBJECT_HEVC_VP9_VDENC_ME_CURBE_G12
 {
     // DW0
@@ -2100,6 +2112,11 @@ public:
     static const uint32_t       m_brcConstantSurfaceHeight = 35;       //!< BRC constant surface height
     static const uint32_t       m_brcHistoryBufSize = 2304;            //!< BRC history buffer size
     static const uint32_t       m_bframeMeBidirectionalWeight = 32;    //!< B frame bidirection weight
+    uint32_t                    m_prevQpModulationStrength = 0;
+    bool                        m_initDeltaQP = true;
+    uint32_t                    m_prevVdencReadBatchBufferSize = 0;
+    uint32_t                    m_numNAL = 0;
+    uint32_t                    m_overallNALPayload = 0;
 
     // HuC tables.
     // These Values are diff for each Gen
@@ -2171,6 +2188,7 @@ public:
 
     // scalability
     unsigned char                               m_numPipe            = 1;         //!< Number of pipes
+    unsigned char                               m_numPipePre         = 1;         //!< Number of pipes of previous frame
     unsigned char                               m_numPassesInOnePipe = 1;         //!< Number of PAK passes in one pipe
     CODECHAL_ENCODE_BUFFER                      m_resPakSliceLevelStreamoutData;  //!< Surface for slice level stream out data from PAK
     CODECHAL_HEVC_VIRTUAL_ENGINE_OVERRIDE       m_kmdVeOveride;                   //!< KMD override virtual engine index
@@ -2200,7 +2218,7 @@ public:
     CODECHAL_ENCODE_BUFFER m_resBrcSemaphoreMem[CODECHAL_HEVC_MAX_NUM_HCP_PIPE];                                                                       //!< BRC HW semaphore
     CODECHAL_ENCODE_BUFFER m_resVdBoxSemaphoreMem[CODECHAL_HEVC_MAX_NUM_HCP_PIPE];                                                                     //!< VDBox HW semaphore
     CODECHAL_ENCODE_BUFFER m_resBrcPakSemaphoreMem;                                                                                                    //!< BRC PAK HW semaphore
-    MOS_RESOURCE           m_resPipeStartSemaMem;                                                                                                      //!< HW semaphore for scalability pipe start at the same time
+    CODECHAL_ENCODE_BUFFER m_resPipeStartSemaMem[CODECHAL_HEVC_MAX_NUM_HCP_PIPE];                                                                      //!< HW semaphore for scalability pipe start at the same time
 
     int32_t m_curPicSlot = -1;        //!< Slot selected to store current Picutre data
     uint32_t m_prevStoreData = 0;     //!< Previous stored data
@@ -2216,6 +2234,11 @@ public:
         bool isRef;
     } slotInfo[CODECHAL_ENCODE_HEVC_VDENC_WP_DATA_BLOCK_NUMBER] = { { 0, 0, false, false } };
 
+    // SCC
+    bool          m_enableLBCOnly = false;               //!< Enable LBC only for IBC
+    bool          m_enableSCC = false;                   //!< Flag to indicate if HEVC SCC is enabled.
+    MOS_RESOURCE  m_vdencRecNotFilteredBuffer = {};
+
     //!
     //! \brief    Constructor
     //!
@@ -2340,6 +2363,7 @@ public:
     MOS_STATUS InitializePicture(const EncoderParams& params) override;
     MOS_STATUS ValidateRefFrameData(PCODEC_HEVC_ENCODE_SLICE_PARAMS slcParams) override;
     MOS_STATUS SetPictureStructs() override;
+    MOS_STATUS SetSequenceStructs() override;
     MOS_STATUS GetStatusReport(EncodeStatus* encodeStatus, EncodeStatusReport* encodeStatusReport) override;
     MOS_STATUS UserFeatureKeyReport() override;
     MOS_STATUS EncodeKernelFunctions() override;
@@ -2769,6 +2793,20 @@ private:
     MOS_STATUS DumpHucDebugOutputBuffers();
 
     MOS_STATUS SetAddCommands(uint32_t commandtype, PMOS_COMMAND_BUFFER cmdBuffer, bool addToBatchBufferHuCBRC, uint32_t roundInterValue, uint32_t roundIntraValue, bool isLowDelayB = true, int8_t *pRefIdxMapping = nullptr, int8_t recNotFilteredID = 0);
+
+    //! \brief    Lookahead analysis
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS AnalyzeLookaheadStats();
+
+    MOS_STATUS HuCLookaheadInit();
+
+    MOS_STATUS HuCLookaheadUpdate();
+
+    MOS_STATUS InsertConditionalBBEndWithHucErrorStatus(PMOS_COMMAND_BUFFER cmdBuffer);
+
 #if USE_CODECHAL_DEBUG_TOOL
     MOS_STATUS DumpHucPakIntegrate();
     MOS_STATUS DumpHucCqp();
