@@ -913,6 +913,52 @@ public:
         uint8_t   RSVD[16];
     };
 
+    //!
+    //! \struct    HucProbDmem
+    //! \brief     HUC prob dmem
+    //!
+    struct HucProbDmem
+    {
+        uint32_t         HuCPassNum;
+        uint32_t         FrameWidth;
+        uint32_t         FrameHeight;
+        uint32_t         Rsvd32[6];
+        char             SegmentRef[CODEC_VP9_MAX_SEGMENTS];
+        uint8_t          SegmentSkip[CODEC_VP9_MAX_SEGMENTS];
+        uint8_t          SegCodeAbs;
+        uint8_t          SegTemporalUpdate;
+        uint8_t          LastRefIndex;
+        uint8_t          GoldenRefIndex;
+        uint8_t          AltRefIndex;
+        uint8_t          RefreshFrameFlags;
+        uint8_t          RefFrameFlags;
+        uint8_t          ContextFrameTypes;
+        HucFrameCtrl     FrameCtrl;
+        HucPrevFrameInfo PrevFrameInfo;
+        uint8_t          Rsvd[2];
+        uint8_t          FrameToShow;
+        uint8_t          LoadKeyFrameDefaultProbs;
+        uint32_t         FrameSize;
+        uint32_t         VDEncImgStateOffset;
+        uint32_t         RePak;
+        uint16_t         LFLevelBitOffset;
+        uint16_t         QIndexBitOffset;
+        uint16_t         SegBitOffset;
+        uint16_t         SegLengthInBits;
+        uint16_t         UnCompHdrTotalLengthInBits;
+        uint16_t         SegUpdateDisable;
+        int32_t          RePakThreshold[256];
+        uint16_t         PicStateOffset;
+        uint16_t         SLBBSize;
+        uint8_t          StreamInEnable;
+        uint8_t          StreamInSegEnable;
+        uint8_t          DisableDMA;
+        uint8_t          IVFHeaderSize;
+        uint8_t          PakOnlyEnable;
+        uint8_t          Reserved[43];
+    };
+
+
     //!
     //! \struct HucInputCmdG12
     //! \brief  The struct of Huc input command
@@ -1028,6 +1074,8 @@ public:
     MOS_RESOURCE                                m_resHucStitchDataBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][CODECHAL_ENCODE_VP9_BRC_MAX_NUM_OF_PASSES];
     MHW_BATCH_BUFFER                            m_HucStitchCmdBatchBuffer = {};
 
+    bool                                        m_pakOnlyModeEnabledForLastPass = false;
+
     //!
     //! \brief    Constructor
     //!
@@ -1178,11 +1226,11 @@ public:
 
     MOS_STATUS InitMmcState() override;
 
-    MOS_STATUS GetSystemPipeNumberCommon();
+    virtual MOS_STATUS GetSystemPipeNumberCommon();
 
     MOS_STATUS InitKernelStateMe();
 
-    MOS_STATUS SetCurbeMe(
+    virtual MOS_STATUS SetCurbeMe(
         MeCurbeParams* params);
 
     MOS_STATUS SendMeSurfaces(
@@ -1262,5 +1310,7 @@ public:
     MOS_STATUS AddCommandsVp9(
         uint32_t commandType,
         PMOS_COMMAND_BUFFER cmdBuffer);
+    MOS_STATUS SetDmemHuCVp9Prob() override;
+    MOS_STATUS InsertConditionalBBEndWithHucErrorStatus(PMOS_COMMAND_BUFFER cmdBuffer);
 };
 #endif  // __CODECHAL_VDENC_VP9_G12_H__
