@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2019, Intel Corporation
+* Copyright (c) 2015-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -84,10 +84,10 @@ MOS_STATUS MhwSfcInterfaceG12::AddSfcState(
     wVYOffset           = 0;
 
     // Check input/output size
-    MHW_ASSERT(pSfcStateParamsG12->dwInputFrameWidth   >= MHW_SFC_MIN_WIDTH);
-    MHW_ASSERT(pSfcStateParamsG12->dwInputFrameHeight  >= MHW_SFC_MIN_HEIGHT);
-    MHW_ASSERT(pSfcStateParamsG12->dwOutputFrameWidth  <= MHW_SFC_MAX_WIDTH);
-    MHW_ASSERT(pSfcStateParamsG12->dwOutputFrameHeight <= MHW_SFC_MAX_HEIGHT);
+    MHW_ASSERT(pSfcStateParamsG12->dwInputFrameWidth   >= m_minWidth);
+    MHW_ASSERT(pSfcStateParamsG12->dwInputFrameHeight  >= m_minHeight);
+    MHW_ASSERT(pSfcStateParamsG12->dwOutputFrameWidth  <= m_maxWidth);
+    MHW_ASSERT(pSfcStateParamsG12->dwOutputFrameHeight <= m_maxHeight);
 
     // Set DW0
     if (pSfcStateParamsG12->sfcPipeMode == MhwSfcInterfaceG12::SFC_PIPE_MODE_HCP)
@@ -368,6 +368,21 @@ MOS_STATUS MhwSfcInterfaceG12::AddSfcState(
             &ResourceParams));
     }
 
+    if (pSfcStateParamsG12->resIefLineTileBuffer && !Mos_ResourceIsNull(pSfcStateParamsG12->resIefLineTileBuffer))
+    {
+        MOS_ZeroMemory(&ResourceParams, sizeof(ResourceParams));
+        ResourceParams.presResource = pSfcStateParamsG12->resIefLineTileBuffer;
+        ResourceParams.pdwCmd = &(cmd.DW41.Value);
+        ResourceParams.dwLocationInCmd = 41;
+        ResourceParams.HwCommandType = MOS_SFC_STATE;
+        ResourceParams.bIsWritable = true;
+
+        MHW_CHK_STATUS_RETURN(pfnAddResourceToCmd(
+            pOsInterface,
+            pCmdBuffer,
+            &ResourceParams));
+    }
+
     if (pSfcStateParamsG12->resSfdLineTileBuffer && !Mos_ResourceIsNull(pSfcStateParamsG12->resSfdLineTileBuffer))
     {
         MOS_ZeroMemory(&ResourceParams, sizeof(ResourceParams));
@@ -561,7 +576,7 @@ MOS_STATUS MhwSfcInterfaceG12 :: SetSfcSamplerTable(
     }
 
     // Recalculate Horizontal scaling table
-    if (SrcFormat != pAvsParams->Format || fScaleX != pAvsParams->fScaleX)
+    if (SrcFormat != pAvsParams->Format || fScaleX != pAvsParams->fScaleX || pAvsParams->bUse8x8Filter != bUse8x8Filter)
     {
         MOS_ZeroMemory(
             piYCoefsX,
@@ -575,66 +590,80 @@ MOS_STATUS MhwSfcInterfaceG12 :: SetSfcSamplerTable(
 
         pAvsParams->fScaleX = fScaleX;
 
-        // For 1x scaling in horizontal direction and not force polyphase coefs, use special coefficients for filtering
-        if (fScaleX == 1.0F && !pAvsParams->bForcePolyPhaseCoefs)
+        if (m_scalingMode == MHW_SCALING_NEAREST)
         {
             MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
                 piYCoefsX,
                 Plane,
                 true));
+            MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                piUVCoefsX,
+                MHW_U_PLANE,
+                true));
+        }
+        else
+        {
+            // For 1x scaling in horizontal direction and not force polyphase coefs, use special coefficients for filtering
+            if ((fScaleX == 1.0F && !pAvsParams->bForcePolyPhaseCoefs))
+            {
+                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                    piYCoefsX,
+                    Plane,
+                    true));
+
+                // The 8-tap adaptive is enabled for all channel if RGB format input, then UV/RB use the same coefficient as Y/G
+                // So, coefficient for UV/RB channels caculation can be passed
+                if ((!(IS_RGB32_FORMAT(SrcFormat) && bUse8x8Filter)))
+                {
+                    MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                        piUVCoefsX,
+                        MHW_U_PLANE,
+                        true));
+                }
+            }
+            else
+            {
+                // Clamp the Scaling Factor if > 1.0x
+                fScaleX = MOS_MIN(1.0F, fScaleX);
+
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
+                    piYCoefsX,
+                    fScaleX,
+                    Plane,
+                    SrcFormat,
+                    fHPStrength,
+                    bUse8x8Filter,
+                    NUM_HW_POLYPHASE_TABLES,
+                    0));
+            }
 
             // The 8-tap adaptive is enabled for all channel if RGB format input, then UV/RB use the same coefficient as Y/G
             // So, coefficient for UV/RB channels caculation can be passed
             if (!(IS_RGB32_FORMAT(SrcFormat) && bUse8x8Filter))
             {
-                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
-                    piUVCoefsX,
-                    MHW_U_PLANE,
-                    true));
-            }
-        }
-        else
-        {
-            // Clamp the Scaling Factor if > 1.0x
-            fScaleX = MOS_MIN(1.0F, fScaleX);
-
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
-                piYCoefsX,
-                fScaleX,
-                Plane,
-                SrcFormat,
-                fHPStrength,
-                bUse8x8Filter,
-                NUM_HW_POLYPHASE_TABLES,
-                0));
-        }
-
-        // The 8-tap adaptive is enabled for all channel if RGB format input, then UV/RB use the same coefficient as Y/G
-        // So, coefficient for UV/RB channels caculation can be passed
-        if (!(IS_RGB32_FORMAT(SrcFormat) && bUse8x8Filter))
-        {
-            // If Chroma Siting info is present
-            if (dwChromaSiting & MHW_CHROMA_SITING_HORZ_LEFT)
-            {
-                // No Chroma Siting
-                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                    piUVCoefsX,
-                    2.0F,
-                    fScaleX));
-            }
-            else
-            {
-                // Chroma siting offset will be add in the HW cmd
-                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                    piUVCoefsX,
-                    3.0F,
-                    fScaleX));
+                // If Chroma Siting info is present
+                if (dwChromaSiting & MHW_CHROMA_SITING_HORZ_LEFT)
+                {
+                    // No Chroma Siting
+                    MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                        piUVCoefsX,
+                        2.0F,
+                        fScaleX));
+                }
+                else
+                {
+                    // Chroma siting offset will be add in the HW cmd
+                    MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                        piUVCoefsX,
+                        3.0F,
+                        fScaleX));
+                }
             }
         }
     }
 
     // Recalculate Vertical scaling table
-    if (SrcFormat != pAvsParams->Format || fScaleY != pAvsParams->fScaleY)
+    if (SrcFormat != pAvsParams->Format || fScaleY != pAvsParams->fScaleY || pAvsParams->bUse8x8Filter != bUse8x8Filter)
     {
         memset((void *)piYCoefsY, 0, 8 * 32 * sizeof(int32_t));
 
@@ -644,65 +673,81 @@ MOS_STATUS MhwSfcInterfaceG12 :: SetSfcSamplerTable(
 
         pAvsParams->fScaleY = fScaleY;
 
-        // For 1x scaling in vertical direction and not force polyphase coefs, use special coefficients for filtering
-        if (fScaleY == 1.0F && !pAvsParams->bForcePolyPhaseCoefs)
+        if (m_scalingMode == MHW_SCALING_NEAREST)
         {
             MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
                 piYCoefsY,
                 Plane,
                 true));
+            MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                piUVCoefsY,
+                MHW_U_PLANE,
+                true));
+        }
+        else
+        {
+            // For 1x scaling in vertical direction and not force polyphase coefs, use special coefficients for filtering
+            if ((fScaleY == 1.0F && !pAvsParams->bForcePolyPhaseCoefs))
+            {
+                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                    piYCoefsY,
+                    Plane,
+                    true));
+
+                // The 8-tap adaptive is enabled for all channel if RGB format input, then UV/RB use the same coefficient as Y/G
+                // So, coefficient for UV/RB channels caculation can be passed
+                if ((!(IS_RGB32_FORMAT(SrcFormat) && bUse8x8Filter)))
+                {
+                    MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                        piUVCoefsY,
+                        MHW_U_PLANE,
+                        true));
+                }
+            }
+            else
+            {
+                // Clamp the Scaling Factor if > 1.0x
+                fScaleY = MOS_MIN(1.0F, fScaleY);
+
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
+                    piYCoefsY,
+                    fScaleY,
+                    Plane,
+                    SrcFormat,
+                    fHPStrength,
+                    bUse8x8Filter,
+                    NUM_HW_POLYPHASE_TABLES, 0));
+            }
 
             // The 8-tap adaptive is enabled for all channel if RGB format input, then UV/RB use the same coefficient as Y/G
             // So, coefficient for UV/RB channels caculation can be passed
             if (!(IS_RGB32_FORMAT(SrcFormat) && bUse8x8Filter))
             {
-                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
-                    piUVCoefsY,
-                    MHW_U_PLANE,
-                    true));
-            }
-        }
-        else
-        {
-            // Clamp the Scaling Factor if > 1.0x
-            fScaleY = MOS_MIN(1.0F, fScaleY);
-
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
-                piYCoefsY,
-                fScaleY,
-                Plane,
-                SrcFormat,
-                fHPStrength,
-                bUse8x8Filter,
-                NUM_HW_POLYPHASE_TABLES,0));
-        }
-
-        // The 8-tap adaptive is enabled for all channel if RGB format input, then UV/RB use the same coefficient as Y/G
-        // So, coefficient for UV/RB channels caculation can be passed
-        if (!(IS_RGB32_FORMAT(SrcFormat) && bUse8x8Filter))
-        {
-            // If Chroma Siting info is present
-            if (dwChromaSiting & MHW_CHROMA_SITING_VERT_TOP)
-            {
-                // No Chroma Siting
-                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                    piUVCoefsY,
-                    2.0F,
-                    fScaleY));
-            }
-            else
-            {
-                // Chroma siting offset will be add in the HW cmd
-                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                    piUVCoefsY,
-                    3.0F,
-                    fScaleY));
+                // If Chroma Siting info is present
+                if (dwChromaSiting & MHW_CHROMA_SITING_VERT_TOP)
+                {
+                    // No Chroma Siting
+                    MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                        piUVCoefsY,
+                        2.0F,
+                        fScaleY));
+                }
+                else
+                {
+                    // Chroma siting offset will be add in the HW cmd
+                    MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                        piUVCoefsY,
+                        3.0F,
+                        fScaleY));
+                }
             }
         }
     }
 
     // Save format used to calculate AVS parameters
     pAvsParams->Format = SrcFormat;
+    // Need to recaculate if use8x8Filter changed
+    pAvsParams->bUse8x8Filter = bUse8x8Filter;
 
     MhwSfcInterface::SetSfcAVSLumaTable(
         SrcFormat,
