@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
 */
 //!
 //! \file       renderhal_g12.cpp
-//! \brief      implementation of Gen11 hardware functions
+//! \brief      implementation of Gen12 hardware functions
 //! \details    Render functions
 //!
 
@@ -142,7 +142,8 @@ MOS_STATUS XRenderHal_Interface_g12::SetupSurfaceState (
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pStateHeap);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pHwSizes);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwStateHeap);
-    MHW_RENDERHAL_ASSERT(pRenderHalSurface->Rotation >= 0 && pRenderHalSurface->Rotation < 8);
+    MHW_RENDERHAL_ASSERT(pRenderHalSurface->Rotation >= MHW_ROTATION_IDENTITY &&
+                         pRenderHalSurface->Rotation <= MHW_ROTATE_90_MIRROR_HORIZONTAL);
     //-----------------------------------------
 
     dwSurfaceSize = pRenderHal->pHwSizes->dwSizeSurfaceState;
@@ -163,6 +164,7 @@ MOS_STATUS XRenderHal_Interface_g12::SetupSurfaceState (
         pSurfaceEntry = ppSurfaceEntries[i];
 
         pSurface = pSurfaceEntry->pSurface;
+        MHW_RENDERHAL_CHK_NULL(pSurface);
 
         // Set the Surface State Offset from base of SSH
         pSurfaceEntry->dwSurfStateOffset = pRenderHal->pStateHeap->iSurfaceStateOffset +                // Offset to Base Of Current Surface State Area
@@ -181,6 +183,21 @@ MOS_STATUS XRenderHal_Interface_g12::SetupSurfaceState (
         SurfStateParams.dwCacheabilityControl = pRenderHal->pfnGetSurfaceMemoryObjectControl(pRenderHal, pParams);
         SurfStateParams.RotationMode          = g_cLookup_RotationMode_g12[pRenderHalSurface->Rotation];
 
+    #if !EMUL
+        if (pRenderHal->pOsInterface !=nullptr)
+        {
+            GMM_RESOURCE_FLAG                   gmmFlags = {0};
+            gmmFlags = pSurface->OsResource.pGmmResInfo->GetResFlags();
+            if (gmmFlags.Gpu.CameraCapture)
+            {
+                SurfStateParams.dwCacheabilityControl = pRenderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
+                    MOS_MHW_GMM_RESOURCE_USAGE_CAMERA_CAPTURE,
+                    pRenderHal->pOsInterface->pfnGetGmmClientContext(pRenderHal->pOsInterface)).DwordValue;
+                MHW_RENDERHAL_NORMALMESSAGE(" disable  CameraCapture  caches on render path ");
+            }
+        }
+    #endif
+
         if (IsFormatMMCSupported(pSurface->Format) &&
             m_renderHalMMCEnabled)
         {
@@ -566,16 +583,17 @@ MOS_STATUS XRenderHal_Interface_g12::EnableL3Caching(
     // customize the cache config for renderhal and let mhw_render overwrite it
     pCacheConfig = &mHwL3CacheConfig;
 
-    pCacheConfig->dwCntlReg = RENDERHAL_L3_CACHE_CONFIG_CNTLREG_VALUE_G12LP_RENDERHAL;
+    mHwL3CacheConfig.dwAllocReg = RENDERHAL_L3_CACHE_CONFIG_CNTLREG_VALUE_G12LP_RENDERHAL;
 
     // Override L3 cache configuration
     if (pCacheSettings->bOverride)
     {
         if (pCacheSettings->bCntlRegOverride)
         {
-            pCacheConfig->dwCntlReg = pCacheSettings->dwCntlReg;
+            mHwL3CacheConfig.dwAllocReg = pCacheSettings->dwCntlReg;
         }
     }
+
     MHW_RENDERHAL_CHK_STATUS(pMhwRender->EnableL3Caching(pCacheConfig));
 
 finish:
@@ -633,7 +651,7 @@ MOS_STATUS XRenderHal_Interface_g12::GetSamplerOffsetAndPtr_DSH(
         case MHW_SAMPLER_TYPE_AVS:
             MHW_RENDERHAL_ASSERT(iSamplerID < pDynamicState->SamplerAVS.iCount);
             dwOffset += pDynamicState->SamplerAVS.dwOffset +                    // Go to AVS sampler area
-                        iSamplerID * MHW_SAMPLER_STATE_AVS_INC_G9;              // 16: size of one element, 128 elements for SKL
+                        iSamplerID * MHW_SAMPLER_STATE_AVS_INC_G12;              // 16: size of one element, 128 elements for SKL
             break;
 
         case MHW_SAMPLER_TYPE_CONV:
@@ -641,15 +659,15 @@ MOS_STATUS XRenderHal_Interface_g12::GetSamplerOffsetAndPtr_DSH(
             dwOffset = pDynamicState->SamplerConv.dwOffset;                     // Goto Conv sampler base
             if ( pSamplerParams->Convolve.ui8ConvolveType == 0 && pSamplerParams->Convolve.skl_mode )
             {   // 2D convolve
-                dwOffset += iSamplerID * MHW_SAMPLER_STATE_CONV_INC_G9;         // 16: size of one element, 128 elements for SKL
+                dwOffset += iSamplerID * MHW_SAMPLER_STATE_CONV_INC_G12;         // 16: size of one element, 128 elements for SKL
             }
             else if ( pSamplerParams->Convolve.ui8ConvolveType == 1 )
             {   // 1D convolve
-                dwOffset += iSamplerID * MHW_SAMPLER_STATE_CONV_1D_INC_G9;      // 16: size of one element, 8 elements for SKL
+                dwOffset += iSamplerID * MHW_SAMPLER_STATE_CONV_1D_INC;      // 16: size of one element, 8 elements for SKL
             }
             else
             {   // 1P convolve (same as gen8) and 2D convolve BDW mode
-                dwOffset += iSamplerID * MHW_SAMPLER_STATE_CONV_INC_G8;         // 16: size of one element, 32: 32 entry
+                dwOffset += iSamplerID * MHW_SAMPLER_STATE_CONV_INC_LEGACY;  // 16: size of one element, 32: 32 entry
             }
             break;
 
@@ -836,19 +854,18 @@ MOS_STATUS XRenderHal_Interface_g12::IsRenderHalMMCEnabled(
 
     // Read user feature key to set MMC for Fast Composition surfaces
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
-    UserFeatureData.i32DataFlag = MOS_USER_FEATURE_VALUE_DATA_FLAG_CUSTOM_DEFAULT_VALUE_TYPE;
-#ifdef LINUX
-    UserFeatureData.bData       = false; // disable MMC on Linux
-#else
-    UserFeatureData.bData       = true; // init as default value to enable MMCD on Gen12LP
-#endif
 
-#if (_DEBUG || _RELEASE_INTERNAL)
+    UserFeatureData.i32DataFlag = MOS_USER_FEATURE_VALUE_DATA_FLAG_CUSTOM_DEFAULT_VALUE_TYPE;
+#if(LINUX)
+    UserFeatureData.bData = !MEDIA_IS_WA(pRenderHal->pWaTable, WaDisableVPMmc) || !MEDIA_IS_WA(pRenderHal->pWaTable, WaDisableCodecMmc); // Enable MMC on Linux based on platforms settings
+#else
+    UserFeatureData.bData = true; // init as default value to enable MMCD on Gen12LP
+#endif
     MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_ENABLE_RENDER_ENGINE_MMC_ID,
-        &UserFeatureData));
-#endif
+        &UserFeatureData,
+        pRenderHal->pOsInterface->pOsContext));
 
     m_renderHalMMCEnabled = UserFeatureData.bData && MEDIA_IS_SKU(pRenderHal->pSkuTable, FtrE2ECompression);
     pRenderHal->isMMCEnabled = m_renderHalMMCEnabled;
@@ -1018,6 +1035,7 @@ bool XRenderHal_Interface_g12::IsFormatMMCSupported(MOS_FORMAT format)
         (format != Format_400P)             &&
         (format != Format_420O)             &&
         (format != Format_R8UN)             &&
+        (format != Format_A8)               &&
         (format != Format_R8G8UN))
     {
         MHW_RENDERHAL_NORMALMESSAGE("Unsupported Format '0x%08x' for Render MMC.", format);
@@ -1087,6 +1105,10 @@ MOS_STATUS XRenderHal_Interface_g12::SetScratchSpaceBufferState(
 MOS_STATUS XRenderHal_Interface_g12::FreeScratchSpaceBuffer(
     RENDERHAL_INTERFACE *renderHal)
 {
+    MOS_GFXRES_FREE_FLAGS resFreeFlags = {0};
+
+    resFreeFlags.AssumeNotInUse = 1;
+
     if (m_scratchSpaceResource.iSize <= 0)
     {
         return MOS_STATUS_SUCCESS;  // Scratch space is not allocated. No need to free resources.
@@ -1095,7 +1117,7 @@ MOS_STATUS XRenderHal_Interface_g12::FreeScratchSpaceBuffer(
     renderHal->pOsInterface
             ->pfnFreeResourceWithFlag(renderHal->pOsInterface,
                                       &m_scratchSpaceResource,
-                                      1);
+                                      resFreeFlags.Value);
     renderHal->pOsInterface
             ->pfnResetResourceAllocationIndex(renderHal->pOsInterface,
                                               &m_scratchSpaceResource);
