@@ -61,7 +61,7 @@ MOS_STATUS MediaVeboxDecompStateG12::RenderDecompCMD(PMOS_SURFACE surface)
         return eStatus;
     }
 
-    if (!IsDecompressionFormatSupported(surface))
+    if (!IsFormatSupported(surface))
     {
         VPHAL_MEMORY_DECOMP_NORMALMESSAGE("Input surface is not supported by Vebox, In_Place resolve can't be done");
         return eStatus;
@@ -177,7 +177,8 @@ MOS_STATUS MediaVeboxDecompStateG12::IsVeboxDecompressionEnabled()
     MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
         nullptr,
         __VPHAL_ENABLE_VEBOX_MMC_DECOMPRESS_ID,
-        &UserFeatureData));
+        &UserFeatureData,
+        m_osInterface->pOsContext));
 
     m_veboxMMCResolveEnabled = UserFeatureData.bData ? true: false;
 
@@ -185,7 +186,7 @@ MOS_STATUS MediaVeboxDecompStateG12::IsVeboxDecompressionEnabled()
 }
 
 MOS_STATUS MediaVeboxDecompStateG12::RenderDoubleBufferDecompCMD(
-    PMOS_SURFACE inputSurface, 
+    PMOS_SURFACE inputSurface,
     PMOS_SURFACE outputSurface)
 {
     MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
@@ -200,6 +201,12 @@ MOS_STATUS MediaVeboxDecompStateG12::RenderDoubleBufferDecompCMD(
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(inputSurface);
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(outputSurface);
 
+    if (!IsFormatSupported(inputSurface) || !IsFormatSupported(outputSurface))
+    {
+        VPHAL_MEMORY_DECOMP_NORMALMESSAGE("Input surface is not supported by Vebox, In_Place resolve can't be done");
+        return eStatus;
+    }
+
     veboxInterface = m_veboxInterface;
 
     m_osInterface->pfnSetGpuContext(m_osInterface, MOS_GPU_CONTEXT_VEBOX);
@@ -231,11 +238,12 @@ MOS_STATUS MediaVeboxDecompStateG12::RenderDoubleBufferDecompCMD(
     // Prepare Vebox_Surface_State, surface input/and output are the same but the compressed status.
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(SetupVeboxSurfaceState(&mhwVeboxSurfaceStateCmdParams, inputSurface, outputSurface));
 
-    //---------------------------------
-    // Send Pvt MMCD CMD
-    //---------------------------------
-    MediaVeboxDecompStateG12 *pVeboxInterfaceExt12;
-    pVeboxInterfaceExt12 = (MediaVeboxDecompStateG12 *)veboxInterface;
+    MhwVeboxInterfaceG12 *pVeboxInterfaceExt12;
+    pVeboxInterfaceExt12 = (MhwVeboxInterfaceG12 *)veboxInterface;
+
+    VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(pVeboxInterfaceExt12->setVeboxPrologCmd(
+        m_mhwMiInterface,
+        &cmdBuffer));
 
     //---------------------------------
     // Send CMD: Vebox_Surface_State
@@ -391,7 +399,7 @@ MOS_STATUS MediaVeboxDecompStateG12::VeboxSendVeboxTileConvertCMD(
     ResourceParams.pdwCmd          = &(cmd.DW1_2.Value[0]);
     ResourceParams.bIsWritable     = false;
     ResourceParams.dwOffset        = inputSurface->dwOffset + veboxInputSurfCtrlBits.DW0.Value;
-    m_veboxInterface->pfnAddResourceToCmd(m_osInterface, cmdBuffer, &ResourceParams);
+    VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(m_veboxInterface->pfnAddResourceToCmd(m_osInterface, cmdBuffer, &ResourceParams));
 
     MOS_ZeroMemory(&ResourceParams, sizeof(MHW_RESOURCE_PARAMS));
 
