@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -437,7 +437,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
         VPHAL_CSPACE        ColorSpace;
         VPHAL_SAMPLE_TYPE   SampleType;
 
-        GetFFDISurfParams(ColorSpace, SampleType);
+        VPHAL_RENDER_CHK_STATUS(GetFFDISurfParams(ColorSpace, SampleType));
 
         for (i = 0; i < pVeboxState->iNumFFDISurfaces; i++)
         {
@@ -468,6 +468,9 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
 
             pVeboxState->FFDISurfaces[i]->ColorSpace = ColorSpace;
 
+            // Copy ScalingMode, it's used in setting SFC state
+            pVeboxState->FFDISurfaces[i]->ScalingMode = pVeboxState->m_currentSurface->ScalingMode;
+
             if (bAllocated)
             {
                 // Report Compress Status
@@ -559,6 +562,8 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
             // Copy FrameID and parameters, as DN output will be used as next blt's current
             pVeboxState->FFDNSurfaces[i]->FrameID            = pVeboxState->m_currentSurface->FrameID;
             pVeboxState->FFDNSurfaces[i]->pDenoiseParams     = pVeboxState->m_currentSurface->pDenoiseParams;
+            // Copy ScalingMode, it's used in setting SFC state
+            pVeboxState->FFDNSurfaces[i]->ScalingMode        = pVeboxState->m_currentSurface->ScalingMode;
 
             if (bAllocated)
             {
@@ -638,6 +643,37 @@ MOS_STATUS VPHAL_VEBOX_STATE_G9_BASE::AllocateResources()
         }
     }
 
+    // Allocate BT2020 CSC temp surface----------------------------------------------
+    if (pRenderData->b2PassesCSC)
+    {
+        VPHAL_RENDER_CHK_STATUS(VpHal_ReAllocateSurface(
+            pOsInterface,
+            &pVeboxState->m_BT2020CSCTempSurface,
+            "VeboxBT2020CSCTempSurface_g9",
+            Format_A8B8G8R8,
+            MOS_GFXRES_2D,
+            MOS_TILE_Y,
+            pVeboxState->m_currentSurface->dwWidth,
+            pVeboxState->m_currentSurface->dwHeight,
+            false,
+            MOS_MMC_DISABLED,
+            &bAllocated));
+
+        // Copy rect sizes so that if input surface state needs to adjust,
+        // output surface can be adjustted also.
+        pVeboxState->m_BT2020CSCTempSurface.rcSrc = pVeboxState->m_currentSurface->rcSrc;
+        pVeboxState->m_BT2020CSCTempSurface.rcDst = pVeboxState->m_currentSurface->rcDst;
+        // Copy max src rect
+        pVeboxState->m_BT2020CSCTempSurface.rcMaxSrc = pVeboxState->m_currentSurface->rcMaxSrc;
+
+        // Copy Rotation, it's used in setting SFC state
+        pVeboxState->m_BT2020CSCTempSurface.Rotation   = pVeboxState->m_currentSurface->Rotation;
+        pVeboxState->m_BT2020CSCTempSurface.SampleType = pVeboxState->m_currentSurface->SampleType;
+        pVeboxState->m_BT2020CSCTempSurface.ColorSpace = CSpace_sRGB;
+        // Copy ScalingMode, it's used in setting SFC state
+        pVeboxState->m_BT2020CSCTempSurface.ScalingMode = pVeboxState->m_currentSurface->ScalingMode;
+    }
+
     // Allocate Statistics State Surface----------------------------------------
     // Width to be a aligned on 64 bytes and height is 1/4 the height
     // Per frame information written twice per frame for 2 slices
@@ -790,6 +826,11 @@ void VPHAL_VEBOX_STATE_G9_BASE::FreeResources()
         pOsInterface,
         &pVeboxState->VeboxStatisticsSurface.OsResource);
 
+    // Free BT2020 CSC temp surface for VEBOX used by BT2020 CSC
+    pOsInterface->pfnFreeResource(
+        pOsInterface,
+        &pVeboxState->m_BT2020CSCTempSurface.OsResource);
+
 #if VEBOX_AUTO_DENOISE_SUPPORTED
     // Free Spatial Attributes Configuration Surface for DN kernel
     pOsInterface->pfnFreeResource(
@@ -1602,6 +1643,12 @@ VPHAL_OUTPUT_PIPE_MODE VPHAL_VEBOX_STATE_G9_BASE::GetOutputPipe(
         goto finish;
     }
 
+    if (VeboxIs2PassesCSCNeeded(pSrcSurface, pcRenderParams->pTarget[0]))
+    {
+        OutputPipe = VPHAL_OUTPUT_PIPE_MODE_COMP;
+        goto finish;
+    }
+
     pTarget    = pcRenderParams->pTarget[0];
     // Check if SFC can be the output pipe
     if (m_sfcPipeState)
@@ -1717,6 +1764,23 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
             pSrcSurface,
             &pRenderPassData->bCompNeeded));
 
+    //If using Vebox to Crop, setting the bVEBOXCroppingUsed = true. We use the rcSrc to set Vebox width/height instead of using rcMaxsrc in VeboxAdjustBoundary().
+    if (IS_VPHAL_OUTPUT_PIPE_VEBOX(pRenderData) &&
+        ((uint32_t)pSrcSurface->rcSrc.bottom < pSrcSurface->dwHeight ||
+            (uint32_t)pSrcSurface->rcSrc.right < pSrcSurface->dwWidth))
+    {
+        pSrcSurface->bVEBOXCroppingUsed = true;
+        VPHAL_RENDER_NORMALMESSAGE("bVEBOXCroppingUsed = true, pSrcSurface->rcSrc.bottom: %d, pSrcSurface->rcSrc.right: %d; pSrcSurface->dwHeight: %d, pSrcSurface->dwHeight: %d;",
+            (uint32_t)pSrcSurface->rcSrc.bottom,
+            (uint32_t)pSrcSurface->rcSrc.right,
+            pSrcSurface->dwHeight,
+            pSrcSurface->dwWidth);
+    }
+    else
+    {
+        pSrcSurface->bVEBOXCroppingUsed = false;
+    }
+
     // Set MMC State
     SET_VPHAL_MMC_STATE(pRenderData, pVeboxState->bEnableMMC);
 
@@ -1744,6 +1808,11 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsNeeded(
             pSrcSurface,
             pRenderTarget);
 
+        if (pRenderData->b2PassesCSC)
+        {
+            pRenderData->bVeboxBypass = false;
+        }
+
         // Vebox is needed if Vebox isn't bypassed
         bVeboxNeeded = !pRenderData->bVeboxBypass;
     }
@@ -2139,7 +2208,11 @@ bool VPHAL_VEBOX_STATE_G9_BASE::IsFormatSupported(
         pSrcSurface->Format != Format_Y8   &&
         pSrcSurface->Format != Format_Y16U &&
         pSrcSurface->Format != Format_Y16S &&
-        !IS_PA_FORMAT(pSrcSurface->Format))
+        (!IS_PA_FORMAT(pSrcSurface->Format) ||
+         pSrcSurface->Format == Format_Y410 ||    // Gen9 can't support Y410/Y416/Y210/Y216 Format
+         pSrcSurface->Format == Format_Y416 ||
+         pSrcSurface->Format == Format_Y210 ||
+         pSrcSurface->Format == Format_Y216))
     {
         VPHAL_RENDER_NORMALMESSAGE("Unsupported Source Format '0x%08x' for VEBOX.", pSrcSurface->Format);
         goto finish;
