@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2018, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -62,7 +62,7 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
     uint32_t sliceBaseOffset;
     sliceBaseOffset = GetBsBufOffset(m_groupIndex);
 
-    uint32_t i, slcCount;
+    uint32_t i, slcCount, refCount;
     for (slcCount = 0; slcCount < numSlices; slcCount++)
     {
         if (m_ddiDecodeCtx->bShortFormatInUse)
@@ -113,7 +113,8 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
             avcSliceParams->slice_alpha_c0_offset_div2    = slc->slice_alpha_c0_offset_div2;
             avcSliceParams->slice_beta_offset_div2        = slc->slice_beta_offset_div2;
             // reference list 0
-            for (i = 0; i < CODEC_MAX_NUM_REF_FIELD; i++)
+            refCount = std::min(avcSliceParams->num_ref_idx_l0_active_minus1 + 1, CODEC_MAX_NUM_REF_FIELD);
+            for (i = 0; i < refCount; i++)
             {
                 SetupCodecPicture(
                     mediaCtx,
@@ -127,7 +128,8 @@ VAStatus DdiDecodeAVC::ParseSliceParams(
                 GetSlcRefIdx(&(avcPicParams->RefFrameList[0]), &(avcSliceParams->RefPicList[0][i]));
             }
             // reference list 1
-            for (i = 0; i < CODEC_MAX_NUM_REF_FIELD; i++)
+            refCount = std::min(avcSliceParams->num_ref_idx_l1_active_minus1 + 1, CODEC_MAX_NUM_REF_FIELD);
+            for (i = 0; i < refCount; i++)
             {
                 SetupCodecPicture(
                     mediaCtx,
@@ -469,13 +471,13 @@ VAStatus DdiDecodeAVC::SetDecodeParams()
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
         auto procParams = 
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        procParams->pInputSurface = (&m_ddiDecodeCtx->DecodeParams)->m_destSurface;
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        procParams->m_inputSurface = (&m_ddiDecodeCtx->DecodeParams)->m_destSurface;
         // codechal_decode_sfc.c expects Input Width/Height information.
-        procParams->pInputSurface->dwWidth    = procParams->pInputSurface->OsResource.iWidth;
-        procParams->pInputSurface->dwHeight = procParams->pInputSurface->OsResource.iHeight;
-        procParams->pInputSurface->dwPitch    = procParams->pInputSurface->OsResource.iPitch;
-        procParams->pInputSurface->Format    = procParams->pInputSurface->OsResource.Format;
+        procParams->m_inputSurface->dwWidth  = procParams->m_inputSurface->OsResource.iWidth;
+        procParams->m_inputSurface->dwHeight = procParams->m_inputSurface->OsResource.iHeight;
+        procParams->m_inputSurface->dwPitch  = procParams->m_inputSurface->OsResource.iPitch;
+        procParams->m_inputSurface->Format   = procParams->m_inputSurface->OsResource.Format;
     }
 #endif
 
@@ -613,11 +615,11 @@ VAStatus DdiDecodeAVC::CodecHalInit(
 #ifdef _DECODE_PROCESSING_SUPPORTED
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
-        PCODECHAL_DECODE_PROCESSING_PARAMS procParams = nullptr;
+        DecodeProcessingParams *procParams = nullptr;
 
         m_codechalSettings->downsamplingHinted = true;
 
-        procParams = (PCODECHAL_DECODE_PROCESSING_PARAMS)MOS_AllocAndZeroMemory(sizeof(CODECHAL_DECODE_PROCESSING_PARAMS));
+        procParams = (DecodeProcessingParams *)MOS_AllocAndZeroMemory(sizeof(DecodeProcessingParams));
         if (procParams == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
@@ -625,8 +627,8 @@ VAStatus DdiDecodeAVC::CodecHalInit(
         }
 
         m_ddiDecodeCtx->DecodeParams.m_procParams = procParams;
-        procParams->pOutputSurface               = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
-        if (procParams->pOutputSurface == nullptr)
+        procParams->m_outputSurface               = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
+        if (procParams->m_outputSurface == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
             goto CleanUpandReturn;
@@ -672,8 +674,8 @@ CleanUpandReturn:
     if (m_ddiDecodeCtx->DecodeParams.m_procParams)
     {
         auto procParams = 
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        MOS_FreeMemory(procParams->pOutputSurface);
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        MOS_FreeMemory(procParams->m_outputSurface);
 
         MOS_FreeMemory(m_ddiDecodeCtx->DecodeParams.m_procParams);
         m_ddiDecodeCtx->DecodeParams.m_procParams = nullptr;
