@@ -109,12 +109,12 @@ VAStatus DdiEncodeHevc::ContextInitialize(
     codecHalSettings->mode            = m_encodeCtx->wModeType;
     codecHalSettings->standard        = CODECHAL_HEVC;
 
-    if(m_encodeCtx->vaProfile==VAProfileHEVCMain)
+    if(m_encodeCtx->vaProfile==VAProfileHEVCMain || m_encodeCtx->vaProfile==VAProfileHEVCSccMain)
     {
        codecHalSettings->chromaFormat    = HCP_CHROMA_FORMAT_YUV420;
        codecHalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_8_BITS;
     }
-    else if(m_encodeCtx->vaProfile==VAProfileHEVCMain10)
+    else if(m_encodeCtx->vaProfile==VAProfileHEVCMain10 || m_encodeCtx->vaProfile==VAProfileHEVCSccMain10)
     {
        codecHalSettings->chromaFormat    = HCP_CHROMA_FORMAT_YUV420;
        codecHalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_10_BITS;
@@ -134,12 +134,12 @@ VAStatus DdiEncodeHevc::ContextInitialize(
         codecHalSettings->chromaFormat    = HCP_CHROMA_FORMAT_YUV422;
         codecHalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_12_BITS;
     }
-    else if (m_encodeCtx->vaProfile == VAProfileHEVCMain444)
+    else if (m_encodeCtx->vaProfile == VAProfileHEVCMain444 || m_encodeCtx->vaProfile==VAProfileHEVCSccMain444)
     {
         codecHalSettings->chromaFormat = HCP_CHROMA_FORMAT_YUV444;
         codecHalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_8_BITS;
     }
-    else if (m_encodeCtx->vaProfile == VAProfileHEVCMain444_10)
+    else if (m_encodeCtx->vaProfile == VAProfileHEVCMain444_10 || m_encodeCtx->vaProfile==VAProfileHEVCSccMain444_10)
     {
         codecHalSettings->chromaFormat = HCP_CHROMA_FORMAT_YUV444;
         codecHalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_10_BITS;
@@ -149,6 +149,7 @@ VAStatus DdiEncodeHevc::ContextInitialize(
         codecHalSettings->chromaFormat = HCP_CHROMA_FORMAT_YUV444;
         codecHalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_12_BITS;
     }
+    codecHalSettings->isSCCEnabled = IsSccProfile();
 
     VAStatus eStatus = VA_STATUS_SUCCESS;
 
@@ -339,7 +340,10 @@ VAStatus DdiEncodeHevc::EncodeInCodecHal(uint32_t numSlices)
     }
 
     PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS hevcSeqParams = (PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS)((uint8_t *)m_encodeCtx->pSeqParams);
-    hevcSeqParams->TargetUsage = m_encodeCtx->targetUsage;
+    if (m_encodeCtx->bNewSeq)
+    {
+        hevcSeqParams->TargetUsage = m_encodeCtx->targetUsage;
+    }
     encodeParams.pSeqParams   = m_encodeCtx->pSeqParams;
     encodeParams.pVuiParams   = m_encodeCtx->pVuiParams;
     encodeParams.pPicParams   = m_encodeCtx->pPicParams;
@@ -487,6 +491,12 @@ VAStatus DdiEncodeHevc::ParseSeqParams(void *ptr)
     hevcSeqParams->bit_depth_luma_minus8                = seqParams->seq_fields.bits.bit_depth_luma_minus8;
     hevcSeqParams->bit_depth_chroma_minus8              = seqParams->seq_fields.bits.bit_depth_chroma_minus8;
 
+    if (m_codechalSettings->isSCCEnabled)
+    {
+        hevcSeqParams->palette_mode_enabled_flag = seqParams->scc_fields.bits.palette_mode_enabled_flag;
+        hevcSeqParams->motion_vector_resolution_control_idc = 0;
+    }
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -506,9 +516,25 @@ VAStatus DdiEncodeHevc::ParsePicParams(
 
     PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS hevcSeqParams = (PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS)((uint8_t *)m_encodeCtx->pSeqParams);
 
+    DDI_MEDIA_SURFACE *surface;
     if(picParams->decoded_curr_pic.picture_id != VA_INVALID_SURFACE)
     {
-        DDI_CHK_RET(RegisterRTSurfaces(&(m_encodeCtx->RTtbl), DdiMedia_GetSurfaceFromVASurfaceID(mediaCtx, picParams->decoded_curr_pic.picture_id)), "RegisterRTSurfaces failed!");
+        surface = DdiMedia_GetSurfaceFromVASurfaceID(mediaCtx, picParams->decoded_curr_pic.picture_id);
+
+        if(m_encodeCtx->vaProfile == VAProfileHEVCMain444
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain444_10
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain444_12
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain422_10
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain422_12
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain10
+        || m_encodeCtx->vaProfile == VAProfileHEVCMain12
+        || m_encodeCtx->vaProfile == VAProfileHEVCSccMain10
+        || m_encodeCtx->vaProfile == VAProfileHEVCSccMain444
+        || m_encodeCtx->vaProfile == VAProfileHEVCSccMain444_10)
+        {
+            surface = DdiMedia_ReplaceSurfaceWithVariant(surface, m_encodeCtx->vaEntrypoint);
+        }
+        DDI_CHK_RET(RegisterRTSurfaces(&(m_encodeCtx->RTtbl),surface), "RegisterRTSurfaces failed!");
     }
 
     // Curr Recon Pic
@@ -558,6 +584,9 @@ VAStatus DdiEncodeHevc::ParsePicParams(
     /* picParams->coding_type; App is always setting this to 0 */
     hevcPicParams->CodingType = picParams->pic_fields.bits.coding_type;
 
+    /* CodingType may be updated in slice processing. Do below to save pyramid level info */
+    hevcPicParams->ppsCodingType = picParams->pic_fields.bits.coding_type;
+
     hevcPicParams->HierarchLevelPlus1 = picParams->hierarchical_level_plus1;
 
     /* Reset it to zero now */
@@ -646,6 +675,16 @@ VAStatus DdiEncodeHevc::ParsePicParams(
         }
     }
 
+    if (m_codechalSettings->isSCCEnabled)
+    {
+        // SCC
+        hevcPicParams->pps_curr_pic_ref_enabled_flag = picParams->scc_fields.bits.pps_curr_pic_ref_enabled_flag;
+        hevcPicParams->residual_adaptive_colour_transform_enabled_flag = 0;
+        hevcPicParams->pps_slice_act_qp_offsets_present_flag = 0;
+        // GEN12 HW only can support the initial palette size 0
+        hevcPicParams->PredictorPaletteSize = 0;
+    }
+
     DDI_MEDIA_BUFFER *buf = DdiMedia_GetBufferFromVABufferID(mediaCtx, picParams->coded_buf);
     if (nullptr == buf)
     {
@@ -737,23 +776,22 @@ VAStatus DdiEncodeHevc::ParseSlcParams(
             hevcSlcParams->luma_offset[0][i]       = vaEncSlcParamsHEVC->luma_offset_l0[i];
             hevcSlcParams->delta_luma_weight[0][i] = vaEncSlcParamsHEVC->delta_luma_weight_l0[i];
 
-            hevcSlcParams->chroma_offset[0][i][0]       = vaEncSlcParamsHEVC->chroma_offset_l0[i][0];
+            hevcSlcParams->chroma_offset[0][i][0]       = MOS_CLAMP_MIN_MAX(vaEncSlcParamsHEVC->chroma_offset_l0[i][0], minChromaOffset, maxChromaOffset);
             hevcSlcParams->delta_chroma_weight[0][i][0] = vaEncSlcParamsHEVC->delta_chroma_weight_l0[i][0];
 
-            hevcSlcParams->chroma_offset[0][i][1]       = vaEncSlcParamsHEVC->chroma_offset_l0[i][1];
+            hevcSlcParams->chroma_offset[0][i][1]       = MOS_CLAMP_MIN_MAX(vaEncSlcParamsHEVC->chroma_offset_l0[i][1], minChromaOffset, maxChromaOffset);
             hevcSlcParams->delta_chroma_weight[0][i][1] = vaEncSlcParamsHEVC->delta_chroma_weight_l0[i][1];
 
             // list 1
             hevcSlcParams->luma_offset[1][i]       = vaEncSlcParamsHEVC->luma_offset_l1[i];
             hevcSlcParams->delta_luma_weight[1][i] = vaEncSlcParamsHEVC->delta_luma_weight_l1[i];
 
-            hevcSlcParams->chroma_offset[1][i][0]       = vaEncSlcParamsHEVC->chroma_offset_l1[i][0];
+            hevcSlcParams->chroma_offset[1][i][0]       = MOS_CLAMP_MIN_MAX(vaEncSlcParamsHEVC->chroma_offset_l1[i][0], minChromaOffset, maxChromaOffset);
             hevcSlcParams->delta_chroma_weight[1][i][0] = vaEncSlcParamsHEVC->delta_chroma_weight_l1[i][0];
 
-            hevcSlcParams->chroma_offset[1][i][1]       = vaEncSlcParamsHEVC->chroma_offset_l1[i][1];
+            hevcSlcParams->chroma_offset[1][i][1]       = MOS_CLAMP_MIN_MAX(vaEncSlcParamsHEVC->chroma_offset_l1[i][1], minChromaOffset, maxChromaOffset);
             hevcSlcParams->delta_chroma_weight[1][i][1] = vaEncSlcParamsHEVC->delta_chroma_weight_l1[i][1];
         }
-
         for (uint32_t i = 0; i < numMaxRefFrame; i++)
         {
             if(i >  hevcSlcParams->num_ref_idx_l0_active_minus1)
@@ -1025,7 +1063,6 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         VAEncMiscParameterHRD *vaEncMiscParamHRD = (VAEncMiscParameterHRD *)miscParamBuf->data;
         seqParams->VBVBufferSizeInBit            = vaEncMiscParamHRD->buffer_size;
         seqParams->InitVBVBufferFullnessInBit    = vaEncMiscParamHRD->initial_buffer_fullness;
-        seqParams->RateControlMethod             = RATECONTROL_CBR;
         break;
     }
     case VAEncMiscParameterTypeFrameRate:
@@ -1072,6 +1109,9 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         {
             picParams->BRCMaxQp  = (vaEncMiscParamRC->max_qp == 0) ? 51 : (uint8_t)CodecHal_Clip3(1, 51, (int8_t)vaEncMiscParamRC->max_qp);
             picParams->BRCMinQp = (vaEncMiscParamRC->min_qp == 0) ? 1 : (uint8_t)CodecHal_Clip3(1, picParams->BRCMaxQp, (int8_t)vaEncMiscParamRC->min_qp);
+#if VA_CHECK_VERSION(1, 10, 0)
+            picParams->TargetFrameSize = vaEncMiscParamRC->target_frame_size;
+#endif
         }
         else
         {
@@ -1174,7 +1214,6 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
     case VAEncMiscParameterTypeROI:
     {
         VAEncMiscParameterBufferROI *vaEncMiscParamROI = (VAEncMiscParameterBufferROI *)miscParamBuf->data;
-        uint32_t                     maxROIsupported   = CODECHAL_ENCODE_HEVC_MAX_NUM_ROI;
         uint8_t                      blockSize         = (m_encodeCtx->bVdencActive) ? vdencRoiBlockSize : CODECHAL_MACROBLOCK_WIDTH;
 
          uint32_t frameWidth = (seqParams->wFrameWidthInMinCbMinus1 + 1) << (seqParams->log2_min_coding_block_size_minus3 + 3);
@@ -1182,6 +1221,12 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
          uint16_t rightBorder = (uint16_t)CODECHAL_GET_WIDTH_IN_BLOCKS(frameWidth, blockSize) - 1;
          uint16_t bottomBorder = (uint16_t)CODECHAL_GET_HEIGHT_IN_BLOCKS(frameHeight, blockSize) - 1;
 
+         if(vaEncMiscParamROI->num_roi > CODECHAL_ENCODE_HEVC_MAX_NUM_ROI)
+         {
+             DDI_ASSERTMESSAGE("The number of ROI rect is greater than %d", CODECHAL_ENCODE_HEVC_MAX_NUM_ROI);
+             return VA_STATUS_ERROR_INVALID_PARAMETER;
+         }
+
         if (vaEncMiscParamROI->num_roi)
         {
             for (uint32_t i = 0; i < vaEncMiscParamROI->num_roi; ++i)
@@ -1206,37 +1251,26 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
                     DDI_ASSERTMESSAGE("ROI Top > ROI Bottom.");
                     return VA_STATUS_ERROR_INVALID_PARAMETER;
                 }
-
-
-                if (m_encodeCtx->bVdencActive == false)
-                {
-                    // align to CTB edge (32 on Gen9) to avoid QP average issue
-                    pic_param_roi.Left   = MOS_ALIGN_FLOOR(pic_param_roi.Left, 32);
-                    pic_param_roi.Right  = MOS_ALIGN_CEIL(pic_param_roi.Right, 32);
-                    pic_param_roi.Top    = MOS_ALIGN_FLOOR(pic_param_roi.Top, 32);
-                    pic_param_roi.Bottom = MOS_ALIGN_CEIL(pic_param_roi.Bottom, 32);
-                }
-
-
+              
                 // Convert from pixel units to block size units
                 pic_param_roi.Left   /= blockSize;
                 pic_param_roi.Right  /= blockSize;
                 pic_param_roi.Top    /= blockSize;
                 pic_param_roi.Bottom /= blockSize;
 
-                // DDI defination for right and bottom parameters is inclusive whereas
-                // the defination in BRC kernel input is exclusive. So adding 1 to right & bottom.
-                 pic_param_roi.Right += 1;
-                 pic_param_roi.Bottom += 1;
-
                  // check frame boundary
                  pic_param_roi.Left   = pic_param_roi.Left  > rightBorder  ? rightBorder : pic_param_roi.Left;
                  pic_param_roi.Right  = pic_param_roi.Right  > rightBorder  ? rightBorder  : pic_param_roi.Right;
                  pic_param_roi.Top    = pic_param_roi.Top    > bottomBorder ? bottomBorder : pic_param_roi.Top;
                  pic_param_roi.Bottom = pic_param_roi.Bottom > bottomBorder ? bottomBorder : pic_param_roi.Bottom;
 
+                  // DDI defination for right and bottom parameters is inclusive whereas
+                  // the defination in BRC kernel input is exclusive. So adding 1 to right & bottom.
+                  pic_param_roi.Right += 1;
+                  pic_param_roi.Bottom += 1;
+
             }
-            picParams->NumROI = MOS_MIN(vaEncMiscParamROI->num_roi, maxROIsupported);
+            picParams->NumROI = vaEncMiscParamROI->num_roi;
         }
 #ifndef ANDROID
         // support DeltaQP based ROI by default
@@ -1254,8 +1288,8 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         VAEncMiscParameterBufferDirtyRect *vaEncMiscDirtyRect = (VAEncMiscParameterBufferDirtyRect *)miscParamBuf->data;
 
         uint8_t blockSize  = (m_encodeCtx->bVdencActive) ? vdencRoiBlockSize : CODECHAL_MACROBLOCK_WIDTH;
-        uint32_t frameWidth = (seqParams->wFrameWidthInMinCbMinus1 + 1) << (seqParams->log2_min_coding_block_size_minus3 + 3);
-        uint32_t frameHeight = (seqParams->wFrameHeightInMinCbMinus1 + 1) << (seqParams->log2_min_coding_block_size_minus3 + 3);
+        uint32_t rightBorder = CODECHAL_GET_WIDTH_IN_BLOCKS(m_encodeCtx->dwFrameWidth, blockSize) - 1;
+        uint32_t bottomBorder = CODECHAL_GET_HEIGHT_IN_BLOCKS(m_encodeCtx->dwFrameHeight, blockSize) - 1;
 
          DDI_CHK_NULL(vaEncMiscDirtyRect->roi_rectangle, "nullptr dirty rect", VA_STATUS_ERROR_INVALID_PARAMETER);
         if(vaEncMiscDirtyRect->num_roi_rectangle > ENCODE_VDENC_HEVC_MAX_DIRTYRECT_G10)
@@ -1287,21 +1321,10 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
             {
                 auto &rect    = picParams->pDirtyRect[i];
                 auto &va_rect = vaEncMiscDirtyRect->roi_rectangle[i];
-
-                // Check and adjust if rect not within frame boundaries
-                rect.Left   = MOS_MIN(va_rect.x, frameWidth - 1);
-                rect.Top    = MOS_MIN(va_rect.y, frameHeight - 1);
-                rect.Right  = MOS_MIN(va_rect.x + va_rect.width, frameWidth - 1);
-                rect.Bottom = MOS_MIN(va_rect.y + va_rect.height, frameHeight - 1);
-
-                if( rect.Left > rect.Right ||  rect.Top > rect.Bottom)
-                {
-                    DDI_ASSERTMESSAGE("Invalid rect region parameter.");
-                    return VA_STATUS_ERROR_INVALID_PARAMETER;
-                }
-
-                rect.Right  = MOS_ALIGN_CEIL(rect.Right, blockSize);
-                rect.Bottom = MOS_ALIGN_CEIL(rect.Bottom, blockSize);
+                rect.Left   = va_rect.x;
+                rect.Top    = va_rect.y;
+                rect.Right  = va_rect.x + va_rect.width - 1;
+                rect.Bottom = va_rect.y + va_rect.height - 1;
 
                 // Convert from pixel units to block units
                 rect.Left /= blockSize;
@@ -1309,6 +1332,16 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
                 rect.Top /= blockSize;
                 rect.Bottom /= blockSize;
 
+                // Check and adjust if rect not within frame boundaries
+                rect.Left = MOS_MIN(rect.Left, rightBorder);
+                rect.Right = MOS_MIN(rect.Right, rightBorder);
+                rect.Top = MOS_MIN(rect.Top, bottomBorder);
+                rect.Bottom = MOS_MIN(rect.Bottom, bottomBorder);
+                if (rect.Left > rect.Right || rect.Top > rect.Bottom)
+                {
+                    DDI_ASSERTMESSAGE("Invalid rect region parameter.");
+                    return VA_STATUS_ERROR_INVALID_PARAMETER;
+                }
                 picParams->NumDirtyRects ++;
             }
         }
@@ -1332,7 +1365,7 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
     {
         VAEncMiscParameterMaxSliceSize *vaEncMiscParamMaxSliceSize = (VAEncMiscParameterMaxSliceSize *)miscParamBuf->data;
         m_encodeCtx->EnableSliceLevelRateCtrl                      = true;
-        seqParams->SliceSizeControl                                = true;
+        seqParams->SliceSizeControl                                = (vaEncMiscParamMaxSliceSize->max_slice_size > 0) ? true : false;;
         picParams->MaxSliceSizeInBytes                             = vaEncMiscParamMaxSliceSize->max_slice_size;
         break;
     }
@@ -1342,6 +1375,13 @@ VAStatus DdiEncodeHevc::ParseMiscParams(void *ptr)
         picParams->bUseRawPicForRef                                = vaEncMiscParamPrivate->useRawPicForRef;
         break;
     }
+    case VAEncMiscParameterTypeMaxFrameSize:
+    {
+        VAEncMiscParameterBufferMaxFrameSize *vaEncData  = (VAEncMiscParameterBufferMaxFrameSize *)miscParamBuf->data;
+        seqParams->UserMaxIFrameSize = vaEncData->max_frame_size>>3; // convert to bytes
+        seqParams->UserMaxPBFrameSize = vaEncData->max_frame_size>>3; // convert to bytes
+        break;
+    }
     default:
         DDI_ASSERTMESSAGE("unsupported misc parameter type.");
         return VA_STATUS_ERROR_INVALID_PARAMETER;
@@ -1357,6 +1397,14 @@ uint8_t DdiEncodeHevc::CodechalPicTypeFromVaSlcType(uint8_t vaSliceType)
     case sliceTypeI:
         return I_TYPE;
     case sliceTypeP:
+        if (m_codechalSettings->isSCCEnabled)
+        {
+            PCODEC_HEVC_ENCODE_PICTURE_PARAMS hevcPicParams = (PCODEC_HEVC_ENCODE_PICTURE_PARAMS)((uint8_t *)m_encodeCtx->pPicParams);
+            if (hevcPicParams->CodingType == I_TYPE && hevcPicParams->pps_curr_pic_ref_enabled_flag)
+            {
+                return I_TYPE;
+            }
+        }
         return P_TYPE;
     case sliceTypeB:
         return B_TYPE;
@@ -1451,3 +1499,11 @@ uint32_t DdiEncodeHevc::getQMatrixBufferSize()
 {
     return sizeof(VAQMatrixBufferHEVC);
 }
+
+bool DdiEncodeHevc::IsSccProfile()
+{
+    return (m_encodeCtx->vaProfile==VAProfileHEVCSccMain
+           || m_encodeCtx->vaProfile==VAProfileHEVCSccMain10
+           || m_encodeCtx->vaProfile==VAProfileHEVCSccMain444
+           || m_encodeCtx->vaProfile==VAProfileHEVCSccMain444_10);
+}
