@@ -54,6 +54,26 @@ GpuContextSpecific::GpuContextSpecific(
     {
         MOS_OS_NORMALMESSAGE("gpucontex reusing not enabled on Linux.");
     }
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    // get user engine instance setting from environment variable
+    char *engineInstances = getenv("INTEL_ENGINE_INSTANCE");
+    if (engineInstances != nullptr)
+    {
+        errno             = 0;
+        long int instance = strtol(engineInstances, nullptr, 16);
+        /* Check for various possible errors. */
+        if ((errno == ERANGE && instance == LONG_MAX) || (instance < 0))
+        {
+            MOS_OS_NORMALMESSAGE("Invalid INTEL_ENGINE_INSTANCE setting.(%s)\n", engineInstances);
+            m_engineInstanceSelect = 0x0;
+        }
+        else
+        {
+            m_engineInstanceSelect = (uint32_t)instance;
+        }
+    }
+#endif
 }
 
 GpuContextSpecific::~GpuContextSpecific()
@@ -135,9 +155,12 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
 
     if (osInterface->ctxBasedScheduling)
     {
-        unsigned int nengine = 0;
+        unsigned int nengine              = 0;
         struct i915_engine_class_instance *engine_map = nullptr;
 
+        MOS_TraceEventExt(EVENT_GPU_CONTEXT_CREATE, EVENT_TYPE_START,
+                          &GpuNode, sizeof(GpuNode), nullptr, 0);
+
         m_i915Context[0] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
                                              osInterface->pOsContext->intel_context,
                                              I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
@@ -217,6 +240,9 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
                 return MOS_STATUS_UNKNOWN;
             }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+            SelectEngineInstanceByUser(engine_map, &nengine, m_engineInstanceSelect, GpuNode);
+#endif
             if (mos_set_context_param_load_balance(m_i915Context[0], engine_map, nengine))
             {
                 MOS_OS_ASSERTMESSAGE("Failed to set balancer extension.\n");
@@ -239,6 +265,9 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
                 return MOS_STATUS_UNKNOWN;
             }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+            SelectEngineInstanceByUser(engine_map, &nengine, m_engineInstanceSelect, GpuNode);
+#endif
             if (mos_set_context_param_load_balance(m_i915Context[0], engine_map, nengine))
             {
                 MOS_OS_ASSERTMESSAGE("Failed to set balancer extension.\n");
@@ -326,6 +355,9 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
             return MOS_STATUS_UNKNOWN;
         }
         MOS_SafeFreeMemory(engine_map);
+        MOS_TraceEventExt(EVENT_GPU_CONTEXT_CREATE, EVENT_TYPE_END,
+                          m_i915Context, sizeof(void *),
+                          &nengine, sizeof(nengine));
     }
     return MOS_STATUS_SUCCESS;
 }
@@ -334,6 +366,8 @@ void GpuContextSpecific::Clear()
 {
     MOS_OS_FUNCTION_ENTER;
 
+    MOS_TraceEventExt(EVENT_GPU_CONTEXT_DESTROY, EVENT_TYPE_START,
+                      m_i915Context, sizeof(void *), nullptr, 0);
     // hanlde the status buf bundled w/ the specified gpucontext
     if (m_statusBufferResource)
     {
@@ -344,6 +378,7 @@ void GpuContextSpecific::Clear()
         m_statusBufferResource->Free(m_osContext, 0);
         MOS_Delete(m_statusBufferResource);
     }
+    MOS_FreeMemAndSetNull(m_statusBufferMosResource);
 
     MOS_LockMutex(m_cmdBufPoolMutex);
 
@@ -379,6 +414,8 @@ void GpuContextSpecific::Clear()
             m_i915Context[i] = nullptr;
         }
     }
+    MOS_TraceEventExt(EVENT_GPU_CONTEXT_DESTROY, EVENT_TYPE_END,
+                      nullptr, 0, nullptr, 0);
 }
 
 MOS_STATUS GpuContextSpecific::RegisterResource(
@@ -559,6 +596,7 @@ MOS_STATUS GpuContextSpecific::GetCommandBuffer(
         comamndBuffer->iCmdIndex  = m_nextFetchIndex;
         comamndBuffer->iVdboxNodeIndex = MOS_VDBOX_NODE_INVALID;
         comamndBuffer->iVeboxNodeIndex = MOS_VEBOX_NODE_INVALID;
+        comamndBuffer->is1stLvlBB = true;
         comamndBuffer->Attributes.pAttriVe = nullptr;
 
         // zero comamnd buffer
@@ -803,6 +841,8 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
 {
     MOS_OS_FUNCTION_ENTER;
 
+    MOS_TraceEventExt(EVENT_MOS_BATCH_SUBMIT, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
+
     MOS_OS_CHK_NULL_RETURN(osInterface);
     PMOS_CONTEXT osContext = osInterface->pOsContext;
     MOS_OS_CHK_NULL_RETURN(osContext);
@@ -936,15 +976,33 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
             skipSyncBoList.push_back(alloc_bo);
         }
 
-        // This call will patch the command buffer with the offsets of the indirect state region of the command buffer
-        ret = mos_bo_emit_reloc2(
-            tempCmdBo,                                                         // Command buffer
-            currentPatch->PatchOffset,                                         // Offset in the command buffer
-            alloc_bo,                                                          // Allocation object for which the patch will be made.
-            currentPatch->AllocationOffset,                                    // Offset to the indirect state
-            I915_GEM_DOMAIN_RENDER,                                            // Read domain
-            (currentPatch->uiWriteOperation) ? I915_GEM_DOMAIN_RENDER : 0x0,   // Write domain
-            boOffset);
+#if (_DEBUG || _RELEASE_INTERNAL)
+        {
+            uint32_t evtData[] = {alloc_bo->handle, currentPatch->uiWriteOperation, currentPatch->AllocationOffset};
+            MOS_TraceEventExt(EVENT_MOS_BATCH_SUBMIT, EVENT_TYPE_INFO,
+                              evtData, sizeof(evtData),
+                              &boOffset, sizeof(boOffset));
+        }
+#endif
+        if(mos_gem_bo_is_softpin(alloc_bo))
+        {
+            if (alloc_bo != tempCmdBo)
+            {
+                ret = mos_bo_add_softpin_target(tempCmdBo, alloc_bo, currentPatch->uiWriteOperation);
+            }
+        }
+        else
+        {
+            // This call will patch the command buffer with the offsets of the indirect state region of the command buffer
+            ret = mos_bo_emit_reloc2(
+                tempCmdBo,                                                         // Command buffer
+                currentPatch->PatchOffset,                                         // Offset in the command buffer
+                alloc_bo,                                                          // Allocation object for which the patch will be made.
+                currentPatch->AllocationOffset,                                    // Offset to the indirect state
+                I915_GEM_DOMAIN_RENDER,                                            // Read domain
+                (currentPatch->uiWriteOperation) ? I915_GEM_DOMAIN_RENDER : 0x0,   // Write domain
+                boOffset);
+        }
 
         if (ret != 0)
         {
@@ -961,15 +1019,36 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
     }
     mappedResList.clear();
 
-    //Add Batch buffer End Command
-    uint32_t batchBufferEndCmd = MI_BATCHBUFFER_END;
-    if (MOS_FAILED(Mos_AddCommand(
-            cmdBuffer,
-            &batchBufferEndCmd,
-            sizeof(uint32_t))))
+    if (scalaEnabled)
     {
-        MOS_OS_ASSERTMESSAGE("Inserting BB_END failed!");
-        return MOS_STATUS_UNKNOWN;
+         it = m_secondaryCmdBufs.begin();
+         while(it != m_secondaryCmdBufs.end())
+         {
+             //Add Batch buffer End Command
+             uint32_t batchBufferEndCmd = MI_BATCHBUFFER_END;
+             if (MOS_FAILED(Mos_AddCommand(
+                     it->second,
+                     &batchBufferEndCmd,
+                     sizeof(uint32_t))))
+             {
+                 MOS_OS_ASSERTMESSAGE("Inserting BB_END failed!");
+                 return MOS_STATUS_UNKNOWN;
+             }
+             it++;
+         }
+    }
+    else
+    {
+        //Add Batch buffer End Command
+        uint32_t batchBufferEndCmd = MI_BATCHBUFFER_END;
+        if (MOS_FAILED(Mos_AddCommand(
+                cmdBuffer,
+                &batchBufferEndCmd,
+                sizeof(uint32_t))))
+        {
+            MOS_OS_ASSERTMESSAGE("Inserting BB_END failed!");
+            return MOS_STATUS_UNKNOWN;
+        }
     }
 
     // Now, we can unmap the video command buffer, since we don't need CPU access anymore.
@@ -1026,6 +1105,10 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
                 MOS_OS_ASSERTMESSAGE("Invalid gpuNode.");
             }
         }
+        else
+        {
+            execFlag = I915_EXEC_BSD | I915_EXEC_BSD_RING1;
+        }
     }
 
 #if (_DEBUG || _RELEASE_INTERNAL)
@@ -1125,8 +1208,12 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
                     {
                         if (it->second->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_SLAVE)
                         {
-                            it->second->iSubmissionType |= (secondaryIndex << SUBMISSION_TYPE_MULTI_PIPE_SLAVE_INDEX_SHIFT);
-                            secondaryIndex++;
+                            if(execFlag == MOS_GPU_NODE_VE)
+                            {
+                                // decode excluded since init in other place
+                                it->second->iSubmissionType |= (secondaryIndex << SUBMISSION_TYPE_MULTI_PIPE_SLAVE_INDEX_SHIFT);
+                                secondaryIndex++;
+                            }
                         }
 
                         ret = SubmitPipeCommands(it->second,
@@ -1242,6 +1329,7 @@ if (osInterface->bDumpCommandBuffer)
 
     MOS_ZeroMemory(m_writeModeList, sizeof(bool) * m_maxNumAllocations);
 finish:
+    MOS_TraceEventExt(EVENT_MOS_BATCH_SUBMIT, EVENT_TYPE_END, &eStatus, sizeof(eStatus), nullptr, 0);
     return eStatus;
 }
 
@@ -1292,7 +1380,7 @@ int32_t GpuContextSpecific::SubmitPipeCommands(
 
         for(auto bo: skipSyncBoList)
         {
-            mos_bo_set_exec_object_async(bo);
+            mos_bo_set_exec_object_async(cmdBo, bo);
         }
     }
 
@@ -1322,14 +1410,6 @@ int32_t GpuContextSpecific::SubmitPipeCommands(
         osContext->submit_fence = fence;
     }
 
-    if (cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_SLAVE)
-    {
-        for(auto bo: skipSyncBoList)
-        {
-            mos_bo_clear_exec_object_async(bo);
-        }
-    }
-
     if(cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_FLAGS_LAST_PIPE)
     {
         close(fence);
@@ -1369,6 +1449,9 @@ MOS_STATUS GpuContextSpecific::AllocateGPUStatusBuf()
 {
     MOS_OS_FUNCTION_ENTER;
 
+    m_statusBufferMosResource = (MOS_RESOURCE_HANDLE)MOS_AllocAndZeroMemory(sizeof(MOS_RESOURCE));
+    MOS_OS_CHK_NULL_RETURN(m_statusBufferMosResource);
+
     GraphicsResource::CreateParams params;
     params.m_tileType  = MOS_TILE_LINEAR;
     params.m_type      = MOS_GFXRES_BUFFER;
@@ -1398,3 +1481,58 @@ MOS_STATUS GpuContextSpecific::AllocateGPUStatusBuf()
     m_statusBufferResource = graphicsResource;
     return MOS_STATUS_SUCCESS;
 }
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+bool GpuContextSpecific::SelectEngineInstanceByUser(struct i915_engine_class_instance *engineMap,
+        uint32_t *engineNum, uint32_t userEngineInstance, MOS_GPU_NODE gpuNode)
+{
+    uint32_t engineInstance     = 0x0;
+
+    if(gpuNode == MOS_GPU_NODE_COMPUTE)
+    {
+        engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_COMPUTE_INSTANCE_SHIFT)
+            & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
+    }
+    else if(gpuNode == MOS_GPU_NODE_VE)
+    {
+        engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_VEBOX_INSTANCE_SHIFT)
+            & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
+    }
+    else if(gpuNode == MOS_GPU_NODE_VIDEO || gpuNode == MOS_GPU_NODE_VIDEO2)
+    {
+        engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_VDBOX_INSTANCE_SHIFT)
+            & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
+    }
+    else
+    {
+        MOS_OS_NORMALMESSAGE("Invalid gpu node in use.");
+    }
+
+    if(engineInstance)
+    {
+        auto unSelectIndex = 0;
+        for(auto bit = 0; bit < *engineNum; bit++)
+        {
+            if(((engineInstance >> bit) & 0x1) && (bit > unSelectIndex))
+            {
+                engineMap[unSelectIndex].engine_class = engineMap[bit].engine_class;
+                engineMap[unSelectIndex].engine_instance = engineMap[bit].engine_instance;
+                engineMap[bit].engine_class = 0;
+                engineMap[bit].engine_instance = 0;
+                unSelectIndex++;
+            }
+            else if(((engineInstance >> bit) & 0x1) && (bit == unSelectIndex))
+            {
+                unSelectIndex++;
+            }
+            else if(!((engineInstance >> bit) & 0x1))
+            {
+                engineMap[bit].engine_class = 0;
+                engineMap[bit].engine_instance = 0;
+            }
+        }
+        *engineNum = unSelectIndex;
+    }
+    return engineInstance;
+}
+#endif
