@@ -31,6 +31,7 @@
 #include "mos_cmdbufmgr_next.h" 
 #include "mos_gpucontextmgr_next.h"
 #include "mos_decompression.h"
+#include "mos_mediacopy.h"
 
 class OsContextNext
 {
@@ -50,7 +51,7 @@ public:
     //! \brief  Initialzie the OS ContextNext Object
     //! \return MOS_STATUS_SUCCESS on success case, MOS error status on fail cases
     //!
-    virtual MOS_STATUS Init(DDI_DEVICE_CONTEXT osDriverContextNext);
+    virtual MOS_STATUS Init(DDI_DEVICE_CONTEXT osDriverContextNext) = 0;
 
 private:
     //!
@@ -113,14 +114,6 @@ public:
     //!
     bool GetOsContextValid() { return m_osContextValid; };
 
-    //!
-    //! \brief  Set slice count to shared memory and KMD
-    //! \param  [in,out] pSliceCount
-    //!         pointer to the slice count. Input the slice count for current
-    //!         contextNext, output the ruling slice count shared by all contextNexts.
-    //!
-    virtual void SetSliceCount(uint32_t *pSliceCount) { MOS_UNUSED(pSliceCount); };
-
     //!
     //! \brief  Get GPU context manager of the device
     //! \return GPU context manager
@@ -147,6 +140,16 @@ public:
     {
         return m_mosDecompression;
     }
+
+    //!
+    //! \brief  Get MosMediaCopy
+    //! \return ptr to MosMediaCopy
+    //!
+    MosMediaCopy *GetMosMediaCopy()
+    {
+        return m_mosMediaCopy;
+    }
+
     //! \brief  Get the DumpFrameNum
     //! \return The current dumped frameNum
     //!
@@ -188,6 +191,12 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    //!
+    //! \brief  Determine whether the device is using async mode
+    //! \return true if the device is in async mode, false otherwise
+    //!
+    bool IsAynchronous() { return m_aynchronousDevice; }
+
     static const uint32_t m_cmdBufAlignment = 16;   //!> Cmd buffer alignment
 
 protected:
@@ -226,40 +235,28 @@ protected:
     //! \brief  need KMD to track the media frame or not
     bool                            m_enableKmdMediaFrameTracking = false;
 
-    //! \brief  need KMD to assist the command buffer parsing
-    bool                            m_noParsingAssistanceInKmd = false;
-
-    //! \brief  how many bytes of the Nal Unit need be included
-    uint32_t                        m_numNalUnitBytesIncluded = 0;
-
-    //! \brief   For GPU Reset Statistics, rest counter
-    uint32_t                        m_gpuResetCount = 0;
-
-    //! \brief   For GPU Reset Statistics, the active batch
-    uint32_t                        m_gpuActiveBatch = 0;
-
-    //! \brief   For GPU Reset Statistics, the pending batch
-    uint32_t                        m_gpuPendingBatch = 0;
-
     //! \brief   For Resource addressing, whether patch list mode is active
     bool                            m_usesPatchList = false;
 
     //! \brief   For Resource addressing, whether GPU address mode is active
     bool                            m_usesGfxAddress = false;
 
-    //! \brief   For limited GPU VA resource can not be mapped during creation
-    bool                            m_mapOnCreate = false;
-
-    //! \brief  check whether use inline codec status update or seperate BB
-    bool                            m_inlineCodecStatusUpdate = false;
-
     //! \brief   Component info
     MOS_COMPONENT                   m_component = COMPONENT_UNKNOWN;
 
-    //! \brief   Flag to indicate if implicit Tile is needed
-    bool                            m_implicitTileNeeded = false;
+    //! \brief   Flag to indicate if Tile64 is supported
+    bool                            m_mediaTile64 = false;
+
+    //! \brief   Flag to indicate if NoGfxMemory is needed
+    bool                            m_noGfxMemoryNeeded = false;
 
     //! \brief  the ptr to mos decompression module
-    MosDecompression *m_mosDecompression = nullptr;
+    MosDecompression                *m_mosDecompression = nullptr;
+
+    //! \brief the ptr to mos media copy module
+    MosMediaCopy                    *m_mosMediaCopy = nullptr;
+
+    //!< Indicate if this device is working in aync mode or normal mode
+    bool                            m_aynchronousDevice = false;
 };
 #endif // #ifndef __MOS_CONTEXTNext_NEXT_H__
