@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2020, Intel Corporation
+* Copyright (c) 2019-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -28,6 +28,8 @@
 //!
 #include "sw_filter_pipe.h"
 #include "vp_obj_factories.h"
+#include "vp_feature_manager.h"
+#include "sw_filter_handle.h"
 
 using namespace vp;
 
@@ -69,10 +71,10 @@ MOS_STATUS SwFilterSubPipe::Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf
     {
         if (featureSet)
         {
-            VP_PUBLIC_CHK_STATUS_RETURN(featureSet->Update(inputSurf, outputSurf));
+            VP_PUBLIC_CHK_STATUS_RETURN(featureSet->Update(inputSurf, outputSurf, *this));
         }
     }
-    VP_PUBLIC_CHK_STATUS_RETURN(m_UnorderedFilters.Update(inputSurf, outputSurf));
+    VP_PUBLIC_CHK_STATUS_RETURN(m_UnorderedFilters.Update(inputSurf, outputSurf, *this));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -141,166 +143,22 @@ MOS_STATUS SwFilterSubPipe::AddSwFilterUnordered(SwFilter *swFilter)
     return m_UnorderedFilters.AddSwFilter(swFilter);
 }
 
-/****************************************************************************************************/
-/*                                      SwFilterFeatureHandler                                      */
-/****************************************************************************************************/
-
-SwFilterFeatureHandler::SwFilterFeatureHandler(VpInterface &vpInterface, FeatureType type) : m_vpInterface(vpInterface), m_type(type)
-{}
-
-SwFilterFeatureHandler::~SwFilterFeatureHandler()
-{}
-
-bool SwFilterFeatureHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex, SwFilterPipeType pipeType)
-{
-    if (isInputSurf && (uint32_t)surfIndex >= params.uSrcCount ||
-        !isInputSurf && (uint32_t)surfIndex >= params.uDstCount)
-    {
-        // Invalid parameters.
-        VP_PUBLIC_ASSERTMESSAGE("Surface index is bigger than surface count!");
-        return false;
-    }
-    return true;
-}
-
-MOS_STATUS SwFilterFeatureHandler::CreateSwFilter(SwFilter *&swFilter, VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex, SwFilterPipeType pipeType)
-{
-    swFilter = nullptr;
-    if (!IsFeatureEnabled(params, isInputSurf, surfIndex, pipeType))
-    {
-        // nullptr == swFilter means no such feature in params, which is also the valid case.
-        return MOS_STATUS_SUCCESS;
-    }
-    swFilter = m_vpInterface.GetSwFilterFactory().Create(m_type);
-    VP_PUBLIC_CHK_NULL_RETURN(swFilter);
-    MOS_STATUS status = swFilter->Configure(params, isInputSurf, surfIndex);
-    if (MOS_FAILED(status))
-    {
-        m_vpInterface.GetSwFilterFactory().Destory(swFilter);
-        VP_PUBLIC_CHK_STATUS_RETURN(status);
-    }
-    return MOS_STATUS_SUCCESS;
-}
-
-/****************************************************************************************************/
-/*                                      SwFilterCscHandler                                          */
-/****************************************************************************************************/
-
-SwFilterCscHandler::SwFilterCscHandler(VpInterface &vpInterface) : SwFilterFeatureHandler(vpInterface, FeatureTypeCsc)
-{
-}
-
-SwFilterCscHandler::~SwFilterCscHandler()
-{
-}
-
-bool SwFilterCscHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex, SwFilterPipeType pipeType)
-{
-    if (!SwFilterFeatureHandler::IsFeatureEnabled(params, isInputSurf, surfIndex, pipeType))
-    {
-        return false;
-    }
-
-    if (isInputSurf && (SwFilterPipeType1To1 == pipeType || SwFilterPipeTypeNTo1 == pipeType) ||
-        !isInputSurf && SwFilterPipeType1ToN == pipeType)
-    {
-        return true;
-    }
-    return false;
-}
-
-/****************************************************************************************************/
-/*                                      SwFilterRotMirHandler                                       */
-/****************************************************************************************************/
-
-SwFilterRotMirHandler::SwFilterRotMirHandler(VpInterface &vpInterface) : SwFilterFeatureHandler(vpInterface, FeatureTypeRotMir)
-{}
-SwFilterRotMirHandler::~SwFilterRotMirHandler()
-{}
-
-bool SwFilterRotMirHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex, SwFilterPipeType pipeType)
-{
-    if (!SwFilterFeatureHandler::IsFeatureEnabled(params, isInputSurf, surfIndex, pipeType))
-    {
-        return false;
-    }
-
-    if (isInputSurf && (SwFilterPipeType1To1 == pipeType || SwFilterPipeTypeNTo1 == pipeType) ||
-        !isInputSurf && SwFilterPipeType1ToN == pipeType)
-    {
-        return true;
-    }
-    return false;
-}
-
-/****************************************************************************************************/
-/*                                      SwFilterScalingHandler                                      */
-/****************************************************************************************************/
-
-SwFilterScalingHandler::SwFilterScalingHandler(VpInterface &vpInterface) : SwFilterFeatureHandler(vpInterface, FeatureTypeScaling)
-{}
-SwFilterScalingHandler::~SwFilterScalingHandler()
-{}
-
-bool SwFilterScalingHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex, SwFilterPipeType pipeType)
-{
-    if (!SwFilterFeatureHandler::IsFeatureEnabled(params, isInputSurf, surfIndex, pipeType))
-    {
-        return false;
-    }
-
-    if (isInputSurf && (SwFilterPipeType1To1 == pipeType || SwFilterPipeTypeNTo1 == pipeType) ||
-        !isInputSurf && SwFilterPipeType1ToN == pipeType)
-    {
-        return true;
-    }
-    return false;
-}
-
-/****************************************************************************************************/
-/*                                      SwFilterDnHandler                                      */
-/****************************************************************************************************/
-
-SwFilterDnHandler::SwFilterDnHandler(VpInterface &vpInterface) : SwFilterFeatureHandler(vpInterface, FeatureTypeDn)
-{}
-SwFilterDnHandler::~SwFilterDnHandler()
-{}
-
-bool SwFilterDnHandler::IsFeatureEnabled(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex, SwFilterPipeType pipeType)
-{
-    if (!SwFilterFeatureHandler::IsFeatureEnabled(params, isInputSurf, surfIndex, pipeType))
-    {
-        return false;
-    }
-
-    PVPHAL_SURFACE vphalSurf = isInputSurf ? params.pSrc[surfIndex] : params.pTarget[surfIndex];
-    if (vphalSurf && vphalSurf->pDenoiseParams &&
-        (vphalSurf->pDenoiseParams->bEnableLuma || vphalSurf->pDenoiseParams->bEnableHVSDenoise))
-    {
-        return true;
-    }
-
-    return false;
-}
-
 /****************************************************************************************************/
 /*                                      SwFilterPipe                                                */
 /****************************************************************************************************/
 
 SwFilterPipe::SwFilterPipe(VpInterface &vpInterface) : m_vpInterface(vpInterface)
 {
+    m_surfacesSetting.Clean();
 }
 
 SwFilterPipe::~SwFilterPipe()
 {
     Clean();
-    UnregisterFeatures();
 }
 
 MOS_STATUS SwFilterPipe::Initialize(VP_PIPELINE_PARAMS &params, FeatureRule &featureRule)
 {
-    RegisterFeatures();
-
     Clean();
 
     uint32_t i = 0;
@@ -318,8 +176,20 @@ MOS_STATUS SwFilterPipe::Initialize(VP_PIPELINE_PARAMS &params, FeatureRule &fea
             return MOS_STATUS_NULL_POINTER;
         }
         m_InputSurfaces.push_back(surf);
-        // Keep m_PreviousSurface same size as m_InputSurfaces.
-        m_PreviousSurface.push_back(nullptr);
+
+        // Keep m_pastSurface/m_futureSurface same size as m_InputSurfaces.
+        VP_SURFACE *pastSurface = nullptr;
+        if (params.pSrc[i]->pBwdRef)
+        {
+            pastSurface = m_vpInterface.GetAllocator().AllocateVpSurface(*params.pSrc[i]->pBwdRef);
+        }
+        VP_SURFACE *futureSurface = nullptr;
+        if (params.pSrc[i]->pFwdRef)
+        {
+            futureSurface = m_vpInterface.GetAllocator().AllocateVpSurface(*params.pSrc[i]->pFwdRef);
+        }
+        m_pastSurface.push_back(pastSurface);
+        m_futureSurface.push_back(futureSurface);
 
         // Initialize m_InputPipes.
         SwFilterSubPipe *pipe = MOS_New(SwFilterSubPipe);
@@ -368,6 +238,85 @@ MOS_STATUS SwFilterPipe::Initialize(VP_PIPELINE_PARAMS &params, FeatureRule &fea
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS SwFilterPipe::Initialize(VEBOX_SFC_PARAMS &params)
+{
+    Clean();
+
+    // Initialize input surface.
+    {
+        if (nullptr == params.input.surface)
+        {
+            Clean();
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+        // The value of plane offset are different between vp and codec. updatePlaneOffset need be set to true when create vp surface
+        // with mos surface from codec hal.
+        VP_SURFACE *input = m_vpInterface.GetAllocator().AllocateVpSurface(*params.input.surface, params.input.colorSpace,
+                                                                        params.input.chromaSiting, params.input.rcSrc,
+                                                                        params.output.rcDst, SURF_IN_PRIMARY, true);
+        if (nullptr == input)
+        {
+            Clean();
+            return MOS_STATUS_NULL_POINTER;
+        }
+        m_InputSurfaces.push_back(input);
+        // Keep m_PastSurface same size as m_InputSurfaces.
+        m_pastSurface.push_back(nullptr);
+        m_futureSurface.push_back(nullptr);
+
+        // Initialize m_InputPipes.
+        SwFilterSubPipe *pipe = MOS_New(SwFilterSubPipe);
+        if (nullptr == pipe)
+        {
+            Clean();
+            return MOS_STATUS_NULL_POINTER;
+        }
+        m_InputPipes.push_back(pipe);
+    }
+
+    // Initialize output surface.
+    {
+        if (nullptr == params.output.surface)
+        {
+            Clean();
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+        RECT recOutput = {0, 0, (int32_t)params.output.surface->dwWidth, (int32_t)params.output.surface->dwHeight};
+        // The value of plane offset are different between vp and codec. updatePlaneOffset need be set to true when create vp surface
+        // with mos surface from codec hal.
+        VP_SURFACE *output = m_vpInterface.GetAllocator().AllocateVpSurface(*params.output.surface, params.output.colorSpace,
+                                                                        params.output.chromaSiting, recOutput,
+                                                                        recOutput, SURF_OUT_RENDERTARGET, true);
+        if (nullptr == output)
+        {
+            Clean();
+            return MOS_STATUS_NULL_POINTER;
+        }
+        m_OutputSurfaces.push_back(output);
+
+        // Initialize m_OutputPipes.
+        SwFilterSubPipe *pipe = MOS_New(SwFilterSubPipe);
+        if (nullptr == pipe)
+        {
+            Clean();
+            return MOS_STATUS_NULL_POINTER;
+        }
+        m_OutputPipes.push_back(pipe);
+    }
+
+    UpdateSwFilterPipeType();
+
+    MOS_STATUS status = ConfigFeatures(params);
+    if (MOS_FAILED(status))
+    {
+        Clean();
+        return status;
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 void SwFilterPipe::UpdateSwFilterPipeType()
 {
     m_swFilterPipeType = SwFilterPipeTypeInvalid;
@@ -408,7 +357,7 @@ MOS_STATUS SwFilterPipe::Clean()
         }
     }
 
-    std::vector<VP_SURFACE *> *surfacesArray[] = {&m_InputSurfaces, &m_OutputSurfaces, &m_PreviousSurface, &m_NextSurface};
+    std::vector<VP_SURFACE *> *surfacesArray[] = {&m_InputSurfaces, &m_OutputSurfaces, &m_pastSurface, &m_futureSurface};
     for (auto surfaces : surfacesArray)
     {
         while (!surfaces->empty())
@@ -444,52 +393,6 @@ bool SwFilterPipe::IsPrimaryEmpty()
     return false;
 }
 
-// Only register features once. Do not clear feature handlers when clean.
-MOS_STATUS SwFilterPipe::RegisterFeatures()
-{
-    if (m_isFeatureRegistered)
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
-    // Clear m_featureHandler to avoid any garbage data.
-    UnregisterFeatures();
-
-    // Vebox/Sfc features.
-    SwFilterFeatureHandler *p = MOS_New(SwFilterCscHandler, m_vpInterface);
-    VP_PUBLIC_CHK_NULL_RETURN(p);
-    m_featureHandler.insert(std::make_pair(FeatureTypeCsc, p));
-
-    p = MOS_New(SwFilterRotMirHandler, m_vpInterface);
-    VP_PUBLIC_CHK_NULL_RETURN(p);
-    m_featureHandler.insert(std::make_pair(FeatureTypeRotMir, p));
-
-    p = MOS_New(SwFilterScalingHandler, m_vpInterface);
-    VP_PUBLIC_CHK_NULL_RETURN(p);
-    m_featureHandler.insert(std::make_pair(FeatureTypeScaling, p));
-
-    p = MOS_New(SwFilterDnHandler, m_vpInterface);
-    VP_PUBLIC_CHK_NULL_RETURN(p);
-    m_featureHandler.insert(std::make_pair(FeatureTypeDn, p));
-
-    m_isFeatureRegistered = true;
-    return MOS_STATUS_SUCCESS;
-}
-
-// Only register features once. Do not clear feature handlers during clean.
-MOS_STATUS SwFilterPipe::UnregisterFeatures()
-{
-    while (!m_featureHandler.empty())
-    {
-        auto it = m_featureHandler.begin();
-        SwFilterFeatureHandler *p = it->second;
-        m_featureHandler.erase(it);
-        MOS_Delete(p);
-    }
-    m_isFeatureRegistered = false;
-    return MOS_STATUS_SUCCESS;
-}
-
 MOS_STATUS SwFilterPipe::ConfigFeaturesToPipe(VP_PIPELINE_PARAMS &params, FeatureRule &featureRule, bool isInputPipe)
 {
     std::vector<SwFilterSubPipe *>  &pipes = isInputPipe ? m_InputPipes : m_OutputPipes;
@@ -499,7 +402,7 @@ MOS_STATUS SwFilterPipe::ConfigFeaturesToPipe(VP_PIPELINE_PARAMS &params, Featur
     for (uint32_t pipeIndex = 0; pipeIndex < pipes.size(); ++pipeIndex)
     {
         // Get a copy list for feature handler.
-        auto featureHander = m_featureHandler;
+        auto featureHander = *m_vpInterface.GetSwFilterHandlerMap();
 
         if (pipeIndex < rulePipes.size())
         {
@@ -549,6 +452,37 @@ MOS_STATUS SwFilterPipe::ConfigFeatures(VP_PIPELINE_PARAMS &params, FeatureRule
     return MOS_STATUS_SUCCESS == status1 ? status2 : status1;
 }
 
+MOS_STATUS SwFilterPipe::ConfigFeatures(VEBOX_SFC_PARAMS &params)
+{
+    std::vector<SwFilterSubPipe *>  &pipes = m_InputPipes;
+
+    SwFilter *swFilter = nullptr;
+    // Loop all input surfaces.
+    for (uint32_t pipeIndex = 0; pipeIndex < pipes.size(); ++pipeIndex)
+    {
+        auto featureHander = m_vpInterface.GetSwFilterHandlerMap();
+        // Process remaining unordered features
+        if (featureHander)
+        {
+            for (auto handler = featureHander->begin(); handler != featureHander->end(); handler++)
+            {
+                VP_PUBLIC_CHK_STATUS_RETURN(handler->second->CreateSwFilter(swFilter, params));
+                if (swFilter)
+                {
+                    VP_PUBLIC_CHK_STATUS_RETURN(AddSwFilterUnordered(swFilter, true, 0));
+                }
+            }
+        }
+        else
+        {
+            VP_PUBLIC_ASSERTMESSAGE("No VP Feature Manager Created");
+            return MOS_STATUS_UNIMPLEMENTED;
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS SwFilterPipe::UpdateFeatures(bool isInputPipe, uint32_t pipeIndex)
 {
     auto &pipes = isInputPipe ? m_InputPipes : m_OutputPipes;
@@ -734,9 +668,56 @@ VP_SURFACE *SwFilterPipe::GetSurface(bool isInputSurface, uint32_t index)
     }
 }
 
-VP_SURFACE *SwFilterPipe::GetPreviousSurface(uint32_t index)
+VP_SURFACE *SwFilterPipe::GetPastSurface(uint32_t index)
 {
-    return index < m_PreviousSurface.size() ? m_PreviousSurface[index] : nullptr;
+    return index < m_pastSurface.size() ? m_pastSurface[index] : nullptr;
+}
+
+VP_SURFACE *SwFilterPipe::GetFutureSurface(uint32_t index)
+{
+    return index < m_futureSurface.size() ? m_futureSurface[index] : nullptr;
+}
+
+MOS_STATUS SwFilterPipe::SetPastSurface(uint32_t index, VP_SURFACE *surf)
+{
+    if (index >= m_pastSurface.size())
+    {
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+    m_pastSurface[index] = surf;
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SwFilterPipe::SetFutureSurface(uint32_t index, VP_SURFACE *surf)
+{
+    if (index >= m_futureSurface.size())
+    {
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+    m_futureSurface[index] = surf;
+    return MOS_STATUS_SUCCESS;
+}
+
+VP_SURFACE *SwFilterPipe::RemovePastSurface(uint32_t index)
+{
+    if (index >= m_pastSurface.size())
+    {
+        return nullptr;
+    }
+    VP_SURFACE *surf = m_pastSurface[index];
+    m_pastSurface[index] = nullptr;
+    return surf;
+}
+
+VP_SURFACE *SwFilterPipe::RemoveFutureSurface(uint32_t index)
+{
+    if (index >= m_futureSurface.size())
+    {
+        return nullptr;
+    }
+    VP_SURFACE *surf = m_futureSurface[index];
+    m_futureSurface[index] = nullptr;
+    return surf;
 }
 
 VP_SURFACE *SwFilterPipe::RemoveSurface(bool isInputSurface, uint32_t index)
@@ -750,8 +731,15 @@ VP_SURFACE *SwFilterPipe::RemoveSurface(bool isInputSurface, uint32_t index)
 
         if (isInputSurface)
         {
-            // Keep m_PreviousSurface same status as m_InputSurfaces.
-            m_PreviousSurface[index] = nullptr;
+            // Keep m_pastSurface and m_futureSurface same status as m_InputSurfaces.
+            if (m_pastSurface[index])
+            {
+                m_vpInterface.GetAllocator().DestroyVpSurface(m_pastSurface[index]);
+            }
+            if (m_futureSurface[index])
+            {
+                m_vpInterface.GetAllocator().DestroyVpSurface(m_futureSurface[index]);
+            }
         }
 
         return surf;
@@ -759,6 +747,19 @@ VP_SURFACE *SwFilterPipe::RemoveSurface(bool isInputSurface, uint32_t index)
     return nullptr;
 }
 
+VP_SURFACE *SwFilterPipe::ReplaceSurface(VP_SURFACE *surf, bool isInputSurface, uint32_t index)
+{
+    auto &surfaces = isInputSurface ? m_InputSurfaces : m_OutputSurfaces;
+
+    if (index < surfaces.size())
+    {
+        VP_SURFACE *ret = surfaces[index];
+        surfaces[index] = surf;
+        return ret;
+    }
+    return nullptr;
+}
+
 MOS_STATUS SwFilterPipe::AddSurface(VP_SURFACE *&surf, bool isInputSurface, uint32_t index)
 {
     auto &surfaces = isInputSurface ? m_InputSurfaces : m_OutputSurfaces;
@@ -769,8 +770,9 @@ MOS_STATUS SwFilterPipe::AddSurface(VP_SURFACE *&surf, bool isInputSurface, uint
         surfaces.push_back(nullptr);
         if (isInputSurface)
         {
-            // Keep m_PreviousSurface same size as m_InputSurfaces.
-            m_PreviousSurface.push_back(nullptr);
+            // Keep m_PastSurface same size as m_InputSurfaces.
+            m_pastSurface.push_back(nullptr);
+            m_futureSurface.push_back(nullptr);
         }
     }
 
@@ -840,13 +842,24 @@ MOS_STATUS SwFilterPipe::RemoveUnusedLayers(bool bUpdateInput)
 
         if (bUpdateInput)
         {
-            // Keep m_PreviousSurface same size as m_InputSurfaces.
-            itSurf = m_PreviousSurface.begin();
-            for (i = 0; itSurf != m_PreviousSurface.end(); ++itSurf, ++i)
+            // Keep m_pastSurface same size as m_InputSurfaces.
+            itSurf = m_pastSurface.begin();
+            for (i = 0; itSurf != m_pastSurface.end(); ++itSurf, ++i)
             {
                 if (i == index)
                 {
-                    m_PreviousSurface.erase(itSurf);
+                    m_pastSurface.erase(itSurf);
+                    break;
+                }
+            }
+
+            // Keep m_futureSurface same size as m_InputSurfaces.
+            itSurf = m_futureSurface.begin();
+            for (i = 0; itSurf != m_futureSurface.end(); ++itSurf, ++i)
+            {
+                if (i == index)
+                {
+                    m_futureSurface.erase(itSurf);
                     break;
                 }
             }
