@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2020, Intel Corporation
+* Copyright (c) 2019-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -27,39 +27,53 @@
 //!           this file is for the base interface which is shared by all components.
 //!
 #include "vp_feature_manager.h"
+#include "sw_filter_handle.h"
 using namespace vp;
 
 /****************************************************************************************************/
 /*                                      VpFeatureManagerNext                                        */
 /****************************************************************************************************/
 
-VpFeatureManagerNext::VpFeatureManagerNext(VpAllocator &allocator, VpResourceManager *resourceManager, PVP_MHWINTERFACE pHwInterface) :
-    m_vpInterface(pHwInterface, allocator, resourceManager), m_Policy(m_vpInterface)
+VpFeatureManagerNext::VpFeatureManagerNext(VpInterface &vpInterface) :
+    m_vpInterface(vpInterface)
 {
+    m_vpInterface.SetSwFilterHandlers(m_featureHandler);
 }
 
 VpFeatureManagerNext::~VpFeatureManagerNext()
 {
+    UnregisterFeatures();
+    MOS_Delete(m_policy);
 }
 
-MOS_STATUS VpFeatureManagerNext::Initialize()
+MOS_STATUS VpFeatureManagerNext::Init(void* settings)
 {
-    return m_Policy.Initialize();
+    if (!m_policy)
+    {
+        m_policy = MOS_New(Policy, m_vpInterface);
+    }
+    VP_PUBLIC_CHK_NULL_RETURN(m_policy);
+
+    VP_PUBLIC_CHK_STATUS_RETURN(RegisterFeatures());
+    return m_policy->Initialize();
 }
 
-MOS_STATUS VpFeatureManagerNext::CreateHwFilterPipe(VP_PIPELINE_PARAMS &params, HwFilterPipe *&pHwFilterPipe)
+bool VpFeatureManagerNext::IsVeboxSfcFormatSupported(MOS_FORMAT formatInput, MOS_FORMAT formatOutput)
+{
+    if (m_policy)
+    {
+        return m_policy->IsVeboxSfcFormatSupported(formatInput, formatOutput);
+    }
+
+    return false;
+}
+
+MOS_STATUS VpFeatureManagerNext::CreateHwFilterPipe(SwFilterPipe &swFilterPipe, HwFilterPipe *&pHwFilterPipe)
 {
     MOS_STATUS status = MOS_STATUS_SUCCESS;
     pHwFilterPipe = nullptr;
 
-    SwFilterPipe * pSwFilterPipe = nullptr;
-    status = m_vpInterface.GetSwFilterPipeFactory().Create(params, pSwFilterPipe);
-
-    VP_PUBLIC_CHK_STATUS_RETURN(status);
-    VP_PUBLIC_CHK_NULL_RETURN(pSwFilterPipe);
-
-    status = m_vpInterface.GetHwFilterPipeFactory().Create(*pSwFilterPipe, m_Policy, pHwFilterPipe);
-    m_vpInterface.GetSwFilterPipeFactory().Destory(pSwFilterPipe);
+    status = m_vpInterface.GetHwFilterPipeFactory().Create(swFilterPipe, *m_policy, pHwFilterPipe);
 
     VP_PUBLIC_CHK_STATUS_RETURN(status);
     VP_PUBLIC_CHK_NULL_RETURN(pHwFilterPipe);
@@ -67,12 +81,12 @@ MOS_STATUS VpFeatureManagerNext::CreateHwFilterPipe(VP_PIPELINE_PARAMS &params,
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpFeatureManagerNext::InitPacketPipe(VP_PIPELINE_PARAMS &params,
+MOS_STATUS VpFeatureManagerNext::InitPacketPipe(SwFilterPipe &swFilterPipe,
                 PacketPipe &packetPipe)
 {
     HwFilterPipe *pHwFilterPipe = nullptr;
 
-    MOS_STATUS status = CreateHwFilterPipe(params, pHwFilterPipe);
+    MOS_STATUS status = CreateHwFilterPipe(swFilterPipe, pHwFilterPipe);
 
     VP_PUBLIC_CHK_STATUS_RETURN(status);
     VP_PUBLIC_CHK_NULL_RETURN(pHwFilterPipe);
@@ -97,6 +111,70 @@ MOS_STATUS VpFeatureManagerNext::UpdateResources(HwFilterPipe &hwFilterPipe)
     return hwFilterPipe.UpdateResources();
 }
 
+MOS_STATUS VpFeatureManagerNext::RegisterFeatures()
+{
+    if (m_isFeatureRegistered)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+    // Clear m_featureHandler to avoid any garbage data.
+    UnregisterFeatures();
+
+    // Vebox/Sfc features.
+    SwFilterFeatureHandler *p = MOS_New(SwFilterCscHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeCsc, p));
+
+    p = MOS_New(SwFilterRotMirHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeRotMir, p));
+
+    p = MOS_New(SwFilterScalingHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeScaling, p));
+
+    p = MOS_New(SwFilterDnHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeDn, p));
+
+    p = MOS_New(SwFilterSteHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeSte, p));
+
+    p = MOS_New(SwFilterTccHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeTcc, p));
+
+    p = MOS_New(SwFilterProcampHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeProcamp, p));
+
+    p = MOS_New(SwFilterHdrHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeHdr, p));
+
+    p = MOS_New(SwFilterDiHandler, m_vpInterface);
+    VP_PUBLIC_CHK_NULL_RETURN(p);
+    m_featureHandler.insert(std::make_pair(FeatureTypeDi, p));
+
+    m_isFeatureRegistered = true;
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS vp::VpFeatureManagerNext::UnregisterFeatures()
+{
+    while (!m_featureHandler.empty())
+    {
+        auto it = m_featureHandler.begin();
+        SwFilterFeatureHandler* p = it->second;
+        m_featureHandler.erase(it);
+        MOS_Delete(p);
+    }
+    m_isFeatureRegistered = false;
+    return MOS_STATUS_SUCCESS;
+}
+
 /****************************************************************************************************/
 /*                                      VPFeatureManager                                            */
 /****************************************************************************************************/
@@ -123,6 +201,9 @@ MOS_STATUS VPFeatureManager::CheckFeatures(void * params, bool &bApgFuncSupporte
         return MOS_STATUS_SUCCESS;
     }
 
+    VP_PUBLIC_CHK_NULL_RETURN(pvpParams->pSrc[0]);
+    VP_PUBLIC_CHK_NULL_RETURN(pvpParams->pTarget[0]);
+
     if (pvpParams->pSrc[0]->SurfType != SURF_IN_PRIMARY)
     {
         return MOS_STATUS_SUCCESS;
@@ -132,6 +213,14 @@ MOS_STATUS VPFeatureManager::CheckFeatures(void * params, bool &bApgFuncSupporte
     VP_PUBLIC_CHK_STATUS_RETURN(RectSurfaceAlignment(pvpParams->pSrc[0], pvpParams->pTarget[0]->Format));
     VP_PUBLIC_CHK_STATUS_RETURN(RectSurfaceAlignment(pvpParams->pTarget[0], pvpParams->pTarget[0]->Format));
 
+    //Force 8K to render. Handle this case in APG path after render path being enabled.
+    if (pvpParams->bDisableVeboxFor8K &&
+        ((pvpParams->pSrc[0]->dwWidth >= VPHAL_RNDR_8K_WIDTH || pvpParams->pSrc[0]->dwHeight >= VPHAL_RNDR_8K_HEIGHT) ||
+         (pvpParams->pTarget[0]->dwWidth >= VPHAL_RNDR_8K_WIDTH || pvpParams->pTarget[0]->dwHeight >= VPHAL_RNDR_8K_HEIGHT)))
+    {
+        VP_PUBLIC_NORMALMESSAGE("Disable VEBOX/SFC for 8k resolution");
+        return MOS_STATUS_SUCCESS;
+    }
 
     if (IsHdrNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]))
     {
@@ -151,48 +240,73 @@ MOS_STATUS VPFeatureManager::CheckFeatures(void * params, bool &bApgFuncSupporte
         return MOS_STATUS_SUCCESS;
     }
 
-    if (pvpParams->pSrc[0]->pDenoiseParams                  ||
-        pvpParams->pSrc[0]->pDeinterlaceParams              ||
+    if (pvpParams->pSrc[0]->pDeinterlaceParams              ||
         pvpParams->pSrc[0]->pBlendingParams                 ||
-        pvpParams->pSrc[0]->pColorPipeParams                ||
-        pvpParams->pSrc[0]->pHDRParams                      ||
         pvpParams->pSrc[0]->pLumaKeyParams                  ||
-        pvpParams->pSrc[0]->pProcampParams                  ||
-        pvpParams->pSrc[0]->bInterlacedScaling              ||
         pvpParams->pConstriction)
     {
         return MOS_STATUS_SUCCESS;
     }
 
+    if (pvpParams->pSrc[0]->bInterlacedScaling && !IsSfcInterlacedScalingSupported())
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+    // Disable DN kernel copy/update in APO path.
+    // Disable chroma DN in APO path.
+    // Disable HVS Denoise in APO path.
+    if (pvpParams->pSrc[0]->pDenoiseParams                       &&
+        pvpParams->pSrc[0]->pDenoiseParams->bEnableHVSDenoise)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
     if (Is2PassesCSCNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]))
     {
         return MOS_STATUS_SUCCESS;
     }
 
-    // for now, Temp removed ARGB input for APG
-    if (pvpParams->pSrc[0]->Format == Format_A8R8G8B8 ||
-        pvpParams->pSrc[0]->Format == Format_X8R8G8B8)
+    // Temp removed RGB input with DN/DI/IECP case
+    if ((IS_RGB_FORMAT(pvpParams->pSrc[0]->Format)) &&
+        (pvpParams->pSrc[0]->pDenoiseParams         ||
+        pvpParams->pSrc[0]->pDeinterlaceParams      ||
+        pvpParams->pSrc[0]->pProcampParams          ||
+        pvpParams->pSrc[0]->pColorPipeParams))
     {
         return MOS_STATUS_SUCCESS;
     }
 
-    bool bVeboxNeeded = false;
-    bool bSFCNeeded   = IsSfcOutputFeasible(pvpParams);
-
-    if (IsVeboxOutFeasible(pvpParams) ||
-        !bSFCNeeded)
+    // Ensure only enable DN/ACE/STE/TCC for vebox only case. For other features supported on vebox, such as csc,
+    // just fallback to legacy path.
+    if (IsVeboxOutFeasible(pvpParams) && !IsVeboxSupported(pvpParams))
     {
         return MOS_STATUS_SUCCESS;
     }
 
-    if ((!bVeboxNeeded &&
-        pvpParams->pSrc[0]->ScalingPreference == VPHAL_SCALING_PREFER_SFC_FOR_VEBOX) ||
-        pvpParams->pSrc[0]->ScalingPreference == VPHAL_SCALING_PREFER_COMP)
+    if (!IsVeboxOutFeasible(pvpParams) &&
+        !IsSfcOutputFeasible(pvpParams))
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+    bool bVeboxNeeded = IsVeboxSupported(pvpParams);
+    // If ScalingPreference == VPHAL_SCALING_PREFER_SFC_FOR_VEBOX, use SFC only when VEBOX is required
+    // For GEN12+, IEF has been removed from AVS sampler. Do not change the path if IEF is enabled.
+    if ((pvpParams->pSrc[0]->ScalingPreference == VPHAL_SCALING_PREFER_SFC_FOR_VEBOX) &&
+        (pvpParams->pSrc[0]->pIEFParams == nullptr || (pvpParams->pSrc[0]->pIEFParams && pvpParams->pSrc[0]->pIEFParams->bEnabled == false)) &&
+        (bVeboxNeeded == false))
     {
         VP_PUBLIC_NORMALMESSAGE("DDI choose to use SFC only for VEBOX, and since VEBOX is not required, change to Composition.");
         return MOS_STATUS_SUCCESS;
     }
 
+    if (pvpParams->pSrc[0]->ScalingPreference == VPHAL_SCALING_PREFER_COMP)
+    {
+        VP_PUBLIC_NORMALMESSAGE("DDI choose to use Composition, change to Composition.");
+        return MOS_STATUS_SUCCESS;
+    }
+
     bApgFuncSupported = true;
 
     return MOS_STATUS_SUCCESS;
@@ -319,7 +433,8 @@ bool VPFeatureManager::IsVeboxOutFeasible(
     MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
         nullptr,
         __VPHAL_BYPASS_COMPOSITION_ID,
-        &UserFeatureData));
+        &UserFeatureData,
+        m_hwInterface->m_osInterface->pOsContext));
     dwCompBypassMode = UserFeatureData.u32Data;
 
     if (dwCompBypassMode  != VP_COMP_BYPASS_DISABLED                           &&
@@ -348,8 +463,11 @@ finish:
 }
 bool VPFeatureManager::IsVeboxInputFormatSupport(PVPHAL_SURFACE pSrcSurface)
 {
-    bool    bRet = false;
-    VPHAL_RENDER_CHK_NULL_NO_STATUS(pSrcSurface);
+    if (nullptr == pSrcSurface)
+    {
+        VP_PUBLIC_ASSERTMESSAGE("nullptr == pSrcSurface");
+        return false;
+    }
 
     // Check if Sample Format is supported
     // Vebox only support P016 format, P010 format can be supported by faking it as P016
@@ -362,17 +480,18 @@ bool VPFeatureManager::IsVeboxInputFormatSupport(PVPHAL_SURFACE pSrcSurface)
         pSrcSurface->Format != Format_Y8 &&
         pSrcSurface->Format != Format_Y16U &&
         pSrcSurface->Format != Format_Y16S &&
-        !IS_PA_FORMAT(pSrcSurface->Format)/* &&
+        !IS_PA_FORMAT(pSrcSurface->Format) &&
+        (pSrcSurface->Format != Format_A8B8G8R8) &&
+        (pSrcSurface->Format != Format_X8B8G8R8) &&
+        (pSrcSurface->Format != Format_A8R8G8B8) &&
+        (pSrcSurface->Format != Format_X8R8G8B8)/* &&
         !IS_RGB64_FLOAT_FORMAT(pSrcSurface->Format)*/)
     {
-        VPHAL_RENDER_NORMALMESSAGE("Unsupported Source Format '0x%08x' for VEBOX.", pSrcSurface->Format);
-        goto finish;
+        VP_PUBLIC_NORMALMESSAGE("Unsupported Source Format '0x%08x' for VEBOX.", pSrcSurface->Format);
+        return false;
     }
 
-    bRet = true;
-
-finish:
-    return bRet;
+    return true;
 }
 bool VPFeatureManager::IsVeboxRTFormatSupport(
     PVPHAL_SURFACE pSrcSurface,
@@ -413,12 +532,33 @@ bool VPFeatureManager::IsVeboxRTFormatSupport(
 
     return bRet;
 }
+
+bool VPFeatureManager::IsVeboxSupported(PVP_PIPELINE_PARAMS params)
+{
+    VPHAL_RENDER_CHK_NULL_NO_STATUS(params);
+    VPHAL_RENDER_CHK_NULL_NO_STATUS(params->pSrc[0]);
+
+    if ((nullptr != params->pSrc[0]->pDenoiseParams && true == params->pSrc[0]->pDenoiseParams->bEnableLuma) ||
+        (nullptr != params->pSrc[0]->pProcampParams && true == params->pSrc[0]->pProcampParams->bEnabled) ||
+        (nullptr != params->pSrc[0]->pColorPipeParams &&
+        (true == params->pSrc[0]->pColorPipeParams->bEnableACE ||
+         true == params->pSrc[0]->pColorPipeParams->bEnableSTE ||
+         true == params->pSrc[0]->pColorPipeParams->bEnableTCC)))
+    {
+        return true;
+    }
+
+finish:
+    return false;
+}
+
 bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
 {
     uint32_t                    dwSfcMaxWidth = 0;
     uint32_t                    dwSfcMaxHeight = 0;
     uint32_t                    dwSfcMinWidth = 0;
     uint32_t                    dwSfcMinHeight = 0;
+    uint32_t                    dwDstMinHeight = 0;
     uint16_t                    wWidthAlignUnit = 0;
     uint16_t                    wHeightAlignUnit = 0;
     uint32_t                    dwSourceRegionWidth = 0;
@@ -427,7 +567,9 @@ bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
     uint32_t                    dwOutputRegionHeight = 0;
     bool                        bRet = false;
     float                       fScaleX = 0.0f, fScaleY = 0.0f;
+    float                       minRatio = 0.125f, maxRatio = 8.0f;
     bool                        disableSFC = false;
+    VP_POLICY_RULES             rules = {};
 
     VPHAL_RENDER_CHK_NULL_NO_STATUS(params);
     VPHAL_RENDER_CHK_NULL_NO_STATUS(params->pTarget[0]);
@@ -440,7 +582,8 @@ bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
         MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
             nullptr,
             __VPHAL_VEBOX_DISABLE_SFC_ID,
-            &UserFeatureData));
+            &UserFeatureData,
+            m_hwInterface->m_osInterface->pOsContext));
 
         disableSFC = UserFeatureData.bData ? true : false;
 
@@ -474,6 +617,18 @@ bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
     wWidthAlignUnit     = 1;
     wHeightAlignUnit    = 1;
 
+    switch (params->pSrc[0]->InterlacedScalingType)
+    {
+    case ISCALING_INTERLEAVED_TO_FIELD:
+        dwDstMinHeight = dwSfcMinHeight / 2;
+        break;
+    case ISCALING_FIELD_TO_INTERLEAVED:
+        dwDstMinHeight = dwSfcMinHeight * 2;
+        break;
+    default:
+        dwDstMinHeight = dwSfcMinHeight;
+    }
+
     // Apply alignment restriction to the source and scaled regions.
     switch (params->pTarget[0]->Format)
     {
@@ -510,9 +665,9 @@ bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
         OUT_OF_BOUNDS(dwSourceRegionWidth, dwSfcMinWidth, dwSfcMaxWidth)         ||
         OUT_OF_BOUNDS(dwSourceRegionHeight, dwSfcMinHeight, dwSfcMaxHeight)      ||
         OUT_OF_BOUNDS(dwOutputRegionWidth, dwSfcMinWidth, dwSfcMaxWidth)         ||
-        OUT_OF_BOUNDS(dwOutputRegionHeight, dwSfcMinHeight, dwSfcMaxHeight)      ||
+        OUT_OF_BOUNDS(dwOutputRegionHeight, dwDstMinHeight, dwSfcMaxHeight)      ||
         OUT_OF_BOUNDS(params->pTarget[0]->dwWidth, dwSfcMinWidth, dwSfcMaxWidth) ||
-        OUT_OF_BOUNDS(params->pTarget[0]->dwHeight, dwSfcMinHeight, dwSfcMaxHeight))
+        OUT_OF_BOUNDS(params->pTarget[0]->dwHeight, dwDstMinHeight, dwSfcMaxHeight))
     {
         VPHAL_RENDER_NORMALMESSAGE("Surface dimensions not supported by SFC Pipe.");
         bRet = false;
@@ -548,13 +703,21 @@ bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
         fScaleY = (float)dwOutputRegionWidth / (float)dwSourceRegionHeight;
     }
 
+    m_hwInterface->m_vpPlatformInterface->InitPolicyRules(rules);
+
+    if (rules.sfcMultiPassSupport.scaling.enable)
+    {
+        minRatio *= rules.sfcMultiPassSupport.scaling.downScaling.minRatioEnlarged;
+        maxRatio *= rules.sfcMultiPassSupport.scaling.upScaling.maxRatioEnlarged;
+    }
+
     // SFC scaling range is [0.125, 8] for both X and Y direction.
-    if ((fScaleX < 0.125F) || (fScaleX > 8.0F) ||
-        (fScaleY < 0.125F) || (fScaleY > 8.0F))
+    if ((fScaleX < minRatio) || (fScaleX > maxRatio) ||
+        (fScaleY < minRatio) || (fScaleY > maxRatio))
     {
         VPHAL_RENDER_NORMALMESSAGE("Scaling factor not supported by SFC Pipe.");
-            bRet = false;
-            return bRet;
+        bRet = false;
+        return bRet;
     }
 
     // Check if the input/output combination is supported, given certain alpha fill mode.
@@ -563,18 +726,27 @@ bool VPFeatureManager::IsSfcOutputFeasible(PVP_PIPELINE_PARAMS params)
        (params->pCompAlpha->AlphaMode == VPHAL_ALPHA_FILL_MODE_NONE         ||
         params->pCompAlpha->AlphaMode == VPHAL_ALPHA_FILL_MODE_SOURCE_STREAM))
     {
-        if ((params->pTarget[0]->Format == Format_A8R8G8B8    ||
-            params->pTarget[0]->Format == Format_A8B8G8R8     ||
-            params->pTarget[0]->Format == Format_R10G10B10A2  ||
-            params->pTarget[0]->Format == Format_B10G10R10A2  ||
-            params->pTarget[0]->Format == Format_Y410         ||
-            params->pTarget[0]->Format == Format_Y416         ||
-            params->pTarget[0]->Format == Format_AYUV)        &&
-           (params->pSrc[0]->Format == Format_A8B8G8R8        ||
-            params->pSrc[0]->Format == Format_A8R8G8B8        ||
-            params->pSrc[0]->Format == Format_Y410            ||
-            params->pSrc[0]->Format == Format_Y416            ||
-            params->pSrc[0]->Format == Format_AYUV))
+        //No Alpha DDI for LIBVA, Always allow SFC to do detail feature on GEN12+ on linux
+        //No matter what the current alpha mode is.
+        if (params->pSrc[0]->bIEF == true)
+        {
+            params->pCompAlpha->AlphaMode = VPHAL_ALPHA_FILL_MODE_NONE;
+            params->pCompAlpha->fAlpha    = 1.0;
+            bRet                          = true;
+            return bRet;
+        }
+        else if ((params->pTarget[0]->Format == Format_A8R8G8B8    ||
+                 params->pTarget[0]->Format == Format_A8B8G8R8     ||
+                 params->pTarget[0]->Format == Format_R10G10B10A2  ||
+                 params->pTarget[0]->Format == Format_B10G10R10A2  ||
+                 params->pTarget[0]->Format == Format_Y410         ||
+                 params->pTarget[0]->Format == Format_Y416         ||
+                 params->pTarget[0]->Format == Format_AYUV)        &&
+                (params->pSrc[0]->Format == Format_A8B8G8R8        ||
+                 params->pSrc[0]->Format == Format_A8R8G8B8        ||
+                 params->pSrc[0]->Format == Format_Y410            ||
+                 params->pSrc[0]->Format == Format_Y416            ||
+                 params->pSrc[0]->Format == Format_AYUV))
         {
             bRet = false;
             return bRet;
@@ -602,9 +774,11 @@ bool VPFeatureManager::IsOutputFormatSupported(PVPHAL_SURFACE outSurface)
         outSurface->Format != Format_Y216 &&
         outSurface->Format != Format_Y416)
     {
-        if (outSurface->TileType == MOS_TILE_Y    &&
-            (outSurface->Format == Format_P010    ||
-             outSurface->Format == Format_P016    ||
+        if ((outSurface->TileType == MOS_TILE_Y ||
+             (MEDIA_IS_SKU(m_hwInterface->m_skuTable, FtrSFCLinearOutputSupport) &&
+              outSurface->TileType == MOS_TILE_LINEAR))                          && 
+            (outSurface->Format == Format_P010  ||
+             outSurface->Format == Format_P016  ||
              outSurface->Format == Format_NV12))
         {
             ret = true;
@@ -747,3 +921,28 @@ MOS_STATUS VPFeatureManager::RectSurfaceAlignment(
 
     return eStatus;
 }
+
+bool VPFeatureManager::IsDiFormatSupported(MOS_FORMAT format)
+{
+    if (format != Format_AYUV         &&
+        format != Format_Y416         &&
+        format != Format_Y410         &&
+        format != Format_A8B8G8R8     &&
+        format != Format_A8R8G8B8     &&
+        format != Format_B10G10R10A2  &&
+        format != Format_R10G10B10A2  &&
+        format != Format_A16B16G16R16 &&
+        format != Format_A16R16G16B16)
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
+
+bool VPFeatureManager::IsVeboxSurfaceHeightAligned(VPHAL_SURFACE &surf)
+{
+    return MOS_IS_ALIGNED(MOS_MIN((uint32_t)surf.dwHeight, (uint32_t)surf.rcSrc.bottom), 4);
+}
