@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2020, Intel Corporation
+* Copyright (c) 2018-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -78,7 +78,7 @@ protected:
     //!           Pointer to Vebox Render Execution Caps
     //! \return   MOS_STATUS
     //!
-    MOS_STATUS SetChromaParams(
+    MOS_STATUS SetSfcChromaParams(
         VP_EXECUTE_CAPS         vpExecuteCaps);
 
     //!
@@ -104,9 +104,12 @@ protected:
     //!
     //! \brief    Setup Chroma sitting parameters
     //! \details  Setup Chroma sitting parameters
+    //! \param    [in] vpExecuteCaps
+    //!           Pointer to Vebox Render Execution Caps
     //! \return   MOS_STATUS
     //!
-    MOS_STATUS SetSubSampling();
+    MOS_STATUS UpdateChromaSiting(
+        VP_EXECUTE_CAPS         vpExecuteCaps);
 
     //!
     //! \brief    Check whether Chroma Up Sampling Needed
@@ -122,12 +125,8 @@ protected:
 };
 
 
-struct HW_FILTER_CSC_PARAM
+struct HW_FILTER_CSC_PARAM : public HW_FILTER_PARAM
 {
-    FeatureType             type;
-    PVP_MHWINTERFACE        pHwInterface;
-    VP_EXECUTE_CAPS         vpExecuteCaps;
-    PacketParamFactoryBase *pPacketParamFactory;
     FeatureParamCsc         cscParams;
 };
 
@@ -163,10 +162,22 @@ private:
 class PolicySfcCscHandler : public PolicyFeatureHandler
 {
 public:
-    PolicySfcCscHandler();
+    PolicySfcCscHandler(VP_HW_CAPS &hwCaps);
     virtual ~PolicySfcCscHandler();
     virtual bool IsFeatureEnabled(VP_EXECUTE_CAPS vpExecuteCaps);
     virtual HwFilterParameter *CreateHwFilterParam(VP_EXECUTE_CAPS vpExecuteCaps, SwFilterPipe &swFilterPipe, PVP_MHWINTERFACE pHwInterface);
+    virtual MOS_STATUS UpdateFeaturePipe(VP_EXECUTE_CAPS caps, SwFilter &feature, SwFilterPipe &featurePipe, SwFilterPipe &executePipe, bool isInputPipe, int index);
+    static VpPacketParameter* CreatePacketParam(HW_FILTER_PARAM& param)
+    {
+        if (param.type != FeatureTypeCscOnSfc)
+        {
+            VP_PUBLIC_ASSERTMESSAGE("Invalid Parameter for SFC CSC!");
+            return nullptr;
+        }
+
+        HW_FILTER_CSC_PARAM* cscParam = (HW_FILTER_CSC_PARAM*)(&param);
+        return VpSfcCscParameter::Create(*cscParam);
+    }
 
 private:
     PacketParamFactory<VpSfcCscParameter> m_PacketParamFactory;
@@ -190,13 +201,24 @@ private:
 class PolicyVeboxCscHandler : public PolicyFeatureHandler
 {
 public:
-    PolicyVeboxCscHandler();
+    PolicyVeboxCscHandler(VP_HW_CAPS &hwCaps);
     virtual ~PolicyVeboxCscHandler();
     virtual bool IsFeatureEnabled(VP_EXECUTE_CAPS vpExecuteCaps);
     virtual HwFilterParameter* CreateHwFilterParam(VP_EXECUTE_CAPS vpExecuteCaps, SwFilterPipe& swFilterPipe, PVP_MHWINTERFACE pHwInterface);
+    static VpPacketParameter* CreatePacketParam(HW_FILTER_PARAM& param)
+    {
+        if (param.type != FeatureTypeCscOnVebox)
+        {
+            VP_PUBLIC_ASSERTMESSAGE("Invalid Parameter for Vebox CSC!");
+            return nullptr;
+        }
+
+        HW_FILTER_CSC_PARAM* cscParam = (HW_FILTER_CSC_PARAM*)(&param);
+        return VpVeboxCscParameter::Create(*cscParam);
+    }
 
 private:
     PacketParamFactory<VpVeboxCscParameter> m_PacketParamFactory;
 };
 }
-#endif // !__VP_CSC_FILTER_H__
\ No newline at end of file
+#endif // !__VP_CSC_FILTER_H__
