@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2020, Intel Corporation
+* Copyright (c) 2018-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -34,20 +34,12 @@
 #include "vp_render_sfc_base.h"
 #include "vp_filter.h"
 
-#define VP_VEBOX_MAX_SLICES          4
 #define VP_MAX_NUM_FFDI_SURFACES     4                                       //!< 2 for ADI plus additional 2 for parallel execution on HSW+
 #define VP_NUM_FFDN_SURFACES         2                                       //!< Number of FFDN surfaces
 #define VP_NUM_STMM_SURFACES         2                                       //!< Number of STMM statistics surfaces
 #define VP_DNDI_BUFFERS_MAX          4                                       //!< Max DNDI buffers
 #define VP_NUM_KERNEL_VEBOX          8                                       //!< Max kernels called at Adv stage
 
-#define VP_VEBOX_RGB_HISTOGRAM_SIZE_PER_SLICE                (256 * 4)
-#define VP_VEBOX_ACE_HISTOGRAM_SIZE_PER_FRAME_PER_SLICE      (256 * 4)
-
-#define VP_VEBOX_RGB_HISTOGRAM_SIZE                      (VP_VEBOX_RGB_HISTOGRAM_SIZE_PER_SLICE * \
-                                                          VP_NUM_RGB_CHANNEL                    * \
-                                                          VP_VEBOX_MAX_SLICES)
-
 #define VP_VEBOX_RGB_ACE_HISTOGRAM_SIZE_RESERVED          (3072 * 4)
 
 #define VP_VEBOX_LACE_HISTOGRAM_256_BIN_PER_BLOCK          (256 * 2)
@@ -68,11 +60,13 @@
 #define VP_VEBOX_RGB_HISTOGRAM_SIZE_PER_SLICE                (256 * 4)
 #define VP_VEBOX_ACE_HISTOGRAM_SIZE_PER_FRAME_PER_SLICE      (256 * 4)
 
-#define VP_VEBOX_MAX_SLICES                              4
+//No matter how many vebox running, the histogram slice number is always 4.
+//When there is only one VEBOX, 0 is written to the other histogram slices by HW.
+#define VP_VEBOX_HISTOGRAM_SLICES_COUNT                      4
 
 #define VP_VEBOX_RGB_HISTOGRAM_SIZE                      (VP_VEBOX_RGB_HISTOGRAM_SIZE_PER_SLICE * \
                                                           VP_NUM_RGB_CHANNEL                    * \
-                                                          VP_VEBOX_MAX_SLICES)
+                                                          VP_VEBOX_HISTOGRAM_SLICES_COUNT)
 #define VP_VEBOX_RGB_ACE_HISTOGRAM_SIZE_RESERVED         (3072 * 4)
 
 //!
@@ -213,6 +207,20 @@
 #define VPHAL_VEBOX_DI_LPFWTLUT7_SD_NATUAL                          255
 #define VPHAL_VEBOX_DI_LPFWTLUT7_HD_NATUAL                          255
 
+//!
+//! \brief STE factor
+//!
+
+#define MHW_STE_FACTOR_MAX                      9  // STE factor is 0 ~ 9
+
+// \brief   VEBOX 3DLUT HDR
+#define LUT65_SEG_SIZE                                              65
+#define LUT65_MUL_SIZE                                              128
+#define LUT33_SEG_SIZE                                              33
+#define LUT33_MUL_SIZE                                              64
+#define VP_VEBOX_HDR_3DLUT65                                        LUT65_SEG_SIZE *\
+                                                                    LUT65_SEG_SIZE *\
+                                                                    LUT65_MUL_SIZE * sizeof(int64_t)
 
 //!
 //! \brief  Chroma Denoise params
@@ -313,7 +321,9 @@ public:
 
     virtual MOS_STATUS Destory() { return MOS_STATUS_SUCCESS; };
 
-    virtual MOS_STATUS Prepare() override { return MOS_STATUS_SUCCESS; };
+    virtual MOS_STATUS Prepare() override;
+
+    virtual MOS_STATUS PrepareState() override;
 
     virtual MOS_STATUS                  AllocateExecRenderData()
     {
@@ -365,7 +375,6 @@ public:
     //! \return   void
     //!
     virtual void SetupSurfaceStates(
-        bool                        bDiVarianceEnable,
         PVPHAL_VEBOX_SURFACE_STATE_CMD_PARAMS  pVeboxSurfaceStateCmdParams);
 
     //!
@@ -384,8 +393,6 @@ public:
         MOS_COMMAND_BUFFER                      &CmdBuffer,
         PRENDERHAL_GENERIC_PROLOG_PARAMS        pGenericPrologParams);
 
-    virtual MOS_STATUS InitSfcStateParams();
-
     //!
     //! \brief    Setup Scaling Params for Vebox/SFC
     //! \details  Setup surface Scaling Params for Vebox/SFC
@@ -456,6 +463,59 @@ public:
     //!
     virtual MOS_STATUS SetDnParams(PVEBOX_DN_PARAMS dnParams);
 
+    //!
+    //! \brief    Setup STE Params for Vebox
+    //! \details  Setup surface STE Params for Vebox
+    //! \param    [in] steParams
+    //!           STE Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetSteParams(PVEBOX_STE_PARAMS steParams);
+
+    //!
+    //! \brief    Setup HDR Params for Vebox
+    //! \details  Setup surface HDR Params for Vebox
+    //! \param    [in] HDRParams
+    //!           HDR Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetHdrParams(PVEBOX_HDR_PARAMS hdrParams)
+    {
+        return MOS_STATUS_UNIMPLEMENTED;
+    }
+
+    //!
+    //! \brief    Setup TCC Params for Vebox
+    //! \details  Setup surface TCC Params for Vebox
+    //! \param    [in] tccParams
+    //!           TCC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetTccParams(PVEBOX_TCC_PARAMS tccParams);
+
+    //!
+    //! \brief    Setup Procamp Params for Vebox
+    //! \details  Setup surface Procamp Params for Vebox
+    //! \param    [in] procampParams
+    //!           Procamp Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetProcampParams(PVEBOX_PROCAMP_PARAMS procampParams);
+
+    //!
+    //! \brief    Setup DI Params for Vebox
+    //! \details  Setup surface DN Params for Vebox
+    //! \param    [in] diParams
+    //!           DI Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetDiParams(PVEBOX_DI_PARAMS diParams);
+
     //!
     //! \brief    Get DN luma parameters
     //! \details  Get DN luma parameters
@@ -628,15 +688,12 @@ public:
 
     //!
     //! \brief    Setup Vebox_State Command parameter
-    //! \param    [in] bDiVarianceEnable
-    //!           Is DI/Variances report enabled
     //! \param    [in,out] pVeboxStateCmdParams
     //!           Pointer to VEBOX_STATE command parameters
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS SetupVeboxState(
-        bool                        bDiVarianceEnable,
         PMHW_VEBOX_STATE_CMD_PARAMS pVeboxStateCmdParams);
 
     //!
@@ -676,16 +733,9 @@ public:
         VP_SURFACE                          *inputSurface,
         VP_SURFACE                          *outputSurface,
         VP_SURFACE                          *previousSurface,
-        std::map<SurfaceType, VP_SURFACE*>  &internalSurfaces,
+        VP_SURFACE_SETTING                  &surfSetting,
         VP_EXECUTE_CAPS                     packetCaps) override;
 
-    //!
-    //! \brief    Copy and update vebox state
-    //! \details  Copy and update vebox state for input frame.
-    //! \return   MOS_STATUS
-    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!
-    virtual MOS_STATUS CopyAndUpdateVeboxState();
 
     //!
     //! \brief    Check whether the Vebox command parameters are correct
@@ -697,26 +747,9 @@ public:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS IsCmdParamsValid(
-        const MHW_VEBOX_STATE_CMD_PARAMS        &VeboxStateCmdParams,
-        const MHW_VEBOX_DI_IECP_CMD_PARAMS      &VeboxDiIecpCmdParams);
-
-    //!
-    //! \brief    Copy Vebox state heap
-    //! \details  Call HW interface function,
-    //!           use Secure_Block_Copy kernel,
-    //!           copy Vebox state heap between different memory
-    //! \return   MOS_STATUS
-    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!
-    virtual MOS_STATUS CopyVeboxStates();
-
-    //!
-    //! \brief    Vebox state heap update for auto mode features
-    //! \details  Update Vebox indirect states for auto mode features
-    //! \return   MOS_STATUS
-    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!
-    virtual MOS_STATUS UpdateVeboxStates();
+        const MHW_VEBOX_STATE_CMD_PARAMS            &VeboxStateCmdParams,
+        const MHW_VEBOX_DI_IECP_CMD_PARAMS          &VeboxDiIecpCmdParams,
+        const VPHAL_VEBOX_SURFACE_STATE_CMD_PARAMS  &VeboxSurfaceStateCmdParams);
 
     virtual MOS_STATUS QueryStatLayout(
         VEBOX_STAT_QUERY_TYPE QueryType,
@@ -757,6 +790,15 @@ public:
     //!
     virtual MOS_STATUS VeboxSetPerfTagPaFormat();
 
+    //!
+    //! \brief    Vebox state heap update for auto mode features
+    //! \details  Update Vebox indirect states for auto mode features
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS UpdateVeboxStates();
+
+
 protected:
 
     //!
@@ -765,8 +807,6 @@ protected:
     //! \param    [out] CmdBuffer
     //!           reference to Cmd buffer control struct
     //! \param    [out] GenericPrologParams
-    //!           Generic prolog params struct to be set
-    //! \param    [out] GpuStatusBuffer
     //!           GpuStatusBuffer resource to be set
     //! \param    [out] iRemaining
     //!           integer showing initial cmd buffer usage
@@ -776,7 +816,6 @@ protected:
    virtual MOS_STATUS PrepareVeboxCmd(
       MOS_COMMAND_BUFFER*                      CmdBuffer,
       RENDERHAL_GENERIC_PROLOG_PARAMS&         GenericPrologParams,
-      MOS_RESOURCE&                            GpuStatusBuffer,
       int32_t&                                 iRemaining);
 
     //!
@@ -871,6 +910,15 @@ protected:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS AddVeboxIECPState();
+
+    //!
+    //! \brief    Add vebox Gamut state
+    //! \details  Add vebox Gamut state
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS AddVeboxGamutState(){return MOS_STATUS_SUCCESS;}
+
     //!
     //! \brief    Vebox set up vebox state heap
     //! \details  Setup Vebox indirect states: DNDI and etc
@@ -883,15 +931,25 @@ protected:
     //! \brief    Vebox get the back-end colorspace conversion matrix
     //! \details  When the i/o is A8R8G8B8 or X8R8G8B8, the transfer matrix
     //!           needs to be updated accordingly
-    //! \param    [in] pSrcSurface
-    //!           Pointer to input surface of Vebox
-    //! \param    [in] pOutSurface
-    //!           Pointer to output surface of Vebox
+    //! \param    [in] inputColorSpace
+    //!           color space of vebox input surface
+    //! \param    [in] outputColorSpace
+    //!           color space of vebox output surface
+    //! \param    [in] inputFormat
+    //!           format of vebox input surface
     //! \return   void
     //!
     virtual void VeboxGetBeCSCMatrix(
-        PVPHAL_SURFACE pSrcSurface,
-        PVPHAL_SURFACE pOutSurface);
+        VPHAL_CSPACE    inputColorSpace,
+        VPHAL_CSPACE    outputColorSpace,
+        MOS_FORMAT      inputFormat);
+
+    virtual MOS_STATUS SetDiParams(
+        bool                    bDiEnabled,
+        bool                    bSCDEnabled,
+        bool                    bHDContent,
+        VPHAL_SAMPLE_TYPE       sampleTypeInput,
+        MHW_VEBOX_DNDI_PARAMS   &param);
 
     //!
     //! \brief    Get surface by type
@@ -901,10 +959,12 @@ protected:
     //! \return   VP_SURFACE*
     //!           Pointer to surface of specified type
     //!
-    virtual VP_SURFACE *GetSurface(SurfaceType type);
+    virtual VP_SURFACE* GetSurface(SurfaceType type);
 
     virtual MOS_STATUS InitSurfMemCacheControl(VP_EXECUTE_CAPS packetCaps);
 
+    virtual MHW_CSPACE VpHalCspace2MhwCspace(VPHAL_CSPACE cspace);
+
 private:
 
     //!
@@ -922,6 +982,7 @@ private:
     //! \return   bool  success if succeeded, otherwise failure
     //!
     virtual MOS_STATUS SetSfcMmcParams();
+    MOS_STATUS InitSfcRender();
 
 protected:
 
@@ -934,9 +995,7 @@ protected:
     float                       m_fCscInOffset[3];                                 //!< [3x1] Input Offset matrix for CSC
     float                       m_fCscOutOffset[3];                                //!< [3x1] Output Offset matrix for CSC
     SfcRenderBase               *m_sfcRender             = nullptr;
-    VPHAL_SFC_RENDER_DATA       m_sfcRenderData          = {};
     bool                        m_IsSfcUsed              = false;
-    std::map<SurfaceType, VP_SURFACE*> m_surfacesGroup;
 
     VEBOX_PACKET_SURFACE_PARAMS m_veboxPacketSurface = {};
 
@@ -948,12 +1007,20 @@ protected:
     uint32_t                    m_dwGlobalNoiseLevelV = 0;                        //!< Global Noise Level for V
     uint32_t                    m_dwGlobalNoiseLevel = 0;                         //!< Global Noise Level
     PVP_VEBOX_CACHE_CNTL        m_surfMemCacheCtl = nullptr;                      //!< Surface memory cache control
+    uint32_t                    m_DNDIFirstFrame = 0;
     uint32_t                    m_DIOutputFrames = MEDIA_VEBOX_DI_OUTPUT_CURRENT; //!< default value is 2 for non-DI case.
 
     // Statistics
     uint32_t                    m_dwVeboxPerBlockStatisticsWidth = 0;             //!< Per block statistics width
     uint32_t                    m_dwVeboxPerBlockStatisticsHeight = 0;            //!< Per block statistics height
 
+    // STE factor LUT
+    static const uint32_t       m_satP1Table[MHW_STE_FACTOR_MAX + 1];
+    static const uint32_t       m_satS0Table[MHW_STE_FACTOR_MAX + 1];
+    static const uint32_t       m_satS1Table[MHW_STE_FACTOR_MAX + 1];
+
+    MediaScalability           *m_scalability              = nullptr;               //!< scalability
+
 };
 
 }
